@@ -41,6 +41,12 @@ public class FacilityInfo implements Serializable {
     /** 種別 */
     private int type = 0;
     
+    /** 仮想ノード種別 */
+    private String VirtNodeType = null;
+    
+    /** プラットフォーム名 */
+    private String Platform = null;
+    
     /**ツリー表示順ソートのための値*/
     private int sortOrder = 100;
 
