@@ -15,6 +15,9 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.monitor.run.dialog;
 
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.Iterator;
 import java.util.regex.Pattern;
 import java.util.regex.PatternSyntaxException;
 
@@ -34,6 +37,7 @@ import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
 import com.clustercontrol.bean.DataRangeConstant;
+import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.ProcessConstant;
 import com.clustercontrol.bean.ValidConstant;
@@ -42,15 +46,15 @@ import com.clustercontrol.composite.StringVerifyListener;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.monitor.run.bean.MonitorStringValueInfo;
-import com.clustercontrol.monitor.run.composite.StringRunJobComposite;
 import com.clustercontrol.monitor.run.util.StringValueInfoManager;
+import com.clustercontrol.notify.bean.NotifyRelationInfo;
 import com.clustercontrol.notify.composite.NotifyIdListComposite;
 import com.clustercontrol.util.Messages;
 
 /**
  * 文字列監視[作成・変更]ダイアログクラス<BR>
  * 
- * @version 2.1.0
+ * @version 3.0.0
  * @since 2.1.0
  */
 public class StringValueInfoCreateDialog extends CommonDialog {
@@ -97,11 +101,7 @@ public class StringValueInfoCreateDialog extends CommonDialog {
     /** メッセージ。 */
     private Text m_textMessage = null;
     
-    /** ジョブ実行。 */
-    private Button m_checkJobRun = null;
-    
-    /** ジョブ実行情報。 */
-    private StringRunJobComposite m_jobRun = null;
+ 
 
     /** この設定を有効にする。 */
     private Button m_buttonValid = null;
@@ -349,43 +349,6 @@ public class StringValueInfoCreateDialog extends CommonDialog {
         this.m_textMessage.addVerifyListener(
 				new StringVerifyListener(DataRangeConstant.VARCHAR_256));
         
-        // ジョブ実行
-        this.m_checkJobRun = new Button(group, SWT.CHECK);
-        gridData = new GridData();
-        gridData.horizontalSpan = 15;
-        gridData.horizontalAlignment = GridData.FILL;
-        gridData.grabExcessHorizontalSpace = true;
-        m_checkJobRun.setLayoutData(gridData);
-        m_checkJobRun.setText(Messages.getString("run") + " : ");
-        m_checkJobRun.addSelectionListener(new SelectionAdapter() {
-            public void widgetSelected(SelectionEvent e) {
-            	m_jobRun.setEnabled(m_checkJobRun.getSelection());
-            }
-        });
-		
-		// ジョブ実行グループ
-        Group groupRunJob = new Group(group, SWT.NONE);
-        layout = new GridLayout(1, true);
-        layout.marginWidth = 5;
-        layout.marginHeight = 5;
-        layout.numColumns = 1;
-        groupRunJob.setLayout(layout);
-        gridData = new GridData();
-        gridData.horizontalSpan = 15;
-        gridData.horizontalAlignment = GridData.FILL;
-        gridData.grabExcessHorizontalSpace = true;
-        groupRunJob.setLayoutData(gridData);
-        
-        // 実行（実行，ジョブID，通知抑制と連動，呼出失敗時）
-		this.m_jobRun = new StringRunJobComposite(
-				groupRunJob, 
-				SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = 1;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		m_jobRun.setLayoutData(gridData);
-
         /*
          * 有効／無効
          */
@@ -414,13 +377,31 @@ public class StringValueInfoCreateDialog extends CommonDialog {
         Display display = shell.getDisplay();
         shell.setLocation((display.getBounds().width - shell.getSize().x) / 2,
                 (display.getBounds().height - shell.getSize().y) / 2);
+        Collection<NotifyRelationInfo> modifyNotify = null;
 
         // 識別子が指定されている場合、その情報を初期表示する。
         MonitorStringValueInfo info = StringValueInfoManager.getInstance().get(this.m_identifier);
         if (info == null) {
         	info = new MonitorStringValueInfo();
         }
-        this.setInputData(info);
+        else {
+        	
+        	// 通知関連情報のディープコピーを作成
+        	if(info.getNotifyId() != null) {
+	        	modifyNotify = new ArrayList<NotifyRelationInfo>();
+	        	Iterator<NotifyRelationInfo> itr = info.getNotifyId().iterator();
+	        	while(itr.hasNext()){
+	        		NotifyRelationInfo relationInfo = itr.next();
+	        		modifyNotify.add(new NotifyRelationInfo(
+	        				relationInfo.getNotifyGroupId(), 
+	        				relationInfo.getNotifyId(), 
+	        				relationInfo.getNotifyType(), 
+	        				relationInfo.getNotifyFlg()));
+	        	}
+        	}
+        	
+        }
+        this.setInputData(info, modifyNotify);
     }
 
 	/**
@@ -437,7 +418,7 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 	 * 
 	 * @param info 設定値として用いる判定情報
 	 */
-    protected void setInputData(MonitorStringValueInfo info) {
+    protected void setInputData(MonitorStringValueInfo info, Collection<NotifyRelationInfo> modifyNotify) {
 
         this.m_inputData = info;
 
@@ -462,9 +443,12 @@ public class StringValueInfoCreateDialog extends CommonDialog {
             this.m_radioNotProcess.setSelection(true);
         }
         
-        // 通知
-        if (info.getNotifyId() != null) {
-            this.m_notifyId.setText(info.getNotifyId());
+    	
+        //通知情報の設定
+//        if(info.getNotifyId() != null)
+//        this.m_notifyId.setNotify(info.getNotifyId());
+        if(modifyNotify != null && modifyNotify.size() != 0){
+        	this.m_notifyId.setNotify(modifyNotify);
         }
         
         // 重要度
@@ -479,12 +463,7 @@ public class StringValueInfoCreateDialog extends CommonDialog {
         if (info.getMessage() != null) {
             this.m_textMessage.setText(info.getMessage());
         }
-        
-        // ジョブ実行
-        m_checkJobRun.setSelection(YesNoConstant.typeToBoolean(info.getJobRun()));
-        
-        // 各重要度のジョブ実行
-        m_jobRun.setInputData(info);
+       
         
         // 有効／無効
         if (info.isValidFlg() == ValidConstant.BOOLEAN_VALID) {
@@ -549,18 +528,41 @@ public class StringValueInfoCreateDialog extends CommonDialog {
         String priorityText = this.m_comboPriority.getText();
         info.setPriority(PriorityConstant.stringToType(priorityText));
         
-        // 通知ID
-        String notifyId = this.m_notifyId.getText();
-        if (notifyId != null && !"".equals(notifyId.trim())) {
-        	info.setNotifyId(notifyId);
+        
+        
+        //通知関連情報の設定
+        //通知グループIDの設定
+        //通知グループIDの設定は、監視設定自体を登録する際に設定するため、ここでは設定しないよう変更：uchiyama
+//        info.setNotifyGroupId(NotifyRelationInfo.createNotifyGroupId(HinemosModuleConstant.MONITOR_HTTP,info.getMonitorId(),info.getOrderNo()));
+        
+        //通知情報へのNotifyGroupIdのセット
+       // this.m_notifyId.setNotifyGroupId(info.getNotifyGroupId());
+        //コンポジットから通知情報を取得します。
+        info.setNotifyId(this.m_notifyId.getNotify());
+        
+        // 通知関連情報の設定
+        boolean isSetNotifyId = true;
+        // 通知ID入力確認
+        if (this.m_radioProcess.getSelection() && (info.getNotifyId() == null || info.getNotifyId().size() == 0)) {
+        	 this.setValidateResult(null,Messages.getString("message.notify.27"));
+				if(!displayQuestion(m_validateResult)){
+					m_validateResult = null;
+					return null;
+				}
+				else {
+					isSetNotifyId = false;
+				}
         }
 
+        
+        
+       
         // メッセージID
         if (this.m_textMessageId.getText() != null
                 && !"".equals((this.m_textMessageId.getText()).trim())) {
             info.setMessageId(this.m_textMessageId.getText());
         } else {
-            if (this.m_radioProcess.getSelection()) {
+            if (this.m_radioProcess.getSelection() && isSetNotifyId) {
         		this.setValidateResult(Messages.getString("message.hinemos.1"),
                         Messages.getString("message.monitor.28"));
                 return null;	
@@ -572,7 +574,7 @@ public class StringValueInfoCreateDialog extends CommonDialog {
                 && !"".equals((this.m_textMessage.getText()).trim())) {
             info.setMessage(this.m_textMessage.getText());
         } else {
-            if (this.m_radioProcess.getSelection()) {
+            if (this.m_radioProcess.getSelection() && isSetNotifyId) {
         		this.setValidateResult(Messages.getString("message.hinemos.1"),
                         Messages.getString("message.monitor.29"));
                 return null;	
@@ -580,13 +582,14 @@ public class StringValueInfoCreateDialog extends CommonDialog {
         }
         
         // ジョブ実行
-        info.setJobRun(YesNoConstant.booleanToType(m_checkJobRun.getSelection()));
+     //   info.setJobRun(YesNoConstant.booleanToType(m_checkJobRun.getSelection()));
         
         // 各重要度のジョブ実行
-        m_validateResult = m_jobRun.createInputData(info);
+     /*  m_validateResult = m_jobRun.createInputData(info);
         if(m_validateResult != null){
         	return null;
         }
+       */
         
         // 有効
         if (this.m_buttonValid.getSelection()) {
@@ -641,17 +644,16 @@ public class StringValueInfoCreateDialog extends CommonDialog {
      */
     private void setEnabled(boolean enable) {
 
-    	if(enable){
+    	/*if(enable){
         	this.m_jobRun.setEnabled(this.m_checkJobRun.getSelection());
         }
         else{
         	this.m_jobRun.setEnabled(enable);
-        }
+        }*/
     	this.m_notifyId.setEnabled(enable);
     	this.m_comboPriority.setEnabled(enable);
         this.m_textMessageId.setEnabled(enable);
         this.m_textMessage.setEnabled(enable);
-        this.m_checkJobRun.setEnabled(enable);
     }
     
 	/**
@@ -667,4 +669,22 @@ public class StringValueInfoCreateDialog extends CommonDialog {
         this.m_validateResult.setID(id);
         this.m_validateResult.setMessage(message);
     }
+    
+    /**
+     * 入力値の判定を行います。
+     * 
+     * @return true：正常、false：異常
+     * 
+     * @see com.clustercontrol.dialog.CommonDialog#action()
+     */
+    protected boolean action() {
+    	boolean result = false;
+    	
+    	MonitorStringValueInfo info = this.m_inputData;
+    	if(info != null){
+    		result = true;
+    	}
+    	
+    	return result;
+    }
 }
\ No newline at end of file
