@@ -700,6 +700,16 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
                 return null;
     	}    
         
+    	// 抑制条件は選択されているが、全ての重要度の抑制にチェックが入っていない場合はエラー
+    	if(!this.m_notifyInhibition.m_radioNoInhibition.getSelection() &&
+    			!this.m_checkLogEscalateInhibitionInfo.getSelection() && 
+    			!this.m_checkLogEscalateInhibitionWarning.getSelection() && 
+    			!this.m_checkLogEscalateInhibitionCritical.getSelection() && 
+    			!this.m_checkLogEscalateInhibitionUnknown.getSelection()){
+        	this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.notify.30"));
+                return null;
+    	}
+    	
         ArrayList<NotifyInfoDetail> list = new ArrayList<NotifyInfoDetail>();
 
         list = this.createInputDataForLogEscalate(list, PriorityConstant.TYPE_INFO,		this.m_checkLogEscalateRunInfo,			this.m_comboLogEscalateFacilityInfo, 		this.m_comboLogEscalateSeverityInfo, 		this.m_textLogEscalateMessageInfo,		this.m_checkLogEscalateInhibitionInfo);
