@@ -597,6 +597,16 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
                 return null;
     	}
         
+    	// 抑制条件は選択されているが、全ての重要度の抑制にチェックが入っていない場合はエラー
+    	if(!this.m_notifyInhibition.m_radioNoInhibition.getSelection() &&
+    			!this.m_checkStatusInhibitionInfo.getSelection() && 
+    			!this.m_checkStatusInhibitionWarning.getSelection() && 
+    			!this.m_checkStatusInhibitionCritical.getSelection() && 
+    			!this.m_checkStatusInhibitionUnknown.getSelection()){
+        	this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.notify.30"));
+                return null;
+    	}
+    	
         ArrayList<NotifyInfoDetail> list = new ArrayList<NotifyInfoDetail>();
         
         list = this.createInputDataForStatus(list, PriorityConstant.TYPE_INFO,		this.m_checkStatusNormalInfo,		this.m_checkStatusInhibitionInfo);
