@@ -247,9 +247,6 @@ public class PropertyUtil {
         clone.setUpperBound(original.getUpperBound());
         clone.setLowerBound(original.getLowerBound());
         clone.setStringUpperValue(original.getStringUpperValue());
-        if (clone.getCopy() == PropertyConstant.COPY_AND_MODIFY_OK) {
-            clone.setModify(PropertyConstant.MODIFY_OK);
-        }
 
         Object[][] selectValues = original.getSelectValues();
         Object[] childrens = original.getChildren();
@@ -300,14 +297,22 @@ public class PropertyUtil {
             int index = 0;
 
             if (original.getValue() != null) {
-                String dispText = (String) original.getValue();
-                for (int i = 0; i < selectValues[PropertyConstant.SELECT_DISP_TEXT].length; i++) {
-                    if (dispText
-                            .compareTo((String)selectValues[PropertyConstant.SELECT_DISP_TEXT][i]) == 0) {
+//                String dispText = (String) original.getValue();
+//                for (int i = 0; i < selectValues[PropertyConstant.SELECT_DISP_TEXT].length; i++) {
+//                    if (dispText
+//                            .compareTo((String)selectValues[PropertyConstant.SELECT_DISP_TEXT][i]) == 0) {
+//                        index = i;
+//                        break;
+//                    }
+//                }
+                String value = (String) original.getValue();
+                for (int i = 0; i < selectValues[PropertyConstant.SELECT_VALUE].length; i++) {
+                    if (value.compareTo((String)selectValues[PropertyConstant.SELECT_VALUE][i]) == 0) {
                         index = i;
                         break;
                     }
                 }
+
             }
 
             clone.setDefine(new ComboPropertyDefine(clone.getSelectValues()));
@@ -326,7 +331,8 @@ public class PropertyUtil {
                 }
             } else {
                 clone.removeChildren();
-                Object select = selectValues[PropertyConstant.SELECT_DISP_TEXT][index];
+//                Object select = selectValues[PropertyConstant.SELECT_DISP_TEXT][index];
+                Object select = selectValues[PropertyConstant.SELECT_VALUE][index];
                 clone.setValue(select);
             }
         } else if (define instanceof FilePropertyDefine) {
@@ -357,7 +363,13 @@ public class PropertyUtil {
             clone.setDefine(new TimePropertyDefine());
             clone.setValue(original.getValue());
         } else if (define instanceof TextAreaPropertyDefine) {
-            clone.setDefine(new TextAreaPropertyDefine());
+        	
+        	//テキストエリアの場合、独自にフラグを持っている（デフォルトfalse）ので、コピー時に変更する
+        	TextAreaPropertyDefine def = new TextAreaPropertyDefine();
+        	if (clone.getModify() == PropertyConstant.MODIFY_OK) {
+            	def.setModify(true);        		
+        	}
+            clone.setDefine(def);
             clone.setValue(original.getValue());
         } else {
             clone.setValue(original.getValue());
