@@ -24,7 +24,7 @@ PURPOSE.  See the GNU General Public License for more details.
 #include <stdio.h>
 #include <snmp.h>
 #include <winbase.h>
-#include "HinemosSNMPExtAgent.h"
+#include <HinemosSNMPExtAgent.h>
 
 #include <bitset>
 #include <string>
