@@ -576,7 +576,7 @@ public class StartDelayComposite extends Composite {
 		try {
 			// 開始遅延が有効であり、操作がスキップの場合のみ、入力されている終了値を確認する
 			if (m_waitRule.getStart_delay_operation() == YesNoConstant.TYPE_YES
-					&& m_waitRule.getStart_delay_operation_type() == OperationConstant.TYPE_STOP_SKIP) {
+					&& m_waitRule.getStart_delay_operation() == OperationConstant.TYPE_START_SKIP) {
 				m_waitRule.setStart_delay_operation_end_value(Integer.parseInt(m_operationValue.getText()));
 			}
 		} catch (NumberFormatException e) {
