@@ -24,5 +24,5 @@ package com.clustercontrol.jobmanagement.bean;
  */
 public class TopicConstant {
     /** ジョブ実行用トピック名 */
-    public static final String TOPIC_NAME_EXECUTE = "topic/clustercontrol/JobManagement/execute";
+    public static final String TOPIC_NAME_EXECUTE = "topic/clustercontrolJobManagementExecute";
 }
