@@ -350,7 +350,7 @@ public class JobInfoDAOImpl implements JobInfoDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_info";
+			String sql = "SELECT session_id, job_id FROM cc_job_info";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
@@ -401,7 +401,7 @@ public class JobInfoDAOImpl implements JobInfoDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_info WHERE session_id = ? AND job_id = ?";
+			String sql = "SELECT session_id, job_id FROM cc_job_info WHERE session_id = ? AND job_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
