@@ -306,7 +306,7 @@ public class JobNoticeMasterDAOImpl implements JobNoticeMasterDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_notice_mst";
+			String sql = "SELECT job_id, notice_type FROM cc_job_notice_mst";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
@@ -357,7 +357,7 @@ public class JobNoticeMasterDAOImpl implements JobNoticeMasterDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_notice_mst WHERE job_id = ? AND notice_type = ?";
+			String sql = "SELECT job_id, notice_type FROM cc_job_notice_mst WHERE job_id = ? AND notice_type = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
@@ -410,7 +410,7 @@ public class JobNoticeMasterDAOImpl implements JobNoticeMasterDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_notice_mst WHERE job_id = ?";
+			String sql = "SELECT job_id, notice_type FROM cc_job_notice_mst WHERE job_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
