@@ -391,7 +391,7 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_session_job";
+			String sql = "SELECT session_id, job_id FROM cc_job_session_job";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
@@ -442,7 +442,7 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_session_job WHERE session_id = ? AND job_id = ?";
+			String sql = "SELECT session_id, job_id FROM cc_job_session_job WHERE session_id = ? AND job_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
@@ -495,7 +495,7 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_session_job WHERE session_id = ?";
+			String sql = "SELECT session_id, job_id FROM cc_job_session_job WHERE session_id = ?";
 			
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
@@ -552,7 +552,7 @@ public class JobSessionJobDAOImpl implements JobSessionJobDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
 			StringBuilder sql = new StringBuilder();
-			sql.append("SELECT * FROM cc_job_session_job as a, cc_job_session as b ");
+			sql.append("SELECT a.session_id, a.job_id FROM cc_job_session_job as a, cc_job_session as b ");
 			sql.append("WHERE a.session_id = b.session_id AND a.job_id = b.job_id AND ");
 			sql.append("a.status = ?");
 			
