@@ -426,7 +426,7 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_session_node";
+			String sql = "SELECT session_id, job_id, facility_id FROM cc_job_session_node";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
@@ -478,7 +478,7 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_session_node WHERE session_id = ? AND job_id = ? AND facility_id = ?";
+			String sql = "SELECT session_id, job_id, facility_id FROM cc_job_session_node WHERE session_id = ? AND job_id = ? AND facility_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
@@ -532,7 +532,7 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_session_node WHERE session_id = ? AND job_id = ?";
+			String sql = "SELECT session_id, job_id, facility_id FROM cc_job_session_node WHERE session_id = ? AND job_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
@@ -589,7 +589,7 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_session_node WHERE facility_id = ?";
+			String sql = "SELECT session_id, job_id, facility_id FROM cc_job_session_node WHERE facility_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
@@ -646,7 +646,7 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
 			StringBuilder sql = new StringBuilder();
-			sql.append("SELECT * FROM cc_job_session_node ");
+			sql.append("SELECT session_id, job_id, facility_id FROM cc_job_session_node ");
 			sql.append("WHERE status = ?");
 			
 			//SQL文のセット
