@@ -128,7 +128,8 @@ public abstract class JobRunManagementBean implements javax.ejb.SessionBean {
         //ジョブ完了時に削除されないようにする。
         job.setDurability(true);
 	    //ジョブ実行失敗時に再実行するようにする。
-	    job.setRequestsRecovery(true);
+	    //JBoss再起動時に複数同時に再実行される可能性があるためこのオプションは設定しないよう変更する
+//	    job.setRequestsRecovery(true);
 	    
         //JobDetailに呼び出すクラスとメソッドを設定
         job.getJobDataMap().put(
