@@ -352,7 +352,9 @@ public class CreateFileJob {
 		TransactionManager tm = (TransactionManager)context.lookup("java:/TransactionManager");
 		
 		try {
-			Transaction tx = null, oldtx = null;
+//			Transaction tx = null, 
+//			Transactionの利用を取りやめたため、関連箇所ふくめコメントアウトした : uchiyama
+			Transaction oldtx = null;
 			
 			//現在のTransactionを一時停止
 			if(tm.getTransaction() != null){
@@ -361,16 +363,18 @@ public class CreateFileJob {
 			
 			//新しいTransactionを開始
 			tm.begin();
-			tx = tm.getTransaction();
+//			tx = tm.getTransaction();
 			
 			try {
 				createNodeJobNet(sessionId, parentJobId, jobId, fileData, fileList);
 			} catch (Exception e) {
 				//ロールバック
-				tx.rollback();
+//				tx.rollback();
+				tm.rollback();
 			}
 			//コミット
-			tx.commit();
+//			tx.commit();
+			tm.commit();
 			
 			//一時停止したTransactionを再開
 			if(oldtx != null){
@@ -421,14 +425,15 @@ public class CreateFileJob {
 		RepositoryControllerLocal repository = RepositoryControllerUtil.getLocalHome().create();
 		
 		//転送先ファシリティID取得
-		ArrayList<String> nodeIdList = null;
-		if(repository.isNode(file.getDest_facility_id())){
-			nodeIdList = new ArrayList<String>();
-			nodeIdList.add(file.getDest_facility_id());
-		}
-		else{
-			nodeIdList = repository.getNodeFacilityIdList(file.getDest_facility_id(), RepositoryControllerBean.ALL);
-		}
+		ArrayList<String> nodeIdList = repository.getExecTargetFacilityIdList(file.getDest_facility_id());
+//		ArrayList<String> nodeIdList = null;
+//		if(repository.isNode(file.getDest_facility_id())){
+//			nodeIdList = new ArrayList<String>();
+//			nodeIdList.add(file.getDest_facility_id());
+//		}
+//		else{
+//			nodeIdList = repository.getNodeFacilityIdList(file.getDest_facility_id(), RepositoryControllerBean.ALL);
+//		}
 		
 		//ノード単位のジョブネットを作成
 		for(int i = 0; i < nodeIdList.size(); i++){
