@@ -32,8 +32,8 @@ import com.clustercontrol.bean.FacilityTargetConstant;
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.monitor.bean.StatusInfoData;
-import com.clustercontrol.monitor.ejb.entity.StatusInfoLocal;
-import com.clustercontrol.monitor.ejb.entity.StatusInfoUtil;
+import com.clustercontrol.notify.monitor.ejb.entity.StatusInfoLocal;
+import com.clustercontrol.notify.monitor.ejb.entity.StatusInfoUtil;
 import com.clustercontrol.monitor.ejb.session.MonitorControllerBean;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerBean;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerLocal;
