@@ -366,7 +366,7 @@ public class StatusInfoDAOImpl implements StatusInfoDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			// SQL文の定義
-			String sql = "SELECT * FROM cc_status_info";
+			String sql = "SELECT facility_id,monitor_id,plugin_id FROM cc_status_info";
 			// SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
@@ -423,7 +423,7 @@ public class StatusInfoDAOImpl implements StatusInfoDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 
 			// SQL文の定義
-			String sql = "SELECT * FROM cc_status_info WHERE plugin_id = ? AND monitor_id = ? AND facility_id = ?";
+			String sql = "SELECT facility_id,monitor_id,plugin_id FROM cc_status_info WHERE plugin_id = ? AND monitor_id = ? AND facility_id = ?";
 			// SQL文のセット
 			stmt = conn.prepareStatement(sql);
 
@@ -497,7 +497,7 @@ public class StatusInfoDAOImpl implements StatusInfoDAO {
 
 			// SQL文の定義
 			StringBuffer sql = new StringBuffer();
-			sql.append("SELECT * FROM cc_status_info ");
+			sql.append("SELECT facility_id,monitor_id,plugin_id FROM cc_status_info ");
 			sql.append("WHERE ");
 
 			// ファシリティID設定
@@ -644,7 +644,7 @@ public class StatusInfoDAOImpl implements StatusInfoDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			// SQL文の定義
 			StringBuffer sql = new StringBuffer();
-			sql.append("SELECT * FROM cc_status_info ");
+			sql.append("SELECT facility_id,monitor_id,plugin_id FROM cc_status_info ");
 			
 			StringBuffer sqlWhere = new StringBuffer();
 
@@ -816,7 +816,7 @@ public class StatusInfoDAOImpl implements StatusInfoDAO {
 
 			// SQL文の定義
 			StringBuffer sql = new StringBuffer();
-			sql.append("SELECT * FROM cc_status_info ");
+			sql.append("SELECT facility_id,monitor_id,plugin_id FROM cc_status_info ");
 			sql.append("WHERE expiration_date <= ?");
 
 			// SQL文のセット
