@@ -315,10 +315,10 @@ public class RecordDataWriter implements Runnable {
                     for (int i = 0; i < itemInfoList.size(); i++) {
                         CollectorItemInfo itemInfo = itemInfoList.get(i);
                         if (itemInfo.getItemCode().equals(targetItemInfoList.get(j).getItemCode())
-                        		&& itemInfo.getDeviceName().equals(targetItemInfoList.get(j).getDeviceName())) {
+                        		&& itemInfo.getDisplayName().equals(targetItemInfoList.get(j).getDisplayName())) {
                             String itemName = CollectorItemCodeFactory
                                     .getFullItemName(itemInfo.getItemCode(), 
-                                    		itemInfo.getDeviceName());
+                                    		itemInfo.getDisplayName());
                             msg = msg + ", " + itemName;
                             i = itemInfoList.size(); // ループを抜ける
                         }
