@@ -33,13 +33,19 @@ public class GraphProperty {
     /** スコープ代表値 */
     public static final int TYPE1 = 1;
 
-    /** スコープ代表値詳細 */
+    /** 詳細(収集項目別) */
     public static final int TYPE2 = 2;
 
-    /** サブスコープ代表値 */
+    /** 詳細(サブスコープ別) */
     public static final int TYPE3 = 3;
 
     
+    /** 折れ線グラフ */
+    public static final int FORM1 = 1;
+    
+    /** 積み上げ面グラフ */
+    public static final int FORM2 = 2;
+    
 
     // DBMSなどに格納する上で判りやすいように文字表記とする.
     public static final String DISPLAY_NO = "DISPLAY_NO";  // NonDisplay
@@ -59,6 +65,7 @@ public class GraphProperty {
     FacilityTreeItem targetFacility; // グラフ表示対象ファシリティ
 
     int graphType; // グラフ表示方法
+    int graphForm; // グラフの形
 
     /**
      * コンストラクター
@@ -68,11 +75,12 @@ public class GraphProperty {
      * @param graphType グラフ種別
      */
     public GraphProperty(FacilityTreeItem targetFacility,
-            CollectorItemInfo targetItem, int graphType) {
+            CollectorItemInfo targetItem, int graphType, int graphForm) {
 
         this.targetFacility = targetFacility;
         this.targetItem = targetItem;
         this.graphType = graphType;
+        this.graphForm = graphForm;
     }
 
     /**
@@ -93,6 +101,24 @@ public class GraphProperty {
         this.graphType = graphType;
     }
 
+    /**
+     * グラフの形を取得します。
+     * 
+     * @return graphForm グラフ種別
+     */
+    public int getGraphForm() {
+        return graphForm;
+    }
+
+    /**
+     * グラフの形を設定します。
+     * 
+     * @param graphForm グラフの形
+     */
+    public void setGraphForm(int graphForm) {
+        this.graphForm = graphForm;
+    }
+
     /**
      * 描画対象ファシリティを取得します。
      * 
