@@ -163,8 +163,9 @@ public class RecordGraphHolderComposite extends Composite {
     		int graphNum , 
     		String facilityId, 
     		String itemCode, 
-    		String deviceName, 
+    		String displayName, 
     		int graphType,
+    		int graphForm,
     		Date startTime, 
     		Date endTime,
     		boolean isXRangeAuto,
@@ -190,7 +191,7 @@ public class RecordGraphHolderComposite extends Composite {
 		while(itr.hasNext()){
 			CollectorItemInfo itemInfo = itr.next();
 			if(itemInfo.getItemCode().equals(itemCode) && 
-					itemInfo.getDeviceName().equals(deviceName)){
+					itemInfo.getDisplayName().equals(displayName)){
 				targetItem = itemInfo;
 			}
 		}
@@ -258,7 +259,7 @@ public class RecordGraphHolderComposite extends Composite {
         	// compositeに対する操作であることに注意。
         	// RecordGraphCompositeの描画処理を実行
         	graphCompList[graphNum].drawGraph(
-        			new GraphProperty(targetFacility, targetItem, graphType), 
+        			new GraphProperty(targetFacility, targetItem, graphType, graphForm), 
         			startTime,
         			endTime);
         }
@@ -291,55 +292,6 @@ public class RecordGraphHolderComposite extends Composite {
     	// 一致するものが見つからなかった場合はnullを返す
     	return null;
     }
-    
-//    /**
-//     * 指定の期間設定でグラフを再表示します。
-//     *  
-//     * @param graphProperty グラフ描画設定（グラフの数分のリスト）
-//     */
-//    public void redrawGraph(Date startTime, Date endTime) {
-////        this.graphPropertys = graphProperty;
-//    	this.graphStartTime = startTime;
-//    	this.graphEndTime = endTime;
-//
-//        // 保持しているRecordGraphCompositeの数だけループをまわす
-//        for (int i = 0; i < this.graphCompList.length; i++) {
-//            // グラフ描画
-//            // グラフ種別が非表示の場合もしくは、
-//            // グラフ種別がサブスコープ代表値であるが、選択のスコープに子スコープがない場合
-//            if (graphCompList[i].getGraphType() == GraphProperty.INVISIBLE
-//                    || graphCompList[i].getGraphType() == GraphProperty.TYPE3
-//                    && graphCompList[i].getTargetFacility().getChildren().length == 0) {
-//            	// ここでは何もしない。
-//            } else {
-//                // ここが本来の仕事をするメインルート。
-//                // compositeに対する操作であることに注意。
-//            	// RecordGraphCompositeの描画処理を実行
-//            	graphCompList[i].drawGraph(
-//            			graphCompList[i].getGraphProperty(), 
-//                		graphStartTime.getTime(),
-//                		graphEndTime.getTime());
-//            }          
-//        }
-//    }
-    
-//    /**
-//     * 指定のグラフ領域を取得する（領域が存在しない場合は作成して返す）
-//     * 
-//     * @param index
-//     */
-//    private RecordGraphComposite getGraph(int graphIndex) {
-//        if (composite[graphIndex] == null) {
-//        	// グラフを表示する各々のためのcomposite.
-//            composite[graphIndex] = new RecordGraphComposite(baseCcomposite);
-//            // グラフ表示のためのデータを設定
-//            if (collectorData != null) {
-//                composite[graphIndex].setMasterData(collectorData, itemInfoList,
-//                        facilityTree);
-//            }
-//        }
-//        return composite[graphIndex];
-//    }
 
     /**
      * 指定のグラフ領域を削除する
