@@ -261,8 +261,8 @@ public class PerformancePreferencePage extends FieldEditorPreferencePage
     	for(int i = 0; i < store.getInt(PERF_GRAPH_NUM); i++){
     		store.setValue(PERF_ITEM_INFO[i][0], itemInfo.getItemCode(i));
     		store.setValue(PERF_ITEM_INFO[i][1], itemInfo.getDisplayType(i));
-    		if (itemInfo.getDeviceName(i) != null) {
-    			store.setValue(PERF_ITEM_INFO[i][2], itemInfo.getDeviceName(i));
+    		if (itemInfo.getDisplayName(i) != null) {
+    			store.setValue(PERF_ITEM_INFO[i][2], itemInfo.getDisplayName(i));
     		}
     		else {
     			store.setValue(PERF_ITEM_INFO[i][2], "");
@@ -287,6 +287,7 @@ public class PerformancePreferencePage extends FieldEditorPreferencePage
         			store.getString(PERF_ITEM_INFO[i][0]),
         			store.getString(PERF_ITEM_INFO[i][1]),
         			store.getString(PERF_ITEM_INFO[i][2]),
+        			store.getString(PERF_ITEM_INFO[i][3]),
         			store.getBoolean(PERF_ITEM_FOR_BOOLEAN[i][0])
 			);	
     	}
