@@ -72,8 +72,7 @@ public class RealtimeGraphView extends ScopeListBaseView {
 	 *  リアルタイムグラフを描画します。
 	 */
 	public RealtimeGraphView() {
-		// ノードを含め、INTERNAL, UNREGISTEREDを含めず, TOPICを受信するスコープツリーとする 
-		super(false, false, false, true);
+		super();
 		initialize();
 	}
 
@@ -95,10 +94,10 @@ public class RealtimeGraphView extends ScopeListBaseView {
 		// 動的に項目を設定する場合には、この方式は対応しきれない.
 		// 位置情報itemIdがNULLのときは初期状態と判定し、値がセットされているときは前回設定があると判定する.
 		// FIXME DBのマスタ情報が"CPU0100_CPU_UTIL"ではなくなった場合エラーとなる
-		collectorItemInfo.setItemInfo(0, "CPU0100_CPU_UTIL", "NonDisplay",	"", true); // CPU(CODE_CPU_UTILIZATION)
-		collectorItemInfo.setItemInfo(1, "CPU0100_CPU_UTIL", "NonDisplay",	"", true); // CPU(CODE_CPU_UTILIZATION)
-		collectorItemInfo.setItemInfo(2, "CPU0100_CPU_UTIL", "NonDisplay",	"", true); // CPU(CODE_CPU_UTILIZATION)
-		collectorItemInfo.setItemInfo(3, "CPU0100_CPU_UTIL", "NonDisplay",	"", true); // CPU(CODE_CPU_UTILIZATION)
+		collectorItemInfo.setItemInfo(0, "CPU0100_CPU_UTIL", "NonDisplay", "", "FormLine", true); // CPU(CODE_CPU_UTILIZATION)
+		collectorItemInfo.setItemInfo(1, "CPU0100_CPU_UTIL", "NonDisplay", "", "FormLine", true); // CPU(CODE_CPU_UTILIZATION)
+		collectorItemInfo.setItemInfo(2, "CPU0100_CPU_UTIL", "NonDisplay", "", "FormLine", true); // CPU(CODE_CPU_UTILIZATION)
+		collectorItemInfo.setItemInfo(3, "CPU0100_CPU_UTIL", "NonDisplay", "", "FormLine", true); // CPU(CODE_CPU_UTILIZATION)
 
 		String itemCodeList[] = CollectorItemCodeFactory.getCodeAll();
 		int itemCodeNum = 0;
@@ -207,21 +206,21 @@ public class RealtimeGraphView extends ScopeListBaseView {
 					collectorItemInfo.setItemInfoForCollector(
 							i, 
 							itemInfo.getItemCode(), 
-							itemInfo.getDeviceName(),
+							itemInfo.getDisplayName(),
 							isDetailed);
 				}
 			}
 
 			// グラフ表示項目の指定変更(既に指定されたdeviceIndex(itemId)が存在しない場合への対処)
 			loop1: for (int i = 0; i < collectorInfo.getGraphNum(); i++) {
-				if (collectorItemInfo.getDeviceName(i) != null) {
+				if (collectorItemInfo.getDisplayName(i) != null) {
 					boolean found = false;
 					loop2: for (int j = 0; j < collectorItemInfo
 							.getItemNumForCollector(); j++) {
 						if (collectorItemInfo.getItemCode(i).equals(
 								collectorItemInfo.getItemCodeForCollector(j))
-								&& collectorItemInfo.getDeviceName(i).equals(
-										collectorItemInfo.getDeviceNameForCollector(j))) {
+								&& collectorItemInfo.getDisplayName(i).equals(
+										collectorItemInfo.getDisplayNameForCollector(j))) {
 							found = true;
 							if (!collectorItemInfo.hasDevice(i)) {
 								collectorItemInfo.setHasDevice(i, true);
@@ -347,19 +346,20 @@ public class RealtimeGraphView extends ScopeListBaseView {
 
 			for (int i = 0; i < graphNum; i++) {
 				String itemCode = collectorItemInfo.getItemCode(i);
-				String deviceName = collectorItemInfo.getDeviceName(i); //  .getDeviceNameForCollector(Integer.valueOf(collectorItemInfo.getItemId(i)));
+				String displayName = collectorItemInfo.getDisplayName(i);
 				String displayType = collectorItemInfo.getDisplayType(i);
+				String displayForm = collectorItemInfo.getDisplayForm(i);
 				int graphPlotNum = collectorInfo.getGraphPlotNum();
 
 				graphComposite.addGraph(i, //graphId,
-						itemCode, deviceName, collectorInfo.getSubScopeNum(),
-						displayType, interval, isXRangeAuto, graphPlotNum); // isXRangeAutoはとりあえずfalseの仕様とする.
+						itemCode, displayName, collectorInfo.getSubScopeNum(), displayType, displayForm,
+						interval, isXRangeAuto, graphPlotNum); // isXRangeAutoはとりあえずfalseの仕様とする.
 
 				collectorItemInfo.setIsCollect(i, graphComposite.isCollect());
 
 				if (graphComposite.isCollect()) {
 					setCollector(timestamp, timestampId, itemCode,
-							deviceName, displayType, interval,
+							displayName, displayType, displayForm, interval,
 							facilityId);
 				}
 			}
@@ -384,8 +384,8 @@ public class RealtimeGraphView extends ScopeListBaseView {
 	}
 
 	private void setCollector(Date timestamp, int collectTimestampId,
-			String itemCode, String deviceName,
-			String displayType, int interval, String facilityId) {
+			String itemCode, String displayName, String displayType, String displayForm,
+			int interval, String facilityId) {
 		int requestInterval = collectorInfo.getRequestInterval();
 
 		if (graphComposite.m_timeseries == null) {
@@ -393,7 +393,7 @@ public class RealtimeGraphView extends ScopeListBaseView {
 		// Threadインスタンスの生成(Threadの実行はまだ)
 		collector = new RealtimeCollectThread(timestamp, collectTimestampId,
 				graphComposite.m_timeseries, itemCode,
-				deviceName, displayType, interval, requestInterval, facilityId,
+				displayName, displayType, displayForm, interval, requestInterval, facilityId,
 				check, graphComposite); // 軸の変更対象を伝えるため.
 
 		collector.setCollectorInfo(collectorInfo);
