@@ -86,8 +86,7 @@ public class RecordGraphView extends ScopeListBaseView {
      *  コンストラクタ
      */
     public RecordGraphView() {
-    	// ノードを含め、INTERNAL, UNREGISTEREDを含めず, TOPICを受信しないスコープツリーとする
-        super(false, false, false, false);
+        super();
         initialize();
     }
 
@@ -214,14 +213,14 @@ public class RecordGraphView extends ScopeListBaseView {
         	collectorItemInfo.setItemInfoForCollector(
         			i,
         			info.getItemCode(),
-        			info.getDeviceName(),
+        			info.getDisplayName(),
         			true);  // true暫定
         }
         // 詳細項目の有無のデータを判定してセットする.
         for (int i = 0; i < itemList.size(); i++) {
         	List<String> factorySubItemCodeList = CollectorItemCodeFactory.getSubItemCode(
         			collectorItemInfo.getItemCodeForCollector(i));
-        	String deviceName = collectorItemInfo.getDeviceNameForCollector(i);
+        	String displayName = collectorItemInfo.getDisplayNameForCollector(i);
         	
         	boolean a = true;
         	
@@ -233,7 +232,7 @@ public class RecordGraphView extends ScopeListBaseView {
         			boolean c = false;  // 内訳項目毎の有無のフラグ.
         			loop2: for (int n = 0; n < collectorItemInfo.getItemNumForCollector(); n++) { // 収集itemCode数分だけチェックする.
         				if (collectorItemInfo.getItemCodeForCollector(n).equals(factorySubItemCodeList.get(m).toString())) {
-        					if (deviceName.equals(collectorItemInfo.getDeviceNameForCollector(n))) {
+        					if (displayName.equals(collectorItemInfo.getDisplayNameForCollector(n))) {
         						c = true; // 必要項目が見つかった場合.
         						break loop2;
         					}
@@ -262,7 +261,8 @@ public class RecordGraphView extends ScopeListBaseView {
         				i,
         				info.getItemCode(),
         				"NonDisplay",	// 初期状態は非表示.スコープ代表値以外は条件により表示されない場合があるので不適.ただ代表値にしない.
-        				info.getDeviceName(),
+        				info.getDisplayName(),
+        				"FormLine",
         				true);	// for test.
         	} // for
         } // if
@@ -394,8 +394,9 @@ public class RecordGraphView extends ScopeListBaseView {
     		
     		for (int i = 0; i < graphNum; i++) {
     			String itemCode =  collectorItemInfo.getItemCode(i);
-    			String deviceName = collectorItemInfo.getDeviceName(i);
+    			String displayName = collectorItemInfo.getDisplayName(i);
     			String displayType =  collectorItemInfo.getDisplayType(i);
+    			String displayForm =  collectorItemInfo.getDisplayForm(i);
     			
     			int graphType = GraphProperty.INVISIBLE;
     			//　FIXME 定数クラスに変更の必要
@@ -409,12 +410,20 @@ public class RecordGraphView extends ScopeListBaseView {
     				graphType = GraphProperty.TYPE3;
     			}
     			
+    			int graphForm = GraphProperty.FORM1;
+    			//　FIXME 定数クラスに変更の必要
+    			if (displayForm.equals("FormLine")) {
+    				graphForm = GraphProperty.FORM1;
+    			} else if (displayForm.equals("FormStackArea")) {
+    				graphForm = GraphProperty.FORM2;
+    			}
+    			
     			Date startDate = collectorInfo.getGraphStartTime();
     			Date endDate = collectorInfo.getGraphEndTime();
     			
     			// 各グラフを表示する
-    			graphHolderComposite.redrawGraph(i, facilityId, itemCode, deviceName, graphType, startDate, endDate
-    					,isXRangeAuto, graphPlotNum);
+    			graphHolderComposite.redrawGraph(i, facilityId, itemCode, displayName, graphType, graphForm,
+    					startDate, endDate ,isXRangeAuto, graphPlotNum);
     			
 //    			graphComposite.addGraph(
 //    					i,
@@ -452,192 +461,6 @@ public class RecordGraphView extends ScopeListBaseView {
     	
     }
     
-    private void setCollector(String itemCode, String displayType, int interval, String facilityId) {
-    	// collectorIdの指定
-    	String collectorId = collectorProperty.getCollectorData().getCollectorID();
-    	// facility情報の指定
-    	String[] facilityIdList;
-    	
-    	if (collectorInfo.getSubScopeNum() > 0 && displayType.equals("SubScope")) {     
-    		facilityIdList = new String[collectorInfo.getSubScopeNum()];
-    		
-    		for (int i = 0 ; i < collectorInfo.getSubScopeNum(); i++) {
-    			facilityIdList[i] = collectorInfo.getSubScopeFacilityId(i);
-    		} 
-    	} else {
-    		facilityIdList = new String[1];
-    		facilityIdList[0] = facilityId;
-    	}
-    	
-    	List<CollectorItemInfo> itemList = collectorProperty.getItemList();
-    	CollectorItemInfo[] itemInfoArray = new CollectorItemInfo[itemList.size()];
-    	itemList.toArray(itemInfoArray);
-		
-    	Date startDate = collectorInfo.getGraphStartTime();
-    	Date endDate = collectorInfo.getGraphEndTime();
-	
-		// 自動グラフ表示無期限収集対応(設定されていた箇所が切り詰められた場合)
-		Date nowDate = new Date();		
-		if (collectorInfo.getGraphStartTime().before(collectorInfo.getCollectStartTime())) { // グラフ表示時刻 ＜ 収集開始時刻
-			startDate = collectorInfo.getCollectStartTime();
-			endDate = new Date(startDate.getTime() + collectorInfo.getInterval() * 1000 * GraphConstant.REALTIME_GRAPH_MAX_PLOT);  
-			if (endDate.after(nowDate)) { // グラフ表示終了時刻が現在時刻をすぎている場合
-				endDate = nowDate;
-			} 
-		}
-			
-//    	// itemCodeとdeviceIndexを手がかりにしてitemIdのリストを作成する.
-//    	List<String> ItemCodeCheckList = null;
-//    	
-//    	if (displayType.equals("Detail")) {
-//    		// 順序はfactoryにあくまで合わせる。(グラフ表示も)
-//    		ItemCodeCheckList = CollectorItemCodeFactory.getSubItemCode(itemCode);
-//    	} else {
-//    		ItemCodeCheckList = new ArrayList<String>();
-//    		ItemCodeCheckList.add(itemCode); // スコープ代表値とサブスコープ代表値では、下位のitemCodeはない.
-//    	}
-//    	
-//    	// itemIdを格納する配列を用意する.
-//    	int[] collectorItemIdList = new int[ItemCodeCheckList.size()];	// 配列とする現行仕様を見直すかはあとで検討。
-//    	// 収集IDが集めた項目数(itemCode数にdeviceIndexを加味した数.
-//    	int collectorItemNum = collectorItemInfo.getItemNumForCollector();
-//    	
-//    	// 各itemCodeごとにチェックする.
-//    	loop1: for (int m = 0; m < ItemCodeCheckList.size() ; m++) {
-//    		boolean found = false;  // 内訳項目毎の有無のフラグ.
-//    		// itemCodeとdeviceIndexをキーにしたときのitemIdを取得する.
-//    		loop2: for (int n = 0; n < collectorItemNum; n++) { // 収集itemCode数分だけチェックする.
-//    			// まずはitemCodeレベルでチェックする.
-//    			if (collectorItemInfo.getItemCodeForCollector(n).equals(ItemCodeCheckList.get(m).toString())) {
-//    				// itemCodeが一致したら次にdeviceIndexをチェックする.
-//    				if (deviceIndex.equals(collectorItemInfo.getIndexForCollector(n))) {
-//    					collectorItemIdList[m] = n;
-//    					found = true;
-//    					break loop2;	// 必要項目が見つかった場合.
-//    				}
-//    			}
-//    		}
-//    		if (! found) {
-//    			break loop1;
-//    		}
-//    	}
-    	
-    	// 1つのグラフのための必要データをセットしている.
-    	// collectorItemIdList
-    	//        詳細表示の場合は、複数になる。それ以外はひとつである。ただ、いずれもdeviceIndexが
-    	//        正しい必要があるので注意.単にitemCodeだけみると先頭デバイスを表示してしまう.
-//    	this.drawGraph1Test(collectorId, collectorItemIdList, facilityIdList, startDate, endDate, displayType);
-//    	this.drawGraph1Test(collectorId, itemInfoArray, facilityIdList, startDate, endDate, displayType);
-
-    	
-//    	isRequestCollectorToRun = true;
-    }
-    
-//    /**
-//     * グラフを描画する。
-//     * 
-//     * @param collectorId 収集ID
-//     * @param collectorItemIdList 収集項目のリスト
-//     * @param facilityIdList ファシリティIDのリスト
-//     * @param startDate 収集開始時刻
-//     * @param endDate 収集終了時刻
-//     * @param displayType 表示種別
-//     */
-//    public synchronized void drawGraph1Test(
-//    		String collectorId,
-//    		CollectorItemInfo[] collectorItemInfoList,
-//    		String[] facilityIdList,
-//    		Date startDate,
-//    		Date endDate,
-//    		String displayType) {
-//    	
-//    	// マネージャからデータを取得
-//    	RecordController controller = RecordController.getInstance();
-//    	// マネージャとの接続に失敗した場合はエラーダイアログを表示
-//    	if (controller == null) {
-//    		return;
-//    	}
-//    	
-//    	// 全グラフ共通
-//    	CollectedDataSet dataSet = controller.getRecordCollectedData(
-//    			collectorId, facilityIdList, collectorItemInfoList, startDate, endDate);
-//    	
-//    	// 性能データの取得に失敗した場合はエラーダイアログを表示
-//    	if (dataSet == null) {
-//    		return;
-//    	}
-//    	
-//    	
-//    	// ここで作成するデータはあくまで1つのグラフ用のもの。頭を混乱させてはいけない。
-//    	
-//    	int counter = 0;
-//    	
-//    	if (displayType.equals("SelectedScope")) {
-//    		// facilityはひとつ。線もひとつ。
-//    		// partialのみ取得。サブスコープには使えないので注意
-//    		counter = 1;
-//    	} else if (displayType.equals("SubScope")) {
-//    		counter = collectorInfo.getSubScopeNum();
-//    	} else {
-//    		counter = collectorItemInfoList.length;
-//    	}
-//    	
-//    	
-//    	int graphDotNum = 0;
-//    	
-//    	if (displayType.equals("SelectedScope") || displayType.equals("Detail")) {
-//    		for(int i=0; i < counter; i++){
-//    			List dataListForCheck = dataSet.getCollectedDataList(facilityIdList[0], collectorItemInfoList[i]);
-//    		}
-//    	} else {
-//    		for(int i=0; i < counter; i++){
-//    			List dataListForCheck = dataSet.getCollectedDataList(facilityIdList[i], collectorItemInfoList[0]);
-//    		}
-//    	}
-//    	
-//    	List dataListForCheck = dataSet.getCollectedDataList(facilityIdList[0], collectorItemInfoList[0]);
-//    	graphDotNum = dataListForCheck.size();
-//    	
-//        // 線を1本ずつ完成させていくので、配列で保持しておく。マネージャ側の仕様の見直しが必要とおもわれる。
-//    	double[] sumOfDataInfoValueSum = new double[graphDotNum]; // = 0.0D;
-//    	
-//    	for (int i = 0; i < counter; i++){
-//    		List dataList= null;
-//    		
-//    		// 詳細表示では値を足していくので
-//    		if (displayType.equals("Detail")) {
-//    			dataList = dataSet.getCollectedDataList(facilityIdList[0], collectorItemInfoList[i]);
-//    		} else {
-//    			dataList = dataSet.getCollectedDataList(facilityIdList[i], collectorItemInfoList[0]);
-//    		}
-//    		
-//    		if (dataList.size() != 0) { // 収集中のグラフ表示ではマネージャから値を取得できていない場合もあるため
-//    			double dataInfoValue = 0.0D;
-//    			for(int j=0; j < dataList.size(); j++){
-//    				CollectedDataInfo dataInfo = (CollectedDataInfo) dataList.get(j);
-//    				
-//    				if (!Double.isNaN(dataInfo.getValue())) {
-//    					if (dataInfo.getValue() >= 0.0) {
-//    						
-//    						if (displayType.equals("SelectedScope") || displayType.equals("SubScope")) {
-//    							dataInfoValue = dataInfo.getValue(); 
-//    						} else if (displayType.equals("Detail")) {
-//    							// 値を積みあげる。
-//    							sumOfDataInfoValueSum[j] = sumOfDataInfoValueSum[j] + dataInfo.getValue();
-//    							dataInfoValue = sumOfDataInfoValueSum[j]; 
-//    						}
-//    						if (!Double.isNaN(dataInfoValue)) {
-//    							graphComposite.m_timeseries[i].addOrUpdate(new Second(dataInfo.getDate()),dataInfoValue);
-//    						}
-//    					}
-//    				}
-//    			} // for
-//    		} else {
-//    		} // else
-//    	} // for
-//    } // if
-
-
     
 	/**
 	 * 収集IDをプリファレンスから取得し、collectorPropertyを取得するメソッド
@@ -668,23 +491,8 @@ public class RecordGraphView extends ScopeListBaseView {
 		pathLabel.setText(Messages.getString("SCOPE") + " : " + perfPrePage.getPathLabel());
 	}
 	
-	/**
-	 * プリファレンスに情報をセットするメソッド
-	 *
-	 */
-	private void setPreference() {
-		perfPrePage.setCollectorId(this.collectorProperty.getCollectorData().getCollectorID());
-		
-		String pathLabelSplit[] = this.getPathLabel().getText().split(" "); // スコープのパスだけを抽出
-		perfPrePage.setPathLabel(pathLabelSplit[2]);
-		perfPrePage.setRealtimeCollectorInfo(this.collectorInfo);
-		perfPrePage.setRealtimeCollectorItemInfo(this.collectorItemInfo);
-		
-		perfPrePage.savePreference();	// プリファレンスページのデータを保存する
-		
-	}
 	
-    /**
+	/**
      * ビューのアクションの有効/無効を設定
      * 
      * @param type 選択種別
