@@ -56,26 +56,25 @@ public class CalculatedDataDAO {
 	 *
 	 * 
 	 * @param collectorID 収集ID
-	 * @param collectMethod 収集方法
-	 * @param itemCode　収集項目コード
-	 * @param deviceName  デバイス名
+	 * @param itemCode 収集項目コード
+	 * @param displayName リポジトリ表示名
 	 * @param facilityID ファシリティID
 	 * @param startDate (検索の）開始時刻
-	 * @param stopDate　（検索の）終了時刻
+	 * @param stopDate （検索の）終了時刻
 	 * @return　収集された性能値のコレクション
 	 * @throws EJBException
 	 */
 	public List<CollectedDataInfo> select(
 			String collectorID, 
-			String collectMethod,
+//			String collectMethod,
 			String itemCode,
-			String deviceName,
+			String displayName,
 			String facilityID,
 			Date startDate,
 			Date stopDate )
 	throws EJBException{
 		
-		m_log.debug("select() start :" + collectorID + " " + itemCode + " " + deviceName + " " + facilityID);
+		m_log.debug("select() start :" + collectorID + " " + itemCode + " " + displayName + " " + facilityID);
 		ArrayList<CollectedDataInfo> ret = new ArrayList<CollectedDataInfo>();  // DBから取得したデータを格納するリスト
 		
 		Connection conn = null;
@@ -85,11 +84,11 @@ public class CalculatedDataDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
 			//		SQL文の作成
-			String sql = "SELECT * FROM CC_CALCULATED_DATA WHERE " + 
+			String sql = "SELECT DATE_TIME,VALUE FROM CC_CALCULATED_DATA WHERE " + 
 			"COLLECTORID=? AND " +
-			"COLLECT_METHOD=? AND " +
+//			"COLLECT_METHOD=? AND " +
 			"ITEM_CODE=? AND " + 
-			"DEVICE_NAME=? AND " + 
+			"DISPLAY_NAME=? AND " + 
 			"FACILITYID=? AND " + 
 			"DATE_TIME BETWEEN ? AND ?" +
 			"ORDER BY DATE_TIME";
@@ -101,12 +100,11 @@ public class CalculatedDataDAO {
 			Timestamp stop  = new Timestamp(stopDate.getTime());
 			
 			stmt.setString(1, collectorID);
-			stmt.setString(2, collectMethod);
-			stmt.setString(3, itemCode);
-			stmt.setString(4, deviceName);
-			stmt.setString(5, facilityID);
-			stmt.setTimestamp(6, start);
-			stmt.setTimestamp(7, stop);
+			stmt.setString(2, itemCode);
+			stmt.setString(3, displayName);
+			stmt.setString(4, facilityID);
+			stmt.setTimestamp(5, start);
+			stmt.setTimestamp(6, stop);
 			
 			res = stmt.executeQuery();
 			
@@ -114,9 +112,9 @@ public class CalculatedDataDAO {
 				Date d = new Date(res.getTimestamp("DATE_TIME").getTime());
 				CollectedDataInfo data;
 				if(res.getObject("VALUE") != null){
-					data = new CollectedDataInfo(facilityID, itemCode, deviceName, collectMethod, d, res.getDouble("VALUE"));
+					data = new CollectedDataInfo(facilityID, itemCode, displayName, d, res.getDouble("VALUE"));
 				} else {
-					data = new CollectedDataInfo(facilityID, itemCode, deviceName, collectMethod, d, Double.NaN);
+					data = new CollectedDataInfo(facilityID, itemCode, displayName, d, Double.NaN);
 				}
 				
 //				CollectedDataInfo data = new CollectedDataInfo(facilityID, itemCode, deviceName, collectMethod);
@@ -150,7 +148,7 @@ public class CalculatedDataDAO {
 				throw new EJBException(e1.getMessage());
 			}
 		}	
-		m_log.debug("select() end   :" + collectorID + " " + itemCode + " " + deviceName + " " + facilityID);
+		m_log.debug("select() end   :" + collectorID + " " + itemCode + " " + displayName + " " + facilityID);
 		
 		return ret;
 	}
@@ -184,7 +182,7 @@ public class CalculatedDataDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 
 			// SQL文の作成
-			String sql = "SELECT date_time, item_code, device_name, collect_method, value FROM cc_calculated_data WHERE collectorid = ? AND facilityid = ? AND date_time >= ? AND date_time < ?";
+			String sql = "SELECT date_time, item_code, display_name, value FROM cc_calculated_data WHERE collectorid = ? AND facilityid = ? AND date_time >= ? AND date_time < ?";
 
 			// SQL文発行準備
 			stmt = conn.prepareStatement(sql);
@@ -202,7 +200,7 @@ public class CalculatedDataDAO {
 			// 配列への性能値の格納
 			while (res.next()) {
 				if (res.getObject("VALUE") != null) {
-					ret.add(new CollectedDataInfo(facilityID, res.getString("ITEM_CODE"), res.getString("DEVICE_NAME"), res.getString("COLLECT_METHOD"), res.getTimestamp("DATE_TIME"), res.getDouble("VALUE")));
+					ret.add(new CollectedDataInfo(facilityID, res.getString("ITEM_CODE"), res.getString("DISPLAY_NAME"), res.getTimestamp("DATE_TIME"), res.getDouble("VALUE")));
 				}
 			}
 		} catch (SQLException e) {
@@ -290,9 +288,8 @@ public class CalculatedDataDAO {
 	throws EJBException{
 		
 		m_log.debug("insert() start : " + collectorID +
-				" " + data.getCollectMethod() +
 				" " + data.getItemCode() +
-				" " + data.getDeviceName() +
+				" " + data.getDisplayName() +
 				" " + data.getFacilityId());
 		
 		Connection conn = null;
@@ -304,27 +301,25 @@ public class CalculatedDataDAO {
 			//SQL文の定義
 			String sql = "INSERT INTO CC_CALCULATED_DATA " +
 			"(COLLECTORID, " +
-			"COLLECT_METHOD, " +
 			"ITEM_CODE, " +
-			"DEVICE_NAME, " +
+			"DISPLAY_NAME, " +
 			"DATE_TIME, " +
 			"FACILITYID, " +
 			"VALUE) " +
-			"values (?,?,?,?,?,?,?);";
+			"values (?,?,?,?,?,?);";
 			
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1, collectorID);
-			stmt.setString(2, data.getCollectMethod());
-			stmt.setString(3, data.getItemCode());
-			stmt.setString(4, data.getDeviceName());
-			stmt.setTimestamp(5, time);
-			stmt.setString(6, data.getFacilityId());
+			stmt.setString(2, data.getItemCode());
+			stmt.setString(3, data.getDisplayName());
+			stmt.setTimestamp(4, time);
+			stmt.setString(5, data.getFacilityId());
 			if(Double.isNaN(data.getValue())){
-				stmt.setNull(7, Types.DOUBLE);  // 性能値が算出不能だった場合はnullを書き込む
+				stmt.setNull(6, Types.DOUBLE);  // 性能値が算出不能だった場合はnullを書き込む
 			} else {
-				stmt.setDouble(7, data.getValue());
+				stmt.setDouble(6, data.getValue());
 			}
 			
 			int row = stmt.executeUpdate();
@@ -350,9 +345,8 @@ public class CalculatedDataDAO {
 				throw new EJBException(e1.getMessage());
 			}
 			m_log.debug("insert() end   : " + collectorID +
-					" " + data.getCollectMethod() +
 					" " + data.getItemCode() +
-					" " + data.getDeviceName() +
+					" " + data.getDisplayName() +
 					" " + data.getFacilityId());
 		}	
 	}
@@ -413,71 +407,68 @@ public class CalculatedDataDAO {
 	 * @return 再カウントした結果の収集件数（失敗した場合は負数が返る）
 	 * @throws EJBException
 	 */
-	public int recountFromDB(String collectorID)throws EJBException{
-		
-		m_log.debug("recountFromDB() start :" + collectorID );
-		
-		Connection conn = null;
-		PreparedStatement stmt =null;
-		ResultSet res = null; 
-		int ret = -1;
-		try {
-			conn = ConnectionManager.getConnectionManager().getConnection();
+		public int recountFromDB(String collectorID)throws EJBException{
 			
-			// 指定された収集IDの任意の1件を取り出し、そのitem_codeとfacilityidを取得する。
-			final String preQuery = "SELECT item_code, facilityid FROM cc_calculated_data" + 
-									" where collectorid = ? LIMIT 1";
-			stmt = conn.prepareStatement(preQuery);
-			stmt.setString(1, collectorID);
-			res = stmt.executeQuery();
-			if (!res.next()) {
-				// 1件もとれない（処理に失敗した）場合は負数を返す
-				return -1;
-			}
-			final String item_code = res.getString(1);
-			final String facilityid = res.getString(2);
+			m_log.debug("recountFromDB() start :" + collectorID );
 			
-			// 指定された収集IDで何回収集が行われたかを取得する。
-			// 収集の開始から現時点に至るまでに、item_code/facilityidが変わることは
-			// ありえないことと、同一時間帯にitem_code（収集対象の情報種類）とfacilityid
-			// （収集対象ノード）の数だけ重複して情報を収集することから、ある特定のitem_code
-			// とfacilityidに絞ってその件数を数えれば、収集を実施した回数がわかることになる。
-			final String cntQuery = "SELECT COUNT(*) FROM cc_calculated_data " +
-				"WHERE collectorid = ? AND item_code = ? AND facilityid = ?";
-			stmt = conn.prepareStatement(cntQuery);
-			stmt.setString(1, collectorID);
-			stmt.setString(2, item_code);
-			stmt.setString(3, facilityid);
-			res = stmt.executeQuery();
-			if (!res.next()) {
-				// 1件もとれない（処理に失敗した）場合は負数を返す
-				return -1;
-			}
-			ret = res.getInt(1);
-			
-		} catch (SQLException e) {
-			m_log.error("recountFromDB() error :" + collectorID + " EJBException ",e);
-			throw new EJBException(e.getMessage());
-		}  finally{
-			
-			//コネクション、結果セット、プリペアドステートメントのクロース
+			Connection conn = null;
+			PreparedStatement stmt =null;
+			ResultSet res = null; 
+			int ret = -1;
 			try {
-				if(res != null){
-					res.close();
+				conn = ConnectionManager.getConnectionManager().getConnection();
+				
+				// 指定された収集IDの任意の1件を取り出し、そのitem_codeとfacilityidを取得する。
+				final String preQuery = "SELECT item_code, facilityid FROM cc_calcuated_data" + 
+										" where collectorid = " + collectorID + " LIMIT 1";
+				stmt = conn.prepareStatement(preQuery);
+				res = stmt.executeQuery();
+				if (!res.next()) {
+					return -1;
 				}
-				if(stmt != null){
-					stmt.close();
+				final String item_code = res.getString(1);
+				final String facilityid = res.getString(2);
+				
+				// 指定された収集IDで何回収集が行われたかを取得する。
+				// 収集の開始から現時点に至るまでに、item_code/facilityidが変わることは
+				// ありえないことと、同一時間帯にitem_code（収集対象の情報種類）とfacilityid
+				// （収集対象ノード）の数だけ重複して情報を収集することから、ある特定のitem_code
+				// とfacilityidに絞ってその件数を数えれば、収集を実施した回数がわかることになる。
+				final String cntQuery = "SELECT COUNT(*) FROM cc_calculated_data " +
+										"WHERE collectorid = " + collectorID +
+										" AND item_code = " + item_code +
+										" AND facilityid = " + facilityid;
+				stmt = conn.prepareStatement(cntQuery);
+				res = stmt.executeQuery();
+				if (!res.next()) {
+					// 1件もとれない場合は？
+					return -1;
 				}
-				if(conn != null){
-					conn.close();
+				ret = res.getInt(1);
+				
+			} catch (SQLException e) {
+				m_log.error("recountFromDB() error :" + collectorID + " EJBException ",e);
+				throw new EJBException(e.getMessage());
+			}  finally{
+				
+				//コネクション、結果セット、プリペアドステートメントのクロース
+				try {
+					if(res != null){
+						res.close();
+					}
+					if(stmt != null){
+						stmt.close();
+					}
+					if(conn != null){
+						conn.close();
+					}
+				} catch (SQLException e1) {
+					m_log.error("recountFromDB() error :" + collectorID + " EJBException ");
+					throw new EJBException(e1.getMessage());
 				}
-			} catch (SQLException e1) {
-				m_log.error("recountFromDB() error :" + collectorID + " EJBException ");
-				throw new EJBException(e1.getMessage());
+				m_log.debug("recountFromDB() end   :" + collectorID + " ");
 			}
-			m_log.debug("recountFromDB() end   :" + collectorID + " ");
+			
+			return ret;
 		}
-		
-		return ret;
 	}
-}
