@@ -23,6 +23,7 @@ import java.util.Date;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
+import java.util.Set;
 import java.util.TreeSet;
 
 import javax.ejb.CreateException;
@@ -47,6 +48,7 @@ import com.clustercontrol.bean.EndStatusConstant;
 import com.clustercontrol.bean.FacilityConstant;
 import com.clustercontrol.bean.FacilityTreeItem;
 import com.clustercontrol.bean.HinemosModuleConstant;
+import com.clustercontrol.bean.PollerProtocolConstant;
 import com.clustercontrol.performance.bean.EventCode;
 import com.clustercontrol.performance.bean.QuartzConstant;
 import com.clustercontrol.performance.bean.ScopeTree;
@@ -66,23 +68,28 @@ import com.clustercontrol.performance.ejb.bmp.CollectorStatusLocal;
 import com.clustercontrol.performance.ejb.bmp.CollectorStatusPK;
 import com.clustercontrol.performance.ejb.bmp.CollectorStatusUtil;
 import com.clustercontrol.performance.ejb.bmp.RecordCollectorData;
+import com.clustercontrol.performance.monitor.ejb.entity.CollectorCategoryCollectMstLocal;
+import com.clustercontrol.performance.monitor.ejb.entity.CollectorCategoryCollectMstPK;
+import com.clustercontrol.performance.monitor.ejb.entity.CollectorCategoryCollectMstUtil;
 import com.clustercontrol.performance.monitor.ejb.entity.CollectorDeviceInfoData;
 import com.clustercontrol.performance.monitor.ejb.entity.CollectorDeviceInfoLocal;
 import com.clustercontrol.performance.monitor.ejb.entity.CollectorDeviceInfoUtil;
+import com.clustercontrol.performance.monitor.ejb.entity.CollectorItemCodeMstLocal;
+import com.clustercontrol.performance.monitor.ejb.entity.CollectorItemCodeMstUtil;
+import com.clustercontrol.performance.monitor.ejb.entity.CollectorPollingMstLocal;
+import com.clustercontrol.performance.monitor.ejb.entity.CollectorPollingMstUtil;
 import com.clustercontrol.performance.monitor.ejb.entity.CollectorScopeRelationLocal;
 import com.clustercontrol.performance.monitor.ejb.entity.CollectorScopeRelationUtil;
 import com.clustercontrol.performance.monitor.ejb.entity.CollectorScopeSnapLocal;
 import com.clustercontrol.performance.monitor.ejb.entity.CollectorScopeSnapUtil;
-import com.clustercontrol.performance.monitor.ejb.entity.CollectorSnmpMstLocal;
-import com.clustercontrol.performance.monitor.ejb.entity.CollectorSnmpMstUtil;
 import com.clustercontrol.performance.monitor.ejb.entity.MonitorPerfInfoLocal;
 import com.clustercontrol.performance.monitor.ejb.entity.MonitorPerfInfoUtil;
 import com.clustercontrol.poller.CollectorAlreadyExistException;
 import com.clustercontrol.poller.FacilityNotFoundException;
 import com.clustercontrol.poller.NotInitializedException;
-import com.clustercontrol.poller.snmp.PollingInterval;
-import com.clustercontrol.poller.snmp.SnmpPoller;
-import com.clustercontrol.poller.snmp.SnmpPollerManager;
+import com.clustercontrol.poller.PollerManager;
+import com.clustercontrol.poller.PollingController;
+import com.clustercontrol.poller.PollingInterval;
 import com.clustercontrol.sharedtable.DataTableNotFoundException;
 import com.clustercontrol.sharedtable.SharedTable;
 import com.clustercontrol.util.apllog.AplLogger;
@@ -119,7 +126,7 @@ public class CollectorBean implements EntityBean {
 	protected static Log m_log = LogFactory.getLog(CollectorBean.class);
 	
 	public final static String SHARED_TABLE_JNDI_NAME = "SharedTable";
-	public final static String POLLER_MANAGER_JNDI_NAME = "SnmpPollerManager";
+	public final static String POLLER_MANAGER_JNDI_NAME = "PollerManager";
 	
 	// 計算済み性能値を格納するDBへのアクセスオブジェクト
 //	private CalculatedDataDAO m_dao;
@@ -230,6 +237,7 @@ public class CollectorBean implements EntityBean {
 							collectorID, 
 							deviceData.getFacilityId(), 
 							deviceData.getDeviceName(), 
+							deviceData.getDisplayName(),
 							deviceData.getIndex(), 
 							deviceData.getDeviceId(), 
 							deviceData.getDeviceType());
@@ -551,7 +559,7 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * SNMPポーラーを起動する
+	 * ポーラーを起動する
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="local" 
@@ -564,7 +572,7 @@ public class CollectorBean implements EntityBean {
 			return;
 		}
 
-		// SNMP収集値の共有テーブルをルックアップ
+		// SharedTableをルックアップ
 		try {
 			InitialContext ctx = new InitialContext();
 			SharedTable sst = (SharedTable)ctx.lookup(SHARED_TABLE_JNDI_NAME);
@@ -573,19 +581,51 @@ public class CollectorBean implements EntityBean {
 			String[] nodeIDList = scopeTree.getNodeIDList(facilityID);
 			for(int i=0; i<nodeIDList.length; i++){
 				// ポーリング対象のOIDを設定
-				TreeSet<String> oids = new TreeSet<String>();
+				HashMap<String, TreeSet<String>> treeSetMap = new HashMap<String, TreeSet<String>>();
 				for(int j=0; j<items.length; j++){
 					String platformId = Repository.getPlatformId(nodeIDList[i]);
+					String subPlatformId = Repository.getSubPlatformId(nodeIDList[i]);
 					
-					Collection<CollectorSnmpMstLocal> beans = 
-						CollectorSnmpMstUtil.getLocalHome().findByPlatformIdAndItemCode(
-								platformId, 
+					// ItemCodeからItemCodeMstのデータを取得
+					CollectorItemCodeMstLocal itemCodeMst = 
+						CollectorItemCodeMstUtil.getLocalHome().findByPrimaryKey(items[j].getItemCode());
+					
+					CollectorCategoryCollectMstPK pk = new CollectorCategoryCollectMstPK(
+							platformId,
+							subPlatformId,
+							itemCodeMst.getCategoryCode()
+					);
+					
+					CollectorCategoryCollectMstLocal collect = 
+						CollectorCategoryCollectMstUtil.getLocalHome().findByPrimaryKey(pk);
+					
+					// collectMethod, platformId, subPlatformId, itemoCodeがマッチするポーリング情報を取得
+					Collection<CollectorPollingMstLocal> pollingMstBeans = 
+						CollectorPollingMstUtil.getLocalHome().
+						findByCollectMethodAndPlatformIdAndSubPlatformIdAndItemCode(
+								collect.getCollectMethod(),
+								platformId,
+								subPlatformId,
 								items[j].getItemCode());
 					
-					Iterator<CollectorSnmpMstLocal> itr = beans.iterator();
+					Iterator<CollectorPollingMstLocal> itrPolling = pollingMstBeans.iterator();
 
-					while(itr.hasNext()){
-						oids.add(itr.next().getPollingOid());
+					while(itrPolling.hasNext()){
+						CollectorPollingMstLocal pollingLocal = itrPolling.next();
+						
+						TreeSet<String> treeSet = treeSetMap.get(pollingLocal.getCollectMethod());
+						
+						// TreeSetが存在しない場合は新規作成し、treeSetMapに追加
+						if(treeSet == null || treeSet.size() == 0){
+							treeSet = new TreeSet<String>();
+							treeSetMap.put(pollingLocal.getCollectMethod(), treeSet);
+							
+							m_log.debug("startPoller create treeSetMap key : " + pollingLocal.getCollectMethod());
+						}
+						// 値を追加
+						treeSet.add(pollingLocal.getPollingTarget());
+						
+						m_log.debug("startPoller treeSet add EntryKey : " + pollingLocal.getPollingTarget());
 					}
 				}
 
@@ -598,16 +638,33 @@ public class CollectorBean implements EntityBean {
 
 				// ポーラを生成する
 				Object obj = ctx.lookup(POLLER_MANAGER_JNDI_NAME);
-				SnmpPollerManager manager = 
-					(SnmpPollerManager)PortableRemoteObject.narrow(obj, SnmpPollerManager.class);
+				PollerManager manager = 
+					(PollerManager)PortableRemoteObject.narrow(obj, PollerManager.class);
 
 				// ポーラを取得
-				SnmpPoller poller = manager.getPoller(HinemosModuleConstant.PERFORMANCE, nodeIDList[i]);
+				PollingController poller = manager.getPoller(HinemosModuleConstant.PERFORMANCE, nodeIDList[i]);
 				// ない場合は生成する
 				if(poller == null){
 					poller = manager.createPoller(HinemosModuleConstant.PERFORMANCE, nodeIDList[i], false, HinemosModuleConstant.PERFORMANCE, nodeIDList[i]);
 				}
-				poller.startPolling(collectorID, intervalSec, new ArrayList<String>(oids));
+				
+				// HashMap<String, TreeSet<String>>からHashMap<String, ArrayList<String>>へ詰め替えを行う
+				HashMap<String, List<String>> pollingMap = new HashMap<String, List<String>>();
+				
+				Set<String> keySet = treeSetMap.keySet();
+				Iterator<String> itrKeySet = keySet.iterator();
+				
+				while(itrKeySet.hasNext()){
+					String collectMethod = itrKeySet.next();
+					
+					m_log.debug("collectMethod : " + collectMethod);
+					
+					pollingMap.put(collectMethod, new ArrayList<String>(treeSetMap.get(collectMethod)));
+				}
+				
+				m_log.debug("startPoller map size : " + pollingMap.size());
+				
+				poller.startPolling(collectorID, intervalSec, pollingMap);
 			}
 		} catch (NotInitializedException e) {
 			m_log.error(e.getMessage(), e);
@@ -745,11 +802,11 @@ public class CollectorBean implements EntityBean {
 			for(int i=0; i<nodeIDList.length; i++){
 				// ポーラを生成する
 				Object obj = ctx.lookup(POLLER_MANAGER_JNDI_NAME);
-				SnmpPollerManager manager = 
-					(SnmpPollerManager)PortableRemoteObject.narrow(obj, SnmpPollerManager.class);
+				PollerManager manager = 
+					(PollerManager)PortableRemoteObject.narrow(obj, PollerManager.class);
 
 				// ポーラを取得し停止処理を実行
-				SnmpPoller poller = manager.getPoller(HinemosModuleConstant.PERFORMANCE, nodeIDList[i]);
+				PollingController poller = manager.getPoller(HinemosModuleConstant.PERFORMANCE, nodeIDList[i]);
 				if(poller != null){
 					poller.stopPolling(collectorID);
 				}
@@ -776,7 +833,7 @@ public class CollectorBean implements EntityBean {
 	 * @throws NamingException 
 	 */
 	private void scheduleJob() throws NamingException {
-		m_log.debug("scheduleJob() : Group : "  + QuartzConstant.GROUP_COLLECT + " : " + collectorID + " : " + intervalSec);
+		m_log.debug("scheduleJob()  Group : "  + QuartzConstant.GROUP_COLLECT + " : " + collectorID + " : " + intervalSec);
 		
 		//JobDetail作成
 		JobDetail job = new JobDetail(
@@ -801,73 +858,33 @@ public class CollectorBean implements EntityBean {
         	String cronString = PollingInterval.parseCronExpression(intervalSec);
 
         	cronString = "10 */10 * * * ? *";
-        	
-        	// Quartzのトリガ開始時刻
-        	// collector_profileのstart_dateは登録時のまま変更しない
-        	// 差分をとって計算する場合（最低２回はポーリングを行っている必要がある場合）に合わせて、計算開始時間を１監視間隔分遅らせる
-        	long currentTime = System.currentTimeMillis();
-        	long triggerStartTime = currentTime + intervalSec*1000;
-        	m_log.debug("scheduleJob() : currentTime : " + currentTime + "(" + new Date(currentTime) + ") at " + collectorID);
-        	m_log.debug("scheduleJob() : triggerStartTime : " + triggerStartTime + "(" + new Date(triggerStartTime) + ") at " + collectorID);
-        	
-        	// 収集間隔ごとに、cronStringの生成と、計算ロジックの実行タイミング調整（delayTime）をする
+
         	if(intervalSec < 60){  // 秒単位の場合(リアルタイム、実績収集)
-    			if(m_log.isDebugEnabled())
-    				m_log.debug("scheduleJob() : intervalSec < 60 at " + collectorID);
-
-        		
-        		int delayTimeUnder1min = QuartzConstant.getDelayTimeUnder1min();
+				int delayTimeUnder1min = QuartzConstant.getDelayTimeUnder1min();
 				cronString = delayTimeUnder1min + "/" + intervalSec + " * * * * ? *";
-	        	m_log.debug("scheduleJob() : delayTimeUnder1min : " + delayTimeUnder1min);
-				
-        		// 定期ポーリングから計算ロジックが走るまでの魔の時間(delayTime)に登録された場合は更にdelayTime分計算開始時間を遅らせる
-        		if ((triggerStartTime/1000 % intervalSec) <= (delayTimeUnder1min)){
-
-    				m_log.debug("scheduleJob() : (triggerStartTime/1000 % intervalSec) = " + (triggerStartTime/1000 % intervalSec));
-
-    				// 更新
-        			triggerStartTime = triggerStartTime + delayTimeUnder1min*1000;
-
-        			m_log.debug("scheduleJob() : update triggerStartTime : triggerStartTime + delayTimeUnder1min = "
-							+ triggerStartTime
-							+ "("
-							+ new Date(triggerStartTime) + ")");
-        		} 
-				
         	} else {
-    			if(m_log.isDebugEnabled())
-    				m_log.debug("scheduleJob() : intervalSec >= 60 at " + collectorID);
-
-        		int delayTimeOver1min = QuartzConstant.getDelayTimeOver1min();
+				int delayTimeOver1min = QuartzConstant.getDelayTimeOver1min();
         		if (60 <= intervalSec && intervalSec < 3600){  // 分単位の場合
 					cronString = delayTimeOver1min + " */" + intervalSec/60 + " * * * ? *";
         		} else if (3600 <= intervalSec){  // 時間単位の場合
         			cronString = delayTimeOver1min + " 0 */" + intervalSec/3600 + " * * ? *"; // ポーリングからdelayTime秒ずらして起動
         		} 
-            	m_log.debug("scheduleJob() : delayTimeOver1min : " + delayTimeOver1min);
         		
+        		// 差分をとって計算する場合（最低２回はポーリングを行っている必要がある場合）に合わせて、計算開始時間を１監視間隔分遅らせる
+        		startTime += intervalSec*1000;
+        		
+        		//m_log.info("*BEFORE* startTime = " + startTime);
         		// 定期ポーリングから計算ロジックが走るまでの魔の時間(delayTime)に登録された場合は更にdelayTime分計算開始時間を遅らせる
-        		if ((triggerStartTime/1000 % intervalSec) <= (delayTimeOver1min)){
-
-    				m_log.debug("scheduleJob() : (triggerStartTime/1000 % intervalSec) = " + (triggerStartTime/1000 % intervalSec));
-
-    				// 更新
-        			triggerStartTime = triggerStartTime + delayTimeOver1min*1000;
-        			
-    				m_log.debug("scheduleJob() : update triggerStartTime : triggerStartTime + delayTimeOver1min = "
-							+ triggerStartTime
-							+ "("
-							+ new Date(triggerStartTime) + ")");
+        		if ((startTime/1000 % intervalSec) <= (delayTimeOver1min)){
+        			//m_log.info("*in if 1* startTime = " + startTime);
+        			startTime += delayTimeOver1min*1000;
+        			//m_log.info("*in if 2* startTime = " + startTime);
         		} 
         	}
 			
 			cronTrigger.setCronExpression(cronString);
-			cronTrigger.setStartTime(new Date(triggerStartTime));
+			cronTrigger.setStartTime(new Date(startTime));
 			cronTrigger.setEndTime(new Date(stopTime));
-			
-			// CronTriggerの設定確認用
-			m_log.debug("scheduleJob() : " + cronTrigger.getExpressionSummary());
-			
 		} catch (ParseException e) {
 			m_log.error(e.getMessage(), e);
 		} catch (IllegalArgumentException e){
@@ -1098,20 +1115,20 @@ public class CollectorBean implements EntityBean {
 					String monitorTypeId = monInfoLocal.getMonitorTypeId();
 					String monitorId = monInfoLocal.getMonitorId();
 					String itemCode = monInfoLocal.getItemCode();
-					String deviceName = monInfoLocal.getDeviceName();
+					String displayName = monInfoLocal.getDisplayName();
 					
 					// 収集中の項目のうち監視対象項目を特定する
 					CollectorItemInfo cii = null;
 					
 					for(int i=0; i<items.length; i++){
-						if(itemCode.equals(items[i].getItemCode()) && deviceName.equals(items[i].getDeviceName())){
+						if(itemCode.equals(items[i].getItemCode()) && displayName.equals(items[i].getDisplayName())){
 							cii = items[i];
 						}
 					}
 					
 					// 対応する収集項目がない場合
 					if(cii == null){
-						m_log.error("Not match CollectorItem. (code:" + itemCode + ", device name:"+deviceName+")");
+						m_log.error("Not match CollectorItem. (code:" + itemCode + ", display name:"+displayName+")");
 						return;
 					}
 					
@@ -1243,8 +1260,8 @@ public class CollectorBean implements EntityBean {
 		
 		// デバイス情報を取得
 		List<CollectorDeviceInfoData> allDeviceList = new ArrayList<CollectorDeviceInfoData>();
-		// プラットフォーム情報を取得
-		HashMap<String, String> platformMap = null;
+		// プラットフォーム情報（サブプラットフォームID含む）を取得
+		HashMap<String, ArrayList<String>> platformMap = null;
 		if(collectorType == CollectorType.REALTIME || collectorType == CollectorType.MONITOR){
 			// リポジトリから取得
 			allDeviceList = new Repository().getDeviceList(facilityID);
@@ -1265,6 +1282,7 @@ public class CollectorBean implements EntityBean {
 									bean.getCollectorId(),
 									bean.getFacilityId(),
 									bean.getDeviceName(),
+									bean.getDisplayName(),
 									bean.getIndex(),
 									bean.getDeviceId(),
 									bean.getDeviceType()
@@ -1272,7 +1290,7 @@ public class CollectorBean implements EntityBean {
 				}
 			
 				// プラットフォームIDをDBから取得する
-				platformMap = new HashMap<String, String>();
+				platformMap = new HashMap<String, ArrayList<String>>();
 				Collection<CollectorScopeSnapLocal> col = CollectorScopeSnapUtil.getLocalHome().findByCollectorId(collectorID);
 			
 				Iterator<CollectorScopeSnapLocal> itr2 = col.iterator();
@@ -1281,7 +1299,10 @@ public class CollectorBean implements EntityBean {
 					
 					// bean.getFacilityType() が nodeの場合のみ、HashMapに詰める
 					if(bean.getFacilityType().equals(FacilityConstant.TYPE_NODE_STRING)) {
-						platformMap.put(bean.getFacilityId(), bean.getPlatformId());
+						ArrayList<String> platforms = new ArrayList<String>();
+						platforms.add(bean.getPlatformId());
+						platforms.add(bean.getSubPlatformId());
+						platformMap.put(bean.getFacilityId(), platforms);
 					}
 				}
 			} catch (FinderException e) {
@@ -1483,10 +1504,8 @@ public class CollectorBean implements EntityBean {
 	 */
 	public Date getStartDate() {
 		if(startTime != 0){
-			m_log.debug("getStartDate() start with not null: " + collectorID + " " + (new Date(startTime)).toString());
 			return new Date(startTime);
 		} else {
-			m_log.debug("getStartDate() start with null: " + collectorID);
 			return null;
 		}
 	}
@@ -1500,10 +1519,8 @@ public class CollectorBean implements EntityBean {
 	 */
 	public void setStartDate(Date startDate) {
 		if(startDate != null){
-			m_log.debug("setStartDate() start with not null: " + collectorID + " " + (new Date(startTime)).toString());
 			this.startTime = startDate.getTime();
 		} else {
-			m_log.debug("setStartDate() start with null: " + collectorID);
 			this.startTime = 0;
 		}
 	}
