@@ -17,12 +17,10 @@ package com.clustercontrol.performance.ejb.session;
 
 import java.rmi.RemoteException;
 import java.text.ParseException;
-import java.util.ArrayList;
 import java.util.Calendar;
 import java.util.Collection;
 import java.util.Date;
 import java.util.Iterator;
-import java.util.List;
 
 import javax.ejb.EJBException;
 import javax.ejb.FinderException;
@@ -44,7 +42,6 @@ import com.clustercontrol.performance.bean.QuartzConstant;
 import com.clustercontrol.performance.util.JNDIConnectionManager;
 import com.clustercontrol.performance.ejb.bmp.Collector;
 import com.clustercontrol.performance.ejb.bmp.CollectorHome;
-import com.clustercontrol.performance.ejb.bmp.CollectorPK;
 import com.clustercontrol.quartzmanager.util.QuartzUtil;
 import com.clustercontrol.quartzmanager.ejb.session.QuartzManager;
 import com.clustercontrol.util.apllog.AplLogger;
@@ -91,9 +88,6 @@ public class CollectorRunControllerBean implements SessionBean {
 	 *     unchecked="true"
 	 *     method-intf="Remote"
 	 *     
-	 * @ejb.transaction
-	 *     type="NotSupported"
-	 *     
 	 * @throws FinderException
 	 * @throws NamingException
 	 * @since 2.0.0
@@ -101,42 +95,6 @@ public class CollectorRunControllerBean implements SessionBean {
 	public void managePresavePeriod() throws FinderException, NamingException {
 		m_log.debug("managePresavePeriod() :  start");
 		
-		//無期限収集のcollectorIdリスト取得
-		ArrayList<CollectorPK> list = getPresaveCollectorList();
-		
-		//collectorId毎に定期削除処理を実行する
-		Iterator<CollectorPK> iterator = list.iterator();
-		while (iterator.hasNext()) {
-			CollectorPK pk = (CollectorPK) iterator.next();
-			m_log.debug("managePresavePeriod() :  do collectorId = " + pk.getCollectorID());
-			_managePresavePeriod(pk);
-		}
-		
-		m_log.debug("managePresavePeriod() :  end");
-	}
-
-	/**
-	 * 無期限収集のcollectorIdリスト取得
-	 * 
-	 * @ejb.interface-method
-	 * @generated
-	 * 
-	 * 	@ejb.permission
-	 *     unchecked="true"
-	 *     method-intf="Local"
-	 *     
-	 * @ejb.transaction
-	 *     type="RequiresNew"
-	 *     
-	 * @throws FinderException
-	 * @throws NamingException
-	 * @since 2.0.0
-	 */
-	public ArrayList<CollectorPK> getPresaveCollectorList() throws FinderException, NamingException {
-		m_log.debug("getPresaveCollectorList() :  start");
-		
-		ArrayList<CollectorPK> list = new ArrayList<CollectorPK>();
-		
 		//get Hame Interface 
 		CollectorHome home = JNDIConnectionManager.getCollectorHome();
 		Collection myBeans;
@@ -145,98 +103,66 @@ public class CollectorRunControllerBean implements SessionBean {
 			myBeans = home.findByPresave();	
 			Iterator it = myBeans.iterator();
 			
+			
 			//while Loop
 			while(it.hasNext()){
-				//無期限収集それぞれにたいして、主キーを取得します。			
+				
 				Collector bean = (Collector)it.next();
-				m_log.debug("getPresaveCollectorList() :  add collectorId = " + bean.getCollectorID());
-				CollectorPK pk = new CollectorPK(bean.getCollectorID());
-				list.add(pk);
-			}
-		} catch (RemoteException e) {
-			e.printStackTrace();
-		} catch (FinderException e) {
-			e.printStackTrace();
-		}
-		
-		m_log.debug("getPresaveCollectorList() :  end");
-		return list;
-	}
-	/**
-	 * collectorId指定の定期削除処理
-	 * 
-	 * @ejb.interface-method
-	 * @generated
-	 * 
-	 * 	@ejb.permission
-	 *     unchecked="true"
-	 *     method-intf="Local"
-	 *
-	 * @ejb.transaction
-	 *     type="RequiresNew"
-	 *     
-	 * @throws FinderException
-	 * @throws NamingException
-	 * @since 2.0.0
-	 */
-	public void _managePresavePeriod(CollectorPK pk) throws FinderException, NamingException {
-		m_log.debug("_managePresavePeriod() :  start collectorId = " + pk.getCollectorID());
-		
-		//get Hame Interface 
-		CollectorHome home = JNDIConnectionManager.getCollectorHome();
-		Collection myBeans;
-		
-		try {
-			Collector bean = (Collector)home.findByPrimaryKey(pk);
-			
-			if(bean.getPresavePeriod() >= 0){
-				//保存期間と現在日時から、保存期間の日時を計算
-				Calendar cal = Calendar.getInstance();				
-				cal.add(Calendar.DAY_OF_MONTH, -bean.getPresavePeriod());
-				cal.set(Calendar.MILLISECOND,0);
-				cal.set(Calendar.SECOND,0);
+				//無期限収集それぞれにたいして、処理をおこないます。			
 				
-				Date startDate = (Date)cal.getTime();
-				
-				m_log.debug("_managePresavePeriod() :  presaveDate " + " " + startDate.toString());
-				if(startDate.after(bean.getStartDate())){
+
+				if(bean.getPresavePeriod() >= 0){
+					//保存期間と現在日時から、保存期間の日時を計算
+					Calendar cal = Calendar.getInstance();				
+					cal.add(Calendar.DAY_OF_MONTH, -bean.getPresavePeriod());
+					cal.set(Calendar.MILLISECOND,0);
+					cal.set(Calendar.SECOND,0);
 					
-					//収集開始時刻を書き変える(GUI対策)?					
-					bean.setStartDate(startDate);
+					Date startDate = (Date)cal.getTime();
 					
-					try {
-						//収集開始時刻以前のデータを削除し、収集回数を再定義する。
-						// 処理に時間がかかった場合にはログ出力する。
-						m_log.debug("_managePresavePeriod() :  do managePresave collectorId = " + pk.getCollectorID());
-						bean.managePresave(startDate);
-					} catch (TransactionRolledbackException e) {
-						// jboss.logへの出力
-						m_log.warn("Failed to delete : " + pk.getCollectorID());
-						m_log.warn(e.getMessage(), e);
-						// HinemosApl.logへの出力
-						AplLogger apllog = new AplLogger("PERF", "perf");
-						apllog.put("SYS", "012");
-						throw e;
-					} catch (TransactionRolledbackLocalException e) {
-						// jboss.logへの出力
-						m_log.warn("Failed to delete : " + pk.getCollectorID());
-						m_log.warn(e.getMessage(), e);
-						// HinemosApl.logへの出力
-						AplLogger apllog = new AplLogger("PERF", "perf");
-						apllog.put("SYS", "012");
-						throw e;
+					m_log.debug("managePresavePeriod() :  presaveDate " + " " + startDate.toString());
+					if(startDate.after(bean.getStartDate())){
+						
+						//収集開始時刻を書き変える(GUI対策)?					
+						bean.setStartDate(startDate);
+						
+						try {
+							//収集開始時刻以前のデータを削除し、収集回数を再定義する。
+							// facilityidやitem_codeの指定によっては本処理は非常に時間が
+							// かかる場合があるため、TxRbが起きることを想定しておく必要がある。
+							// 削除・件数カウントの実行時間がJTAに引っかかった場合でも、次の
+							// 収集IDについて同様に削除・件数カウントを実行するため、TxRbを無視する。
+							// 但し起きたことがわかるようにログ出力する (S.Nagatsuma)
+							bean.managePresave(startDate);
+						} catch (TransactionRolledbackException e) {
+							// jboss.logへの出力
+							m_log.warn(e.getMessage(), e);
+							// HinemosApl.logへの出力
+							AplLogger apllog = new AplLogger("PERF", "perf");
+							String[] args = {bean.getCollectorID()};
+							apllog.put("SYS", "012", args);
+						} catch (TransactionRolledbackLocalException e) {
+							// jboss.logへの出力
+							m_log.warn(e.getMessage(), e);
+							// HinemosApl.logへの出力
+							AplLogger apllog = new AplLogger("PERF", "perf");
+							String[] args = {bean.getCollectorID()};
+							apllog.put("SYS", "012", args);
+						}
 					}
 				}
 			}
 		} catch (RemoteException e) {
+			
 			e.printStackTrace();
 		} catch (FinderException e) {
+			
 			e.printStackTrace();
 		}
 		
-		m_log.debug("_managePresavePeriod() :  end collectorId = " + pk.getCollectorID());
+		m_log.debug("managePresavePeriod() :  end");
 	}
-
+	
 	/**
 	 * Quartzへスケジュールを登録します
 	 * 
