@@ -71,12 +71,17 @@ public class AddMonitorProcess extends AddMonitorNumericValueType{
 	 */
 	@Override
 	public Calendar getCalendar(int interval) {
+		// 値取得開始時間（秒）設定が60以上のものは59秒に設定する
+		int startSecond = ProcessProperties.getProperties().getStartSecond();
+		if(startSecond >= 60){
+			startSecond = 59;
+		}
 		
 		// 日時を設定
         Calendar calendar = Calendar.getInstance();
         calendar.set(Calendar.HOUR_OF_DAY, 0);
         calendar.set(Calendar.MINUTE, 0);
-        calendar.set(Calendar.SECOND, interval + ProcessProperties.getProperties().getStartSecond());
+        calendar.set(Calendar.SECOND, interval + startSecond);
         
         return calendar;
 	}
