@@ -103,6 +103,8 @@ public class NodeCreateDialog extends CommonDialog {
     /** クリア実行フラグ */
     private boolean isClearDone = false;
     
+    /** クリアボタン */
+    private Button clearButtonScope = null;
     
     //SNMPで検出する機能のための追加コンポーネント
     private Button buttonAuto = null;
@@ -397,18 +399,21 @@ public class NodeCreateDialog extends CommonDialog {
             public void widgetSelected(SelectionEvent e) {
                 textScope.setEnabled(false);
                 buttonScope.setEnabled(false);
+                clearButtonScope.setEnabled(false);
             }
         });
         this.radioCreateTypeScope.addSelectionListener(new SelectionAdapter() {
             public void widgetSelected(SelectionEvent e) {
                 textScope.setEnabled(true);
                 buttonScope.setEnabled(true);
+                clearButtonScope.setEnabled(true);
             }
         });
 
         // 登録処理の場合、スコープ関連は使用不可とする。
         if (!this.isModifyDialog) {
             this.radioCreateTypeScope.setEnabled(false);
+            this.clearButtonScope.setEnabled(false);
         }else{
         	//変更処理の場合には、SNMPによる検出を使えなくする。
         	  this.ipAddressBox.setText("           ");
@@ -420,6 +425,7 @@ public class NodeCreateDialog extends CommonDialog {
         	  this.portBox.setEnabled(false);
         	  this.versionBox.setEnabled(false);
         	  this.buttonAuto.setEnabled(false);
+              this.clearButtonScope.setEnabled(false);
         }
 
         /*
@@ -463,12 +469,12 @@ public class NodeCreateDialog extends CommonDialog {
         //プロパティシートの展開
         //レベル1までの展開（デバイス情報、ファイルシステム情報は展開しない。）
         this.propertySheet.expandToLevel(1);
-        //ネットワークのインデックスは6
-        Object element =  this.propertySheet.getElementAt(6);
-        this.propertySheet.expandToLevel(element, 2);
-        //OSのインデックスは7
-         element =  this.propertySheet.getElementAt(7);
-        this.propertySheet.expandToLevel(element, 2);
+        //ネットワークのインデックスは7
+        Object element =  this.propertySheet.getElementAt(7);
+        this.propertySheet.expandToLevel(element, 1);
+        //OSのインデックスは8
+         element =  this.propertySheet.getElementAt(8);
+        this.propertySheet.expandToLevel(element, 1);
        
 
         // ラインを引く
@@ -493,6 +499,7 @@ public class NodeCreateDialog extends CommonDialog {
      */
     protected void createButtonsForButtonBar(Composite parent) {
         // クリアボタン
+    	clearButtonScope = 
         this.createButton(parent, IDialogConstants.OPEN_ID, Messages
                 .getString("clear"), false);
         this.getButton(IDialogConstants.OPEN_ID).addSelectionListener(
@@ -621,6 +628,62 @@ public class NodeCreateDialog extends CommonDialog {
 	            return result;
 			}
 			
+	        //ノード種別指定の必須条件
+	        values = PropertyUtil.getPropertyValue(getInputData(), NodeProperty.VIRTNODETYPE);
+			value = (String)values.get(0);
+			//host指定の場合
+			if(value != null && value.equals("host")){
+				
+		        values = PropertyUtil.getPropertyValue(getInputData(), NodeProperty.VIRTSOLUTION);
+				String virtSolution = (String)values.get(0);
+		        values = PropertyUtil.getPropertyValue(getInputData(), NodeProperty.VMUSER);
+				String vmUser = (String)values.get(0);
+		        values = PropertyUtil.getPropertyValue(getInputData(), NodeProperty.VMUSERPASSWORD);
+				String vmUserpassword = (String)values.get(0);
+		        values = PropertyUtil.getPropertyValue(getInputData(), NodeProperty.VMPROTOCOL);
+				String vmProtocol = (String)values.get(0);
+
+				//必須項目を全て入力すること
+				if(virtSolution == null || virtSolution.compareTo("") == 0
+						|| vmUser == null || vmUser.compareTo("") == 0 
+						|| vmUserpassword == null || vmUserpassword.compareTo("") == 0
+						|| vmProtocol == null || vmProtocol.compareTo("") == 0){
+					
+					//
+		            result = new ValidateResult();
+		            result.setID(Messages.getString("message.hinemos.1"));
+		            result.setMessage(Messages.getString("message.repository.42"));
+		            result.setValid(false);
+		            return result;
+				}
+				
+	        //guest指定の場合
+			}else if(value != null && value.equals("guest")){
+				
+		        values = PropertyUtil.getPropertyValue(getInputData(), NodeProperty.VIRTSOLUTION);
+				String virtSolution = (String)values.get(0);
+		        values = PropertyUtil.getPropertyValue(getInputData(), NodeProperty.VMMANAGEMENTNODE);
+				String vmManagementNode = (String)values.get(0);
+		        values = PropertyUtil.getPropertyValue(getInputData(), NodeProperty.VMNAME);
+				String vmName = (String)values.get(0);
+		        values = PropertyUtil.getPropertyValue(getInputData(), NodeProperty.VMID);
+				String vmId = (String)values.get(0);
+				
+				//必須項目を全て入力すること
+				if(virtSolution == null || virtSolution.compareTo("") == 0
+						|| vmManagementNode == null || vmManagementNode.compareTo("") == 0 
+						|| vmName == null || vmName.compareTo("") == 0
+						|| vmId == null || vmId.compareTo("") == 0){
+					
+					//
+		            result = new ValidateResult();
+		            result.setID(Messages.getString("message.hinemos.1"));
+		            result.setMessage(Messages.getString("message.repository.43"));
+		            result.setValid(false);
+		            return result;
+				}
+			}
+			
 			// LDAPのdnをデバイス名から、デバイスTYPE＋デバイスINDEXに変更したため、
 			// 名前入力チェックをコメントアウトした　Ver2.4.0 uchiyama
 			/*
@@ -650,11 +713,13 @@ public class NodeCreateDialog extends CommonDialog {
 			
 			//デバイスの入力チェック
 			//ルール１：
-			//デバイスINDEXとデバイスTYPEが入力してある、かつ、デバイス名が未入力の場合は、エラーを表示
+			//デバイスINDEXとデバイスTYPEが入力してある、かつ、デバイス名、表示名が未入力の場合は、エラーを表示
 			//ルール２：
 			//(ver3.0.1より廃止)デバイスTYPEに「disk」「nic」以外の文字が入力してある場合は、エラをー表示
 			//ルール３：
 			//デバイス名に重複がある場合は、エラーを表示
+			//ルール４：
+			//表示名に重複がある場合は、エラーを表示
 			values = PropertyUtil.getPropertyValue(getInputData(), NodeProperty.DEVICE_INDEX);
 			Iterator itr = values.iterator();
 			
@@ -664,16 +729,22 @@ public class NodeCreateDialog extends CommonDialog {
 			ArrayList values3 = PropertyUtil.getPropertyValue(getInputData(), NodeProperty.DEVICE_NAME);
 			Iterator itr3 = values3.iterator();
 			
+			ArrayList values4 = PropertyUtil.getPropertyValue(getInputData(), NodeProperty.DEVICE_DISPLAY_NAME);
+			Iterator itr4 = values4.iterator();
+			
 			String deviceIndex;
 			String deviceType;
 			String deviceName;
+			String deviceDisplayName;
 			ArrayList<String> checkDn = new ArrayList<String>();
-			ArrayList<String> checkName = new ArrayList<String>();			
+			ArrayList<String> checkName = new ArrayList<String>();
+			ArrayList<String> checkDisplayName = new ArrayList<String>();
 			//デバイスの登録数だけチェックする
 			while(itr.hasNext()){
 				deviceIndex = itr.next().toString();
 				deviceType = itr2.next().toString();
 				deviceName = itr3.next().toString();
+				deviceDisplayName = itr4.next().toString();
 				
 				//デバイスINDEXとデバイスTYPEが未入力でない
 				if(deviceIndex != null && !deviceIndex.equals("") && 
@@ -681,7 +752,17 @@ public class NodeCreateDialog extends CommonDialog {
 					
 					//デバイス名が未入力
 					if(deviceName == null || deviceName.equals("")) {
-						String[] args = { deviceType,deviceIndex };
+						String[] args = { deviceType,deviceIndex,Messages.getString("device.name") };
+						result = new ValidateResult();
+			            result.setID(Messages.getString("message.hinemos.1"));
+			            result.setMessage(Messages.getString("message.repository.33", args));
+			            result.setValid(false);
+			            return result;
+					}
+					
+					//デバイス表示名が未入力
+					if(deviceDisplayName == null || deviceDisplayName.equals("")) {
+						String[] args = { deviceType,deviceIndex,Messages.getString("device.display.name") };
 						result = new ValidateResult();
 			            result.setID(Messages.getString("message.hinemos.1"));
 			            result.setMessage(Messages.getString("message.repository.33", args));
@@ -723,6 +804,7 @@ public class NodeCreateDialog extends CommonDialog {
 					
 					checkDn.add(deviceType+"_"+deviceIndex);
 					checkName.add(deviceName);
+					checkDisplayName.add(deviceDisplayName);
 				}
 			}
 			
@@ -746,6 +828,15 @@ public class NodeCreateDialog extends CommonDialog {
 			            result.setID(Messages.getString("message.hinemos.1"));
 			            result.setMessage(Messages.getString("message.repository.32", args));
 			            result.setValid(false);
+			            return result;
+					}
+					// デバイス表示名重複チェック
+					if (checkDisplayName.get(i).equals(checkDisplayName.get(j))) {
+						String[] args = { Messages.getString("device.display.name"), checkDisplayName.get(i) };
+						result = new ValidateResult();
+			            result.setID(Messages.getString("message.hinemos.1"));
+			            result.setMessage(Messages.getString("message.repository.32", args));
+			            result.setValid(false);
 			            return result;
 					}
 				}
@@ -754,32 +845,49 @@ public class NodeCreateDialog extends CommonDialog {
 			
 			//ファイルシステムの入力項目チェック
 			//ルール１：
-			//ファイルシステムINDEXが入力されている、かつ、マウント位置が未入力の場合は、エラーを表示
+			//ファイルシステムINDEXが入力されている、かつ、マウント位置、表示名が未入力の場合は、エラーを表示
 			//ルール２：
 			//ファイルシステムINDEXが重複している場合は、エラーを表示
 			//ルール３：
 			//マウント位置が重複している場合は、エラーを表示
+			//ルール４：
+			//表示名に重複がある場合は、エラーを表示
 			values = PropertyUtil.getPropertyValue(getInputData(), NodeProperty.FILE_SYSTEM_INDEX);
 			itr = values.iterator();
 			
 			values2 = PropertyUtil.getPropertyValue(getInputData(), NodeProperty.FILE_SYSTEM_MOUNT_POINT);
 			itr2  = values2.iterator();
 			
+			values3 = PropertyUtil.getPropertyValue(getInputData(), NodeProperty.FILE_SYSTEM_DISPLAY_NAME);
+			itr3  = values3.iterator();
+			
 			String fileSystemIndex;
 			String fileSystemMountPoint;
+			String fileSystemDisplayName;
 			checkDn = new ArrayList<String>();
 			checkName = new ArrayList<String>();
+			checkDisplayName = new ArrayList<String>();
 			
 			// ファイルシステムの登録数だけチェックする
 			while(itr.hasNext()){
 				fileSystemIndex = itr.next().toString();
 				fileSystemMountPoint = itr2.next().toString();
+				fileSystemDisplayName = itr3.next().toString();
 				
 				//ファイルシステムINDEXが未入力でない
 				if(fileSystemIndex != null && !fileSystemIndex.equals("")){
 					//マウント位置が未入力
 					if(fileSystemMountPoint == null || fileSystemMountPoint.equals("")){
-						String[] args = { fileSystemIndex };
+						String[] args = { fileSystemIndex,Messages.getString("file.system.mount.point") };
+						result = new ValidateResult();
+			            result.setID(Messages.getString("message.hinemos.1"));
+			            result.setMessage(Messages.getString("message.repository.31", args));
+			            result.setValid(false);
+			            return result;
+					}
+					//デバイス表示名が未入力
+					if(fileSystemDisplayName == null || fileSystemDisplayName.equals("")) {
+						String[] args = { fileSystemIndex,Messages.getString("file.system.display.name") };
 						result = new ValidateResult();
 			            result.setID(Messages.getString("message.hinemos.1"));
 			            result.setMessage(Messages.getString("message.repository.31", args));
@@ -788,6 +896,7 @@ public class NodeCreateDialog extends CommonDialog {
 					}
 					checkDn.add(fileSystemIndex);
 					checkName.add(fileSystemMountPoint);
+					checkDisplayName.add(fileSystemDisplayName);
 				}
 			}
 			
@@ -811,6 +920,15 @@ public class NodeCreateDialog extends CommonDialog {
 			            result.setID(Messages.getString("message.hinemos.1"));
 			            result.setMessage(Messages.getString("message.repository.32", args));
 			            result.setValid(false);
+			            return result;
+					}
+					//表示名重複チェック
+					if (checkDisplayName.get(i).equals(checkDisplayName.get(j))) {
+						String[] args = { Messages.getString("file.system.display.name"), checkDisplayName.get(i) };
+						result = new ValidateResult();
+			            result.setID(Messages.getString("message.hinemos.1"));
+			            result.setMessage(Messages.getString("message.repository.32", args));
+			            result.setValid(false);
 			            return result;
 					}
 				}
