@@ -69,6 +69,19 @@ public class FacilityAttributeConstant {
 	public static final String VMNAME= "ccVMName";
 	public static final String VIRTSOLUTION= "ccVirtualizationSolution";
 
+	//20090114 add
+	public static final String VMID= "ccVMId";
+	public static final String VMUSER= "ccVMUser";
+	public static final String VMUSERPASSWORD= "ccVMUserPassword";
+	public static final String VMPROTOCOL= "ccVMProtocol";
+	
+	//20090127 add
+	public static final String WBEMUSER = "ccWbemUser";
+	public static final String WBEMUSERPASSWORD = "ccWbemUserPassword";
+	public static final String WBEMPORT = "ccWbemPort";
+	public static final String WBEMPROTOCOL = "ccWbemProtocol";
+	public static final String WBEMTIMEOUT = "ccWbemTimeout";
+	public static final String WBEMRETRIES = "ccWbemRetries";
 	
 	
 	
