@@ -19,7 +19,7 @@ package com.clustercontrol.repository.bean;
  * FacilityTree(BMP Entity Bean)の属性名定義クラス<BR>
  * 定義されているStringはLDAPの属性を一致します。
  *
- * @version 1.0.0
+ * @version 3.1.0
  * @since 1.0.0
  */
 public class FacilityTreeAttributeConstant {
@@ -35,6 +35,11 @@ public class FacilityTreeAttributeConstant {
 	
 	public static final String INTERNAL_SCOPE="INTERNAL";
 	public static final String INTERNAL_SCOPE_TEXT="Hinemos_Internal";
-	
+
+	public static final String VM_SCOPE="VM";
+	public static final String VM_SCOPE_TEXT="Vm_Node";
+	public static final String UNALLOCATED_SCOPE="UNALLOCATED";
+	public static final String UNALLOCATED_SCOPE_TEXT="Unallocated_Node";
+
 	public static final String VALID="ccValid";
 }
