@@ -103,6 +103,10 @@ public class DeviceInfoDAOImpl implements DeviceInfoDAO {
 				if(attrs.get(DeviceInfoAttributeConstant.DESCRIPTION) != null){
 					ejb.setDescription((String)attrs.get(DeviceInfoAttributeConstant.DESCRIPTION).get(0));
 				}
+				//ccDisplayName取得
+				if(attrs.get(DeviceInfoAttributeConstant.DISPLAYNAME) != null){
+					ejb.setDisplayName((String)attrs.get(DeviceInfoAttributeConstant.DISPLAYNAME).get(0));
+				}
 				
 				//dnからファシリティIDを抽出する
 				//dnは下記の内容となるため、初めに出現する","以前と最後に出現する","以降を削除したあと
@@ -237,6 +241,16 @@ public class DeviceInfoDAOImpl implements DeviceInfoDAO {
 				else if(attrs.get(DeviceInfoAttributeConstant.DEVICETYPE) != null && ejb.getDeviceType() != null){
 					replaceAttrs.put(DeviceInfoAttributeConstant.DEVICETYPE, ejb.getDeviceType());
 				}
+				//ccDisplayName設定
+				if(attrs.get(DeviceInfoAttributeConstant.DISPLAYNAME) == null && ejb.getDisplayName() != null){
+					addAttrs.put(DeviceInfoAttributeConstant.DISPLAYNAME, ejb.getDisplayName());
+				}
+				else if(attrs.get(DeviceInfoAttributeConstant.DISPLAYNAME) != null && ejb.getDisplayName() == null){
+					removeAttrs.put(DeviceInfoAttributeConstant.DISPLAYNAME, null);
+				}
+				else if(attrs.get(DeviceInfoAttributeConstant.DISPLAYNAME) != null && ejb.getDisplayName() != null){
+					replaceAttrs.put(DeviceInfoAttributeConstant.DISPLAYNAME, ejb.getDisplayName());
+				}
 				//属性を変更する（追加）
 				ctx.modifyAttributes(
 						ejb.getDn(), 
@@ -404,28 +418,6 @@ public class DeviceInfoDAOImpl implements DeviceInfoDAO {
 				//dn設定
 				ejb.setDn(dn.toString());
 				
-				//各種属性値をセットする
-				
-				if (ejb.getDeviceName() != null) {
-					attrs.put(DeviceInfoAttributeConstant.DEVICENAME, ejb.getDeviceName());
-				}
-				
-				if (ejb.getSnmpOID() != null) {
-					attrs.put(DeviceInfoAttributeConstant.SNMPOID, ejb.getSnmpOID());
-				}
-				
-				if (ejb.getDeviceIndex() != null) {
-					attrs.put(DeviceInfoAttributeConstant.DEVICEINDEX, ejb.getDeviceIndex().toString());
-				}
-				
-				if (ejb.getDeviceType() != null) {
-					attrs.put(DeviceInfoAttributeConstant.DEVICETYPE, ejb.getDeviceType());
-				}
-				
-				if (ejb.getDescription() != null) {
-					attrs.put(DeviceInfoAttributeConstant.DESCRIPTION, ejb.getDescription());
-				}
-				
 				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
 				timer = TimeKeeperService.start();
 				
@@ -928,5 +920,6 @@ public class DeviceInfoDAOImpl implements DeviceInfoDAO {
 	    ejb.setDn(null);
 	    ejb.setFacilityId(null);
 	    ejb.setSnmpOID(null);
+	    ejb.setDeviceName(null);
 	}
 }
