@@ -20,6 +20,8 @@ import java.text.SimpleDateFormat;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Date;
+import java.util.HashMap;
+import java.util.Iterator;
 
 import javax.ejb.CreateException;
 import javax.ejb.DuplicateKeyException;
@@ -306,6 +308,64 @@ public class FacilityDAOImpl implements FacilityDAO {
 					if(attrs.get(FacilityAttributeConstant.VIRTSOLUTION) != null){
 						ejb.setVirtSolution((String)attrs.get(FacilityAttributeConstant.VIRTSOLUTION).get(0));
 					}
+					
+					
+					//20090114 add
+					//ccVMId取得
+					if(attrs.get(FacilityAttributeConstant.VMID) != null){
+						ejb.setVmId((String)attrs.get(FacilityAttributeConstant.VMID).get(0));
+					}
+
+					
+					//ccVMUser取得
+					if(attrs.get(FacilityAttributeConstant.VMUSER) != null){
+						ejb.setVmUser((String)attrs.get(FacilityAttributeConstant.VMUSER).get(0));
+					}
+
+					
+					//ccVMUserPassword取得
+					if(attrs.get(FacilityAttributeConstant.VMUSERPASSWORD) != null){
+						ejb.setVmUserpassword((String)attrs.get(FacilityAttributeConstant.VMUSERPASSWORD).get(0));
+					}
+
+					
+					//ccVMProtocol取得
+					if(attrs.get(FacilityAttributeConstant.VMPROTOCOL) != null){
+						ejb.setVmProtocol((String)attrs.get(FacilityAttributeConstant.VMPROTOCOL).get(0));
+					}
+
+					
+					//20090127 add
+					//ccWbemUser取得
+					if(attrs.get(FacilityAttributeConstant.WBEMUSER) != null){
+						ejb.setWbemUser((String)attrs.get(FacilityAttributeConstant.WBEMUSER).get(0));
+					}
+					
+					//ccWbemUserPassword取得
+					if(attrs.get(FacilityAttributeConstant.WBEMUSERPASSWORD) != null){
+						ejb.setWbemUserPassword((String)attrs.get(FacilityAttributeConstant.WBEMUSERPASSWORD).get(0));
+					}
+					
+					//ccWbemPort取得
+					if(attrs.get(FacilityAttributeConstant.WBEMPORT) != null){
+						ejb.setWbemPort(new Integer((String)attrs.get(FacilityAttributeConstant.WBEMPORT).get(0)));
+					}
+					
+					//ccWbemProtocol取得
+					if(attrs.get(FacilityAttributeConstant.WBEMPROTOCOL) != null){
+						ejb.setWbemProtocol((String)attrs.get(FacilityAttributeConstant.WBEMPROTOCOL).get(0));
+					}
+					
+					//ccWbemTimeout取得
+					if(attrs.get(FacilityAttributeConstant.WBEMTIMEOUT) != null){
+						ejb.setWbemTimeout(new Integer((String)attrs.get(FacilityAttributeConstant.WBEMTIMEOUT).get(0)));
+					}
+					
+					//ccWbemRetries取得
+					if(attrs.get(FacilityAttributeConstant.WBEMRETRIES) != null){
+						ejb.setWbemRetries(new Integer((String)attrs.get(FacilityAttributeConstant.WBEMRETRIES).get(0)));
+					}
+					
 				}
 			} catch (javax.naming.NamingException ex) {
 				if (ex instanceof CommunicationException) {
@@ -853,6 +913,119 @@ public class FacilityDAOImpl implements FacilityDAO {
 						replaceAttrs.put(FacilityAttributeConstant.VIRTSOLUTION, ejb.getVirtSolution().toString());
 					}
 
+					//ccVMId設定
+					if(attrs.get(FacilityAttributeConstant.VMID) == null && ejb.getVmId() != null){
+						addAttrs.put(FacilityAttributeConstant.VMID, ejb.getVmId().toString());
+					}
+					else if(attrs.get(FacilityAttributeConstant.VMID) != null && ejb.getVmId() == null){
+						removeAttrs.put(FacilityAttributeConstant.VMID, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.VMID) != null && ejb.getVmId() != null){
+						replaceAttrs.put(FacilityAttributeConstant.VMID, ejb.getVmId().toString());
+					}
+					else{
+					}
+						
+
+					//ccVMUser設定
+					if(attrs.get(FacilityAttributeConstant.VMUSER) == null && ejb.getVmUser() != null){
+						addAttrs.put(FacilityAttributeConstant.VMUSER, ejb.getVmUser().toString());
+					}
+					else if(attrs.get(FacilityAttributeConstant.VMUSER) != null && ejb.getVmUser() == null){
+						removeAttrs.put(FacilityAttributeConstant.VMUSER, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.VMUSER) != null && ejb.getVmUser() != null){
+						replaceAttrs.put(FacilityAttributeConstant.VMUSER, ejb.getVmUser().toString());
+					}
+
+					//ccVMUserPassword設定
+					if(attrs.get(FacilityAttributeConstant.VMUSERPASSWORD) == null && ejb.getVmUserpassword() != null){
+						addAttrs.put(FacilityAttributeConstant.VMUSERPASSWORD, ejb.getVmUserpassword().toString());
+					}
+					else if(attrs.get(FacilityAttributeConstant.VMUSERPASSWORD) != null && ejb.getVmUserpassword() == null){
+						removeAttrs.put(FacilityAttributeConstant.VMUSERPASSWORD, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.VMUSERPASSWORD) != null && ejb.getVmUserpassword() != null){
+						replaceAttrs.put(FacilityAttributeConstant.VMUSERPASSWORD, ejb.getVmUserpassword().toString());
+					}
+
+					//ccVMProtocol設定
+					if(attrs.get(FacilityAttributeConstant.VMPROTOCOL) == null && ejb.getVmProtocol() != null){
+						addAttrs.put(FacilityAttributeConstant.VMPROTOCOL, ejb.getVmProtocol().toString());
+					}
+					else if(attrs.get(FacilityAttributeConstant.VMPROTOCOL) != null && ejb.getVmProtocol() == null){
+						removeAttrs.put(FacilityAttributeConstant.VMPROTOCOL, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.VMPROTOCOL) != null && ejb.getVmProtocol() != null){
+						replaceAttrs.put(FacilityAttributeConstant.VMPROTOCOL, ejb.getVmProtocol().toString());
+					}
+					
+					//ccWbemUser設定
+					if(attrs.get(FacilityAttributeConstant.WBEMUSER) == null && ejb.getWbemUser() != null){
+						addAttrs.put(FacilityAttributeConstant.WBEMUSER, ejb.getWbemUser().toString());
+					}
+					else if(attrs.get(FacilityAttributeConstant.WBEMUSER) != null && ejb.getWbemUser() == null){
+						removeAttrs.put(FacilityAttributeConstant.WBEMUSER, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.WBEMUSER) != null && ejb.getWbemUser() != null){
+						replaceAttrs.put(FacilityAttributeConstant.WBEMUSER, ejb.getWbemUser().toString());
+					}
+					
+					//ccWbemUserPassword設定
+					if(attrs.get(FacilityAttributeConstant.WBEMUSERPASSWORD) == null && ejb.getWbemUserPassword() != null){
+						addAttrs.put(FacilityAttributeConstant.WBEMUSERPASSWORD, ejb.getWbemUserPassword().toString());
+					}
+					else if(attrs.get(FacilityAttributeConstant.WBEMUSERPASSWORD) != null && ejb.getWbemUserPassword() == null){
+						removeAttrs.put(FacilityAttributeConstant.WBEMUSERPASSWORD, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.WBEMUSERPASSWORD) != null && ejb.getWbemUserPassword() != null){
+						replaceAttrs.put(FacilityAttributeConstant.WBEMUSERPASSWORD, ejb.getWbemUserPassword().toString());
+					}
+					
+					//ccWbemPort設定
+					if(attrs.get(FacilityAttributeConstant.WBEMPORT) == null && ejb.getWbemPort() != null){
+						addAttrs.put(FacilityAttributeConstant.WBEMPORT, ejb.getWbemPort().toString());
+					}
+					else if(attrs.get(FacilityAttributeConstant.WBEMPORT) != null && ejb.getWbemPort() == null){
+						removeAttrs.put(FacilityAttributeConstant.WBEMPORT, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.WBEMPORT) != null && ejb.getWbemPort() != null){
+						replaceAttrs.put(FacilityAttributeConstant.WBEMPORT, ejb.getWbemPort().toString());
+					}
+					
+					//ccWbemProtocol設定
+					if(attrs.get(FacilityAttributeConstant.WBEMPROTOCOL) == null && ejb.getWbemProtocol() != null){
+						addAttrs.put(FacilityAttributeConstant.WBEMPROTOCOL, ejb.getWbemProtocol().toString());
+					}
+					else if(attrs.get(FacilityAttributeConstant.WBEMPROTOCOL) != null && ejb.getWbemProtocol() == null){
+						removeAttrs.put(FacilityAttributeConstant.WBEMPROTOCOL, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.WBEMPROTOCOL) != null && ejb.getWbemProtocol() != null){
+						replaceAttrs.put(FacilityAttributeConstant.WBEMPROTOCOL, ejb.getWbemProtocol().toString());
+					}
+					
+					//ccWbemTimeout設定
+					if(attrs.get(FacilityAttributeConstant.WBEMTIMEOUT) == null && ejb.getWbemTimeout() != null){
+						addAttrs.put(FacilityAttributeConstant.WBEMTIMEOUT, ejb.getWbemTimeout().toString());
+					}
+					else if(attrs.get(FacilityAttributeConstant.WBEMTIMEOUT) != null && ejb.getWbemTimeout() == null){
+						removeAttrs.put(FacilityAttributeConstant.WBEMTIMEOUT, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.WBEMTIMEOUT) != null && ejb.getWbemTimeout() != null){
+						replaceAttrs.put(FacilityAttributeConstant.WBEMTIMEOUT, ejb.getWbemTimeout().toString());
+					}
+					
+					//ccWbemRetries設定
+					if(attrs.get(FacilityAttributeConstant.WBEMRETRIES) == null && ejb.getWbemRetries() != null){
+						addAttrs.put(FacilityAttributeConstant.WBEMRETRIES, ejb.getWbemRetries().toString());
+					}
+					else if(attrs.get(FacilityAttributeConstant.WBEMRETRIES) != null && ejb.getWbemRetries() == null){
+						removeAttrs.put(FacilityAttributeConstant.WBEMRETRIES, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.WBEMRETRIES) != null && ejb.getWbemRetries() != null){
+						replaceAttrs.put(FacilityAttributeConstant.WBEMRETRIES, ejb.getWbemRetries().toString());
+					}
+					
 				}
 				//属性を変更する（追加）
 				ctx.modifyAttributes(
@@ -2130,6 +2303,21 @@ public class FacilityDAOImpl implements FacilityDAO {
 	    ejb.setSnmpCommunity(null);
 	    ejb.setSnmpVersion(null);
 	    ejb.setSortValue(null);
+	    ejb.setWbemUser(null);
+	    ejb.setWbemUserPassword(null);
+	    ejb.setWbemPort(null);
+	    ejb.setWbemProtocol(null);
+	    ejb.setWbemTimeout(null);
+	    ejb.setWbemRetries(null);
+	    ejb.setVirtNodeType(null);
+	    ejb.setVMManagementNode(null);
+	    ejb.setVmIndex(null);
+	    ejb.setVmName(null);
+	    ejb.setVirtSolution(null);
+	    ejb.setVmId(null);
+	    ejb.setVmUser(null);
+	    ejb.setVmUserpassword(null);
+	    ejb.setVmProtocol(null);
 	}
 	
 	/**
@@ -2142,4 +2330,132 @@ public class FacilityDAOImpl implements FacilityDAO {
 	private String createDnString(String facilityId) {
 		return "ccFacilityId=" + facilityId + "," + BASE_DN;
 	}
+	
+    /* (non-Javadoc)
+     * @see com.clustercontrol.repository.dao.FacilityDAO#findByNodeName(java.lang.String)
+     */
+    public Collection findByCondition(HashMap condition) throws FinderException {
+		ArrayList<FacilityPK> ret = new ArrayList<FacilityPK>();
+		
+		m_log.debug("findByCondition() : start");
+		
+		// エントリの検索
+		javax.naming.directory.SearchControls constraints = 
+			new javax.naming.directory.SearchControls();
+
+		// BaseDN以下にぶら下がるすべてのレベルを検索の対象
+		constraints.setSearchScope(javax.naming.directory.SearchControls.SUBTREE_SCOPE);
+
+		// 検索文字列作成
+		StringBuffer search = new StringBuffer();
+		search.append("(&(");
+		search.append(OBJECTCLASS);
+		search.append("=");
+		search.append(OBJECT_CLASS_FACILITY);
+		search.append(")(");
+		search.append(OBJECTCLASS);
+		search.append("=");
+		search.append(OBJECT_CLASS_NODE);
+		// 検索文字列をセットする
+		Iterator<String> iterator = condition.keySet().iterator();
+		while (iterator.hasNext()) {
+			String key = (String) iterator.next();
+			String val = (String) condition.get(key); // 「空文字列」では検索しない
+				
+			if(key.compareTo("") != 0 && val != null && val.compareTo("") != 0){
+				search.append(")(");
+				search.append(key);
+				search.append("=");
+				search.append(val);
+			}
+		}
+		search.append("))");
+		m_log.debug("findByCondition() : search string = " + search.toString());
+		
+		
+		//検索実行
+		javax.naming.NamingEnumeration results = null;
+		javax.naming.directory.DirContext ctx = null;
+		
+		int retryCount=0;
+		while(MAX_RETRY > retryCount){
+			TimeKeeper timer = null;
+				
+			try {
+				// LDAP用のコンテキストの作成
+				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
+				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
+				results = ctx.search(BASE_DN, search.toString(), constraints);
+				
+				if (results == null ) {
+					m_log.warn("findByCondition() : No Search Result : search string = " + search.toString());
+					return ret;
+				}
+	
+				//検索結果を取得
+				while ( results.hasMoreElements() ) {
+					javax.naming.directory.SearchResult aResult = 
+						(javax.naming.directory.SearchResult)results.nextElement();
+//					FacilityPK pk = new FacilityPK(aResult.getName() + "," + BASE_DN);
+					Attributes attrs = aResult.getAttributes();
+					FacilityPK pk = new FacilityPK((String)attrs.get(FacilityAttributeConstant.FACILITYID).get(0));
+
+					ret.add(pk);
+				}
+				
+			} catch (NamingException ex) {
+				if(ex instanceof CommunicationException){
+					LdapConnectionManager.getConnectionManager().setDirContext(null);
+				}
+				m_log.debug("findByCondition() : " + ex.getMessage());
+				//中身を空にします。
+				ret.clear();
+				// whileループの判定の前に、メッソッドを抜けるかのチェックをするため、
+				// ここでカウントアップする。
+				retryCount++;
+				if(retryCount >= MAX_RETRY){
+					throw new EJBException(ex);
+				} else {
+					//リトライ上限以下の場合には再度LDAPに問い合わせをします。
+					//whlie loopに戻ります。
+					continue;
+				}
+					
+			} catch (NullPointerException e) {
+				//jreのバグ（？）により、hasMoreElements()でNullPointerExceptionが発生することがある。
+				//根本対処の方法がないため、NullPointerExcetionをcatchする。（2007/06/19　宮本）
+				m_log.debug("findByCondition() : LDAP query result is null");
+				//中身を空にします。
+				ret.clear();
+				//whileループの判定の前に、メッソッドを抜けるかのチェックをするため、
+				// ここでカウントアップする。
+				retryCount++;
+				if(retryCount >= MAX_RETRY){
+					throw new EJBException(e);
+				} else {
+					//リトライ上限以下の場合には再度LDAPに問い合わせをします。
+					//whlie loopに戻ります。
+					continue;
+				}
+				
+			} finally {
+				try {
+					if(results != null)
+						results.close();
+					if(ctx != null)
+						ctx.close();
+				} catch (NamingException e) {
+					m_log.error("findByCondition() context close failed : " + e.getMessage());
+				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
+			}
+			return ret;
+	    }
+		return ret;
+	}
 }
