@@ -29,6 +29,8 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.accesscontrol.util.LdapConnectionManager;
+import com.clustercontrol.accesscontrol.util.TimeKeeper;
+import com.clustercontrol.accesscontrol.util.TimeKeeperService;
 import com.clustercontrol.bean.FacilityConstant;
 import com.clustercontrol.repository.bean.FacilityAttributeConstant;
 import com.clustercontrol.repository.bean.FacilityTreeAttributeConstant;
@@ -68,13 +70,16 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 		
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
-
+			TimeKeeper timer = null;
 			try {
 				clearBean(ejb);
 				
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
-				
+
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+	
 				//属性を取得
 				javax.naming.directory.Attributes attrs = ctx.getAttributes(pk.getDn());
 	
@@ -132,6 +137,9 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				} catch (NamingException e) {
 					m_log.error("load() context close failed : " + e.getMessage());
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			m_log.trace("load() : end " + pk.getDn());
 			return;
@@ -146,10 +154,14 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 		
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
+			TimeKeeper timer = null;
 			try {				
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				//dnをキーとしてLDAPアクセスし、属性を取得
 				javax.naming.directory.Attributes attrs = ctx.getAttributes(ejb.getDn());
 			
@@ -213,6 +225,9 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				} catch (NamingException e) {
 					m_log.error("load() context close failed : " + e.getMessage());
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			return;
 		}
@@ -226,10 +241,14 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 		javax.naming.directory.DirContext ctx = null;
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				//エントリを削除
 				ctx.destroySubcontext(pk.getDn());
 				
@@ -277,6 +296,9 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				} catch (NamingException e) {
 					m_log.error("remove() context close failed : " + e.getMessage());
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			m_log.trace("remove() : end " + pk.getDn());
 			return;
@@ -291,8 +313,8 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 		FacilityTreePK pk = null;
 		javax.naming.directory.DirContext ctx = null;
 		int retryCount=0;
-		while(MAX_RETRY > retryCount){	
-			
+		while(MAX_RETRY > retryCount){
+			TimeKeeper timer = null;
 			try {
 				//親のdnを取得
 				String baseDn = BASE_DN;
@@ -333,7 +355,10 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				
 				//dn設定
 				ejb.setDn(dn.toString());
-	
+				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				//エントリの作成
 				ctx.createSubcontext(ejb.getDn(), attrs);
 	
@@ -388,6 +413,9 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				} catch (NamingException e) {
 					m_log.error("create() context close failed : " + e.getMessage());
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			return pk;
 		}
@@ -488,11 +516,14 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 		
 		int retryCount=0;	
 		while(MAX_RETRY > retryCount){
-			
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				results = ctx.search(baseDn.toString(), search.toString(), constraints);
 				
 				if (results == null ) {
@@ -560,6 +591,9 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				} catch (NamingException e) {
 					m_log.error("findAll() context close failed : " + e.getMessage());
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			
 			return ret;
@@ -575,12 +609,16 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 		
 		int retryCount=0;	
 		while(MAX_RETRY > retryCount){
+			TimeKeeper timer = null;
 			try {
 			    m_log.debug("findByPrimaryKey() : dn = " + pk.getDn());
 			    
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				//属性取得
 				javax.naming.directory.Attributes attrs = ctx.getAttributes(pk.getDn());
 				
@@ -631,6 +669,9 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				} catch (NamingException e) {
 					m_log.error("findByPrimaryKey() context close failed : " + e.getMessage());
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 		}
 		return pk;
@@ -666,10 +707,14 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 		int retryCount=0;
 		
 		while(MAX_RETRY > retryCount){
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				results = ctx.search(pk.getDn(), search.toString(), constraints);
 				
 				if (results == null ) {
@@ -729,6 +774,9 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				} catch (NamingException e) {
 					m_log.error("findChildren() context close failed : " + e.getMessage());
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			return ret;
 		}
@@ -777,11 +825,14 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 		int retryCount=0;
 		
 		while(MAX_RETRY > retryCount){
-			
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				results = ctx.search(BASE_DN, search.toString(), constraints);
 				
 				if (results == null) {
@@ -850,6 +901,9 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				} catch (NamingException e) {
 					m_log.error("findScopeByFacilityId() context close failed : " + e.getMessage());
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 	
 			return pk;
@@ -920,10 +974,14 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 		int retryCount=0;
 		
 		while(MAX_RETRY > retryCount){
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				results = ctx.search(BASE_DN, search.toString(), constraints);
 				
 				if (results == null ) {
@@ -983,6 +1041,9 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				} catch (NamingException e) {
 					m_log.error("findByFacilityId() context close failed : " + e.getMessage());
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 
 			return ret;
@@ -1046,7 +1107,7 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				FacilityTreePK pk = findScopeByFacilityId(facilityId);
 				baseDn.append(pk.getDn());
 			} catch (FinderException e) {
-				m_log.warn("findOneLevel() : No Search Result : FacilityId = " + facilityId + ", Type = " + type);
+				m_log.debug("findOneLevel() : No Search Result : FacilityId = " + facilityId + ", Type = " + type);
 				return ret;
 			}
 		}
@@ -1084,10 +1145,15 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 		int retryCount=0;
 		
 		while(MAX_RETRY > retryCount){
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				// タイマースレッドを停止
+				timer = TimeKeeperService.start();
+				
 				results = ctx.search(baseDn.toString(), search.toString(), constraints);
 				
 				if (results == null ) {
@@ -1148,6 +1214,9 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				} catch (NamingException e) {
 					m_log.error("findOneLevel() context close failed : " + e.getMessage());
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 	
 			return ret;
@@ -1245,7 +1314,11 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 		int retryCount=0;
 		
 		while(MAX_RETRY > retryCount){
+			TimeKeeper timer = null;
 			try {
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				results = ctx.search(baseDn.toString(), search.toString(), constraints);
 
@@ -1306,6 +1379,9 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				} catch (NamingException e) {
 					m_log.error("findNodeListByValid() context close failed : " + e.getMessage());
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			return ret;
 		}
