@@ -56,7 +56,7 @@ import com.clustercontrol.util.apllog.AplLogger;
 /**
  * ファシリティを更新するクラス<BR>
  *
- * @version 1.0.0
+ * @version 3.1.0
  * @since 1.0.0
  */
 public class ModifyFacility {
@@ -75,6 +75,37 @@ public class ModifyFacility {
 	 * @throws NamingException
 	 */
 	public void addScope(String parentFacilityId, Property property) throws RemoveException, CreateException, NamingException {
+		//FIXME　ソートの順番はとりあえずオンコードで100とする。
+		addScope(parentFacilityId, property, DEFAULT_SORT_ORDER);
+	}
+
+	/**
+	 * スコープ追加（表示順指定）
+	 * 
+	 * @param parentFacilityId
+	 * @param property
+	 * @param sortOrder
+	 * @throws RemoveException
+	 * @throws CreateException
+	 * @throws NamingException
+	 */
+	public void addScope(String parentFacilityId, Property property, int sortOrder) throws RemoveException, CreateException, NamingException {
+		addScope(parentFacilityId,property,sortOrder,true);
+	}
+
+
+	/**
+	 * スコープ追加（表示順指定）
+	 * 
+	 * @param parentFacilityId
+	 * @param property
+	 * @param sortOrder
+	 * @param sendFlg
+	 * @throws RemoveException
+	 * @throws CreateException
+	 * @throws NamingException
+	 */
+	public void addScope(String parentFacilityId, Property property, int sortOrder, boolean sendFlg) throws RemoveException, CreateException, NamingException {
     	//アクセスロック
     	AccessLock.lock(AccessLock.REPOSITORY);
 		
@@ -109,12 +140,11 @@ public class ModifyFacility {
 		
 		try {
 			//FacilityTreeを作成
-			//FIXME　ソートの順番はとりあえずオンコードで100とする。
 			FacilityTreeLocal facilityTree = FacilityTreeUtil.getLocalHome().create(
 					(String)facilityId.get(0), 
 					FacilityConstant.TYPE_SCOPE, 
 					parentFacilityId,
-					new Integer(DEFAULT_SORT_ORDER), 
+					new Integer(sortOrder), 
 					new Boolean(false)
 					);
 			
@@ -135,13 +165,9 @@ public class ModifyFacility {
 			throw e;
 		}
 		
-		try {
-			//Topicに送信
-			SendTopic send = new SendTopic(TopicConstant.TOPIC_NAME_EXECUTE);
-			send.put(new UpdateRepositoryInfo());
-		} catch (Exception e) {
-			m_log.debug("addScope() : 更新情報送信エラー : " + e.getMessage());
-		}
+		//Topicに送信			
+		if(sendFlg)
+			SendTopic.sendTopic(TopicConstant.TOPIC_NAME_EXECUTE);
 	}
 	
 	/**
@@ -152,6 +178,18 @@ public class ModifyFacility {
 	 * @throws FinderException
 	 */
 	public void modifyScope(Property property) throws NamingException, FinderException  {
+		modifyScope(property, true);
+	}
+
+	/**
+	 * スコープ変更
+	 * 
+	 * @param property
+	 * @param sendFlg
+	 * @throws NamingException
+	 * @throws FinderException
+	 */
+	public void modifyScope(Property property, boolean sendFlg) throws NamingException, FinderException  {
     	//アクセスロック
     	AccessLock.lock(AccessLock.REPOSITORY);
     	
@@ -173,13 +211,10 @@ public class ModifyFacility {
 			//説明設定
 			facility.setDescription(checkString(description.get(0)));
 			
-			try {
-				//Topicに送信
-				SendTopic send = new SendTopic(TopicConstant.TOPIC_NAME_EXECUTE);
-				send.put(new UpdateRepositoryInfo());
-			} catch (Exception e) {
-				m_log.debug("addScope() : 更新情報送信エラー : " + e.getMessage());
-			}
+			//Topicに送信			
+			if(sendFlg)
+				SendTopic.sendTopic(TopicConstant.TOPIC_NAME_EXECUTE);
+			
 		} catch (EJBException e) {
             AplLogger apllog = new AplLogger("REP", "rep");
             String[] args = {(String)facilityId.get(0)};
@@ -197,6 +232,7 @@ public class ModifyFacility {
 		}
 	}
 	
+
 	/**
 	 * スコープへのノード割当て
 	 * 
@@ -206,6 +242,20 @@ public class ModifyFacility {
 	 * @throws CreateException
 	 */
 	public void assignNodeScope(String parentFacilityId, String[] facilityIds) throws NamingException, CreateException, FinderException {
+		assignNodeScope(parentFacilityId, facilityIds, true);
+	}
+
+	/**
+	 * スコープへのノード割当て
+	 * 
+	 * @param parentFacilityId
+	 * @param facilityIds
+	 * @param sendFlg
+	 * @throws NamingException
+	 * @throws CreateException
+	 * @throws FinderException
+	 */
+	public void assignNodeScope(String parentFacilityId, String[] facilityIds, boolean sendFlg) throws NamingException, CreateException, FinderException {
     	//アクセスロック
     	AccessLock.lock(AccessLock.REPOSITORY);
     	
@@ -228,13 +278,10 @@ public class ModifyFacility {
 			                valid);
 			}
 			
-			try {
-				//Topicに送信
-				SendTopic send = new SendTopic(TopicConstant.TOPIC_NAME_EXECUTE);
-				send.put(new UpdateRepositoryInfo());
-			} catch (Exception e) {
-				m_log.debug("addScope() : 更新情報送信エラー : " + e.getMessage());
-			}
+			//Topicに送信			
+			if(sendFlg)
+				SendTopic.sendTopic(TopicConstant.TOPIC_NAME_EXECUTE);
+			
 		} catch (EJBException e) {
             AplLogger apllog = new AplLogger("REP", "rep");
             String[] args = {facilityId, parentFacilityId};
@@ -253,7 +300,7 @@ public class ModifyFacility {
 		}
 	}
 		
-	
+
 	/**
 	 * ノード追加
 	 * 
@@ -263,23 +310,35 @@ public class ModifyFacility {
 	 * @throws CreateException
 	 */
 	public void addNode(Property property, String user) throws NamingException, CreateException  {
+		addNode(property, user, true);
+	}
+
+
+	/**
+	 * ノード追加
+	 * 
+	 * @param property
+	 * @param user
+	 * @param sendFlg
+	 * @throws NamingException
+	 * @throws CreateException
+	 */
+	public void addNode(Property property, String user, boolean sendFlg) throws NamingException, CreateException  {
     	//アクセスロック
     	AccessLock.lock(AccessLock.REPOSITORY);
 		
 		String facilityId = null;
-		try {
+	    try {
 			ArrayList values = null;
-			
 			//現在日時を取得
 			Date now = new Date();
 			
 			//ファシリティID取得
 			values = PropertyUtil.getPropertyValue(property, NodeProperty.FACILITY_ID);
-			facilityId = checkString(values.get(0));
+			facilityId = (String)values.get(0);
 			//ファシリティ名取得
 			values = PropertyUtil.getPropertyValue(property, NodeProperty.FACILITY_NAME);
-			String facilityName = checkString(values.get(0));
-			
+			String facilityName = (String)values.get(0);
 			
 			//Facilityを作成
 			FacilityLocal facility = FacilityUtil.getLocalHome().create(
@@ -415,15 +474,51 @@ public class ModifyFacility {
 			values = PropertyUtil.getPropertyValue(property, NodeProperty.VIRTSOLUTION);
 			facility.setVirtSolution(checkString(values.get(0)));
 			
+			//20090114
+			
+			//仮想マシンID
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.VMID);
+			facility.setVmId(checkString(values.get(0)));
+
+			//仮想化ソフト接続ユーザ
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.VMUSER);
+			facility.setVmUser(checkString(values.get(0)));
+
+			//仮想化ソフト接続ユーザパスワード
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.VMUSERPASSWORD);
+			facility.setVmUserpassword(checkString(values.get(0)));
+
+			//仮想化ソフト接続プロトコル
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.VMPROTOCOL);
+			facility.setVmProtocol(checkString(values.get(0)));
+			
+			//WBEM接続ユーザ
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.WBEM_USER);
+			facility.setWbemUser(checkString(values.get(0)));
+			//WBEM接続ユーザパスワード
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.WBEM_USER_PASSWORD);
+			facility.setWbemUserPassword(checkString(values.get(0)));
+			//WBEM接続ポート番号
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.WBEM_PORT);
+			facility.setWbemPort(checkInteger(values.get(0)));
+			//WBEM接続プロトコル
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.WBEM_PROTOCOL);
+			facility.setWbemProtocol(checkString(values.get(0)));
+			//WBEM接続タイムアウト
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.WBEM_TIMEOUT);
+			facility.setWbemTimeout(checkInteger(values.get(0)));
+			//WBEM接続リトライ回数
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.WBEM_RETRIES);
+			facility.setWbemRetries(checkInteger(values.get(0)));
 			
 //			FIXME　ソートの順番はとりあえずオンコードで100とする。
 		
 			facility.setSortValue(new Integer(DEFAULT_SORT_ORDER));
-//			
-//			//nullをセットすることでstore()を呼び出す。
-//			facility = null;
-//
-//			//デバイスの配列を取得
+			
+			//nullをセットすることでstore()を呼び出す。
+			facility = null;
+
+			//デバイスの配列を取得
 			ArrayList deviceList = PropertyUtil.getProperty(property, NodeProperty.DEVICE);
 			for(int i = 0; i < deviceList.size(); i++){
 			    //デバイスINDEXを取得
@@ -435,27 +530,34 @@ public class ModifyFacility {
 				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_TYPE);
 				String deviceType = checkString(values.get(0));
 				
-				//デバイス名を取得し、DeviceInfoに設定
-				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_NAME);
-				String deviceName = checkString(values.get(0));
-				//デバイスOIDを取得し、DeviceInfoに設定
-				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_OID);
-				String snmpOID = checkString(values.get(0));
-				//説明を取得し、DeviceInfoに設定
-				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_DESCRIPTION);
-				String description = checkString(values.get(0));
+				if(deviceIndex != null && deviceType != null && !deviceType.equals("")){
+					//DeviceInfoを作成
+					DeviceInfoLocal device = DeviceInfoUtil.getLocalHome().create(
+							deviceIndex, 
+							deviceType,
+							facilityId);
 				
-				// デバイスを登録しない場合はcontinue
-				if (deviceIndex == null && deviceName == null &&
-						deviceType == null && snmpOID == null && description == null) {
-					continue;
+					if(device != null){
+						//デバイス表示名を取得し、DeviceInfoに設定
+						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_DISPLAY_NAME);
+						device.setDisplayName(checkString(values.get(0)));
+						//デバイス名を取得し、DeviceInfoに設定
+						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_NAME);
+						device.setDeviceName(checkString(values.get(0)));
+					    //デバイスINDEXを取得し、DeviceInfoに設定
+						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_INDEX);
+						device.setDeviceIndex(checkInteger(values.get(0)));
+						//デバイスOIDを取得し、DeviceInfoに設定
+						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_OID);
+						device.setSnmpOID(checkString(values.get(0)));
+						//デバイスタイプを取得し、DeviceInfoに設定
+						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_TYPE);
+						device.setDeviceType(checkString(values.get(0)));
+						//説明を取得し、DeviceInfoに設定
+						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_DESCRIPTION);
+						device.setDescription(checkString(values.get(0)));
+					}
 				}
-				
-				//dn, cnはDeviceInfoDAOImplで生成する
-				DeviceInfoLocal device = DeviceInfoUtil.getLocalHome()
-						.create(deviceIndex, deviceName, deviceType, snmpOID, description,
-								facilityId);
-				
 			}
 			
 			//ファイルシステムの配列を取得
@@ -466,36 +568,36 @@ public class ModifyFacility {
 				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_INDEX);
 				Integer cn = checkInteger(values.get(0));
 				
-				//マウント位置を取得し、FileSystemInfoに設定
-				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_MOUNT_POINT);
-				String fileSystemMountPoint = checkString(values.get(0));
-				//ファイルシステムOIDを取得し、FileSystemInfoに設定
-				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_OID);
-				String snmpOID = checkString(values.get(0));
-				//ファイルシステムタイプを取得し、FileSystemInfoに設定
-				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_TYPE);
-				String fileSystemType = checkString(values.get(0));
-				//説明を取得し、FileSystemInfoに設定
-				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_DESCRIPTION);
-				String description = checkString(values.get(0));
-				
 				if(cn != null){
-					//dnはFileSystemInfoDAOImplで生成する
-					FileSystemInfoLocal fileSystem = FileSystemInfoUtil
-							.getLocalHome().create(cn, fileSystemMountPoint,
-									fileSystemType, snmpOID, description,
-									facilityId);
-					
+					//FileSystemInfoを作成
+					FileSystemInfoLocal fileSystem = FileSystemInfoUtil.getLocalHome().create(
+							cn, 
+							facilityId);
+				
+					if(fileSystem != null){
+						//ファイルシステム表示名を取得し、FileSystemInfoに設定
+						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_DISPLAY_NAME);
+						fileSystem.setDisplayName(checkString(values.get(0)));
+					    //マウント位置を取得し、FileSystemInfoに設定
+						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_MOUNT_POINT);
+						fileSystem.setFileSystemMountPoint(checkString(values.get(0)));
+						//ファイルシステムOIDを取得し、FileSystemInfoに設定
+						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_OID);
+						fileSystem.setSnmpOID(checkString(values.get(0)));
+						//ファイルシステムタイプを取得し、FileSystemInfoに設定
+						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_TYPE);
+						fileSystem.setFileSystemType(checkString(values.get(0)));
+						//説明を取得し、FileSystemInfoに設定
+						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_DESCRIPTION);
+						fileSystem.setDescription(checkString(values.get(0)));
+					}
 				}
 			}
 			
-			try {
-				//Topicに送信
-				SendTopic send = new SendTopic(TopicConstant.TOPIC_NAME_EXECUTE);
-				send.put(new UpdateRepositoryInfo());
-			} catch (Exception e) {
-				m_log.debug("addScope() : 更新情報送信エラー : " + e.getMessage());
-			}
+			//Topicに送信			
+			if(sendFlg)
+				SendTopic.sendTopic(TopicConstant.TOPIC_NAME_EXECUTE);
+			
 		} catch (EJBException e) {
             AplLogger apllog = new AplLogger("REP", "rep");
             String[] args = {facilityId};
@@ -505,7 +607,7 @@ public class ModifyFacility {
 			throw e;
 		}
 	}
-	
+
 	/**
 	 * ノード変更
 	 * 
@@ -516,6 +618,20 @@ public class ModifyFacility {
 	 * @throws CreateException
 	 */
 	public void modifyNode(Property property, String user) throws NamingException, FinderException, CreateException  {
+		modifyNode(property, user, true);
+	}
+
+	/**
+	 * ノード変更
+	 * 
+	 * @param property
+	 * @param user
+	 * @param sendFlg
+	 * @throws NamingException
+	 * @throws FinderException
+	 * @throws CreateException
+	 */
+	public void modifyNode(Property property, String user, boolean sendFlg) throws NamingException, FinderException, CreateException  {
     	//アクセスロック
     	AccessLock.lock(AccessLock.REPOSITORY);
     	
@@ -662,6 +778,43 @@ public class ModifyFacility {
 			values = PropertyUtil.getPropertyValue(property, NodeProperty.VIRTSOLUTION);
 			facility.setVirtSolution(checkString(values.get(0)));
 			
+			//20090114
+			
+			//仮想マシンID
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.VMID);
+			facility.setVmId(checkString(values.get(0)));
+
+			//仮想化ソフト接続ユーザ
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.VMUSER);
+			facility.setVmUser(checkString(values.get(0)));
+
+			//仮想化ソフト接続ユーザパスワード
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.VMUSERPASSWORD);
+			facility.setVmUserpassword(checkString(values.get(0)));
+
+			//仮想化ソフト接続プロトコル
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.VMPROTOCOL);
+			facility.setVmProtocol(checkString(values.get(0)));
+
+			//WBEM接続ユーザ
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.WBEM_USER);
+			facility.setWbemUser(checkString(values.get(0)));
+			//WBEM接続ユーザパスワード
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.WBEM_USER_PASSWORD);
+			facility.setWbemUserPassword(checkString(values.get(0)));
+			//WBEM接続ポート番号
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.WBEM_PORT);
+			facility.setWbemPort(checkInteger(values.get(0)));
+			//WBEM接続プロトコル
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.WBEM_PROTOCOL);
+			facility.setWbemProtocol(checkString(values.get(0)));
+			//WBEM接続タイムアウト
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.WBEM_TIMEOUT);
+			facility.setWbemTimeout(checkInteger(values.get(0)));
+			//WBEM接続リトライ回数
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.WBEM_RETRIES);
+			facility.setWbemRetries(checkInteger(values.get(0)));
+			
 		    //Facilityと関連しているデバイスを削除
 			try {
 				//Facilityと関連しているデバイスを取得
@@ -674,8 +827,6 @@ public class ModifyFacility {
 					device = (DeviceInfoLocal)itr.next();
 					device.remove();
 				}
-			} catch (FinderException e) {
-			    m_log.debug("modifyNode() : " + e.getMessage());
 			} catch (EJBException e) {
 			    m_log.debug("modifyNode() : " + e.getMessage());
 			} catch (RemoveException e) {
@@ -700,27 +851,34 @@ public class ModifyFacility {
 				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_TYPE);
 				String deviceType = checkString(values.get(0));
 				
-				//デバイス名を取得し、DeviceInfoに設定
-				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_NAME);
-				String deviceName = checkString(values.get(0));
-				//デバイスOIDを取得し、DeviceInfoに設定
-				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_OID);
-				String snmpOID = checkString(values.get(0));
-				//説明を取得し、DeviceInfoに設定
-				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_DESCRIPTION);
-				String description = checkString(values.get(0));
-				
-				// デバイスを登録しない場合はcontinue
-				if (deviceIndex == null && deviceName == null &&
-						deviceType == null && snmpOID == null && description == null) {
-					continue;
+				if(deviceIndex != null && deviceType != null && !deviceType.equals("")){
+					//DeviceInfoを作成
+					DeviceInfoLocal device = DeviceInfoUtil.getLocalHome().create(
+							deviceIndex, 
+							deviceType,
+							facilityId);
+	
+					if(device != null){
+						//デバイス表示名を取得し、DeviceInfoに設定
+						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_DISPLAY_NAME);
+						device.setDisplayName(checkString(values.get(0)));
+					    //デバイス名を取得し、DeviceInfoに設定
+						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_NAME);
+						device.setDeviceName(checkString(values.get(0)));
+					    //デバイスINDEXを取得し、DeviceInfoに設定
+						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_INDEX);
+						device.setDeviceIndex(checkInteger(values.get(0)));
+						//デバイスOIDを取得し、DeviceInfoに設定
+						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_OID);
+						device.setSnmpOID(checkString(values.get(0)));
+						//デバイスタイプを取得し、DeviceInfoに設定
+						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_TYPE);
+						device.setDeviceType(checkString(values.get(0)));
+						//説明を取得し、DeviceInfoに設定
+						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_DESCRIPTION);
+						device.setDescription(checkString(values.get(0)));
+					}
 				}
-				
-				//dn, cnはDeviceInfoDAOImplで生成する
-				DeviceInfoLocal device = DeviceInfoUtil.getLocalHome()
-						.create(deviceIndex, deviceName, deviceType, snmpOID, description,
-								facilityId);
-				
 			}
 			
 			//Facilityと関連しているファイルシステムを削除
@@ -735,13 +893,13 @@ public class ModifyFacility {
 					fileSystem = (FileSystemInfoLocal)itr.next();
 					fileSystem.remove();
 				}
-			} catch (FinderException e) {
-			    m_log.debug("modifyNode() : " + e.getMessage());
 			} catch (EJBException e) {
 			    m_log.debug("modifyNode() : " + e.getMessage());
 			} catch (RemoveException e) {
 			    m_log.debug("modifyNode() : " + e.getMessage());
 			}
+			//nullをセットすることでstore()を呼び出す。
+			facility = null;
 			
 			//ファイルシステムの配列を取得
 			ArrayList fileSystemList = PropertyUtil.getProperty(property, NodeProperty.FILE_SYSTEM);
@@ -753,35 +911,36 @@ public class ModifyFacility {
 				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_INDEX);
 				Integer cn = checkInteger(values.get(0));
 				
-				//マウント位置を取得し、FileSystemInfoに設定
-				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_MOUNT_POINT);
-				String fileSystemMountPoint = checkString(values.get(0));
-				//ファイルシステムOIDを取得し、FileSystemInfoに設定
-				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_OID);
-				String snmpOID = checkString(values.get(0));
-				//ファイルシステムタイプを取得し、FileSystemInfoに設定
-				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_TYPE);
-				String fileSystemType = checkString(values.get(0));
-				//説明を取得し、FileSystemInfoに設定
-				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_DESCRIPTION);
-				String description = checkString(values.get(0));
+				if(cn != null){					
+					//FileSystemInfoを作成
+					FileSystemInfoLocal fileSystem = FileSystemInfoUtil.getLocalHome().create(
+							cn, 
+							facilityId);
 				
-				if(cn != null){
-					//dnはFileSystemInfoDAOImplで生成する
-					FileSystemInfoLocal fileSystem = FileSystemInfoUtil
-							.getLocalHome().create(cn, fileSystemMountPoint,
-									fileSystemType, snmpOID, description,
-									facilityId);
+					if(fileSystem != null){
+						//ファイルシステム表示名を取得し、FileSystemInfoに設定
+						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_DISPLAY_NAME);
+						fileSystem.setDisplayName(checkString(values.get(0)));
+					    //マウント位置を取得し、FileSystemInfoに設定
+						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_MOUNT_POINT);
+						fileSystem.setFileSystemMountPoint(checkString(values.get(0)));
+						//ファイルシステムOIDを取得し、FileSystemInfoに設定
+						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_OID);
+						fileSystem.setSnmpOID(checkString(values.get(0)));
+						//ファイルシステムタイプを取得し、FileSystemInfoに設定
+						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_TYPE);
+						fileSystem.setFileSystemType(checkString(values.get(0)));
+						//説明を取得し、FileSystemInfoに設定
+						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_DESCRIPTION);
+						fileSystem.setDescription(checkString(values.get(0)));
+					}
 				}
 			}
 			
-			try {
-				//Topicに送信
-				SendTopic send = new SendTopic(TopicConstant.TOPIC_NAME_EXECUTE);
-				send.put(new UpdateRepositoryInfo());
-			} catch (Exception e) {
-				m_log.debug("addScope() : 更新情報送信エラー : " + e.getMessage());
-			}
+			//Topicに送信			
+			if(sendFlg)
+				SendTopic.sendTopic(TopicConstant.TOPIC_NAME_EXECUTE);
+			
 		} catch (EJBException e) {
             AplLogger apllog = new AplLogger("REP", "rep");
             String[] args = {facilityId};
@@ -809,6 +968,20 @@ public class ModifyFacility {
 	 * @throws FinderException
 	 */
 	public void modifyAllNode(Property property, String parentFacilityId, String user) throws NamingException, FinderException {
+		modifyAllNode(property,parentFacilityId,user, true);
+	}
+
+	/**
+	 * ノード変更(一括)
+	 * 
+	 * @param property
+	 * @param parentFacilityId
+	 * @param user
+	 * @param sendFlg
+	 * @throws NamingException
+	 * @throws FinderException
+	 */
+	public void modifyAllNode(Property property, String parentFacilityId, String user, boolean sendFlg) throws NamingException, FinderException {
     	//アクセスロック
     	AccessLock.lock(AccessLock.REPOSITORY);
     	
@@ -985,6 +1158,45 @@ public class ModifyFacility {
 					values = PropertyUtil.getProperty(property, NodeProperty.VIRTSOLUTION);
 					facility.setVirtSolution(checkString(values.get(0)));
 					
+					
+					//20090114
+					
+					//仮想マシンID
+					values = PropertyUtil.getProperty(property, NodeProperty.VMID);
+					facility.setVmId(checkString(values.get(0)));
+
+					//仮想化ソフト接続ユーザ
+					values = PropertyUtil.getProperty(property, NodeProperty.VMUSER);
+					facility.setVmUser(checkString(values.get(0)));
+
+					//仮想化ソフト接続ユーザパスワード
+					values = PropertyUtil.getProperty(property, NodeProperty.VMUSERPASSWORD);
+					facility.setVmUserpassword(checkString(values.get(0)));
+
+					
+					//仮想化ソフト接続プロトコル
+					values = PropertyUtil.getProperty(property, NodeProperty.VMPROTOCOL);
+					facility.setVmProtocol(checkString(values.get(0)));
+
+					//WBEM接続ユーザ
+					values = PropertyUtil.getPropertyValue(property, NodeProperty.WBEM_USER);
+					facility.setWbemUser(checkString(values.get(0)));
+					//WBEM接続ユーザパスワード
+					values = PropertyUtil.getPropertyValue(property, NodeProperty.WBEM_USER_PASSWORD);
+					facility.setWbemUserPassword(checkString(values.get(0)));
+					//WBEM接続ポート番号
+					values = PropertyUtil.getPropertyValue(property, NodeProperty.WBEM_PORT);
+					facility.setWbemPort(checkInteger(values.get(0)));
+					//WBEM接続プロトコル
+					values = PropertyUtil.getPropertyValue(property, NodeProperty.WBEM_PROTOCOL);
+					facility.setWbemProtocol(checkString(values.get(0)));
+					//WBEM接続タイムアウト
+					values = PropertyUtil.getPropertyValue(property, NodeProperty.WBEM_TIMEOUT);
+					facility.setWbemTimeout(checkInteger(values.get(0)));
+					//WBEM接続リトライ回数
+					values = PropertyUtil.getPropertyValue(property, NodeProperty.WBEM_RETRIES);
+					facility.setWbemRetries(checkInteger(values.get(0)));
+					
 					//デバイスの配列を取得
 					ArrayList deviceList = PropertyUtil.getProperty(property, NodeProperty.DEVICE);
 				    //デバイス名を取得
@@ -1004,8 +1216,6 @@ public class ModifyFacility {
 								device = (DeviceInfoLocal)itr1.next();
 								device.remove();
 							}
-						} catch (FinderException e) {
-						    m_log.debug("modifyAllNode() : " + e.getMessage());
 						} catch (EJBException e) {
 						    m_log.debug("modifyAllNode() : " + e.getMessage());
 						} catch (RemoveException e) {
@@ -1032,6 +1242,9 @@ public class ModifyFacility {
 									facility.getFacilityId());
 			
 							if(device != null){
+								//デバイス表示名を取得し、DeviceInfoに設定
+								values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_DISPLAY_NAME);
+								device.setDisplayName(checkString(values.get(0)));
 							    //デバイス名を取得し、DeviceInfoに設定
 								values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_NAME);
 								device.setDeviceName(checkString(values.get(0)));
@@ -1072,8 +1285,6 @@ public class ModifyFacility {
 								fileSystem = (FileSystemInfoLocal)itr1.next();
 								fileSystem.remove();
 							}
-						} catch (FinderException e) {
-						    m_log.debug("modifyAllNode() : " + e.getMessage());
 						} catch (EJBException e) {
 						    m_log.debug("modifyAllNode() : " + e.getMessage());
 						} catch (RemoveException e) {
@@ -1095,6 +1306,9 @@ public class ModifyFacility {
 									facility.getFacilityId());
 						
 							if(fileSystem != null){
+								//ファイルシステム表示名を取得し、FileSystemInfoに設定
+								values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_DISPLAY_NAME);
+								fileSystem.setDisplayName(checkString(values.get(0)));
 							    //マウント位置を取得し、FileSystemInfoに設定
 								values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_MOUNT_POINT);
 								fileSystem.setFileSystemMountPoint(checkString(values.get(0)));
@@ -1116,20 +1330,36 @@ public class ModifyFacility {
 				}
 			}
 			
-			try {
-				//Topicに送信
-				SendTopic send = new SendTopic(TopicConstant.TOPIC_NAME_EXECUTE);
-				send.put(new UpdateRepositoryInfo());
-			} catch (Exception e) {
-				m_log.debug("addScope() : 更新情報送信エラー : " + e.getMessage());
-			}
+			//Topicに送信			
+			if(sendFlg)
+				SendTopic.sendTopic(TopicConstant.TOPIC_NAME_EXECUTE);
+			
 		} catch (EJBException e) {
 		    m_log.debug("modifyAllNode() : " + e.getMessage());
 			throw e;
 		}
 	}
-	
+
+	/**
+	 * 有効/無効の修正
+	 * 
+	 * @param property
+	 * @throws FinderException
+	 * @throws NamingException
+	 */
 	public void modifyFacilityTreeValid(Property property) throws FinderException, NamingException {
+		modifyFacilityTreeValid(property, true);
+	}
+
+	/**
+	 * 有効/無効の修正
+	 * 
+	 * @param property
+	 * @param sendFlg
+	 * @throws FinderException
+	 * @throws NamingException
+	 */
+	public void modifyFacilityTreeValid(Property property, boolean sendFlg) throws FinderException, NamingException {
     	//アクセスロック
     	AccessLock.lock(AccessLock.REPOSITORY);
   	
@@ -1160,13 +1390,10 @@ public class ModifyFacility {
 //				facilitytree = null;
 			}
 
-			try {
-				//Topicに送信
-				SendTopic send = new SendTopic(TopicConstant.TOPIC_NAME_EXECUTE);
-				send.put(new UpdateRepositoryInfo());
-			} catch (Exception e) {
-				m_log.debug("addScope() : 更新情報送信エラー : " + e.getMessage());
-			}
+			//Topicに送信			
+			if(sendFlg)
+				SendTopic.sendTopic(TopicConstant.TOPIC_NAME_EXECUTE);
+			
 				
 		} catch (FinderException e) {
 			m_log.error("modifyFacilityTreeValid() : findByFacilityId() failure ", e);
@@ -1399,6 +1626,58 @@ public class ModifyFacility {
             	facility.setVirtSolution(attribute);
             }
 
+
+            //20090114
+            
+            if(attributes.get(FacilityAttributeConstant.VMID) != null){
+            	String attribute = (String)attributes.get(FacilityAttributeConstant.VMID);
+            	facility.setVmId(attribute);
+            }
+            if(attributes.get(FacilityAttributeConstant.VMUSER) != null){
+            	String attribute = (String)attributes.get(FacilityAttributeConstant.VMUSER);
+            	facility.setVmUser(attribute);
+            }
+            if(attributes.get(FacilityAttributeConstant.VMUSERPASSWORD) != null){
+            	//ccSnmpVersion取得
+            	String attribute = (String)attributes.get(FacilityAttributeConstant.VMUSERPASSWORD);
+            	facility.setVmUserpassword(attribute);
+            }
+            if(attributes.get(FacilityAttributeConstant.VMPROTOCOL) != null){
+            	//ccSnmpVersion取得
+            	String attribute = (String)attributes.get(FacilityAttributeConstant.VMPROTOCOL);
+            	facility.setVmProtocol(attribute);
+            }
+
+            if(attributes.get(FacilityAttributeConstant.WBEMUSER) != null){
+            	//ccWbemUser取得
+            	String attribute = (String)attributes.get(FacilityAttributeConstant.WBEMUSER);
+            	facility.setWbemUser(attribute);
+            }
+            if(attributes.get(FacilityAttributeConstant.WBEMUSERPASSWORD) != null){
+            	//ccWbemUserPassword取得
+            	String attribute = (String)attributes.get(FacilityAttributeConstant.WBEMUSERPASSWORD);
+            	facility.setWbemUserPassword(attribute);
+            }
+            if(attributes.get(FacilityAttributeConstant.WBEMPORT) != null){
+            	//ccWbemPort取得
+            	Integer attribute = (Integer)attributes.get(FacilityAttributeConstant.WBEMPORT);
+            	facility.setWbemPort(attribute);
+            }
+            if(attributes.get(FacilityAttributeConstant.WBEMPROTOCOL) != null){
+            	//ccWbemProtocol取得
+            	String attribute = (String)attributes.get(FacilityAttributeConstant.WBEMPROTOCOL);
+            	facility.setWbemProtocol(attribute);
+            }
+            if(attributes.get(FacilityAttributeConstant.WBEMTIMEOUT) != null){
+            	//ccWbemTimeout取得
+            	Integer attribute = (Integer)attributes.get(FacilityAttributeConstant.WBEMTIMEOUT);
+            	facility.setWbemTimeout(attribute);
+            }
+            if(attributes.get(FacilityAttributeConstant.WBEMRETRIES) != null){
+            	//ccWbemRetries取得
+            	Integer attribute = (Integer)attributes.get(FacilityAttributeConstant.WBEMRETRIES);
+            	facility.setWbemRetries(attribute);
+            }
             
         } catch (FinderException e) {
             m_log.debug("setNodeDetail() : " + e.getMessage());
