@@ -17,6 +17,7 @@ package com.clustercontrol.repository.factory;
 
 import java.util.ArrayList;
 import java.util.Collection;
+import java.util.HashMap;
 import java.util.Iterator;
 import java.util.Locale;
 
@@ -30,6 +31,8 @@ import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.bean.PropertyConstant;
 import com.clustercontrol.bean.SnmpVersionConstant;
+import com.clustercontrol.repository.bean.FacilityAttributeConstant;
+import com.clustercontrol.repository.bean.FacilityTreeAttributeConstant;
 import com.clustercontrol.repository.ejb.entity.CollectorPlatformMstLocal;
 import com.clustercontrol.repository.ejb.entity.CollectorPlatformMstUtil;
 import com.clustercontrol.repository.ejb.entity.DeviceInfoLocal;
@@ -38,6 +41,10 @@ import com.clustercontrol.repository.ejb.entity.FacilityUtil;
 import com.clustercontrol.repository.ejb.entity.FileSystemInfoLocal;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
+import com.clustercontrol.vm.ejb.entity.VmProtocolMstLocal;
+import com.clustercontrol.vm.ejb.entity.VmProtocolMstUtil;
+import com.clustercontrol.vm.ejb.entity.VmSolutionMstLocal;
+import com.clustercontrol.vm.ejb.entity.VmSolutionMstUtil;
 
 /**
  * ノード用プロパティを作成するクラス<BR>
@@ -124,6 +131,8 @@ public class NodeProperty {
 	public static final String DEVICE_TYPE = "deviceType";
 	/** デバイス説明 */
 	public static final String DEVICE_DESCRIPTION = "deviceDescription";
+	/** デバイス表示名 */
+	public static final String DEVICE_DISPLAY_NAME = "deviceDisplayName";
 	
 	/** マウント位置 */
 	public static final String FILE_SYSTEM_MOUNT_POINT = "fileSystemMountPoint";
@@ -135,6 +144,8 @@ public class NodeProperty {
 	public static final String FILE_SYSTEM_TYPE = "fileSystemType";
 	/** ファイルシステム説明 */
 	public static final String FILE_SYSTEM_DESCRIPTION = "fileSystemDescription";
+	/** ファイルシステム表示名 */
+	public static final String FILE_SYSTEM_DISPLAY_NAME = "fileSystemDisplayName";
 	
 	/** ネットワーク */
 	public static final String NETWORK = "network";
@@ -148,6 +159,8 @@ public class NodeProperty {
 	public static final String FILE_SYSTEM = "fileSystem";
 	/** SNMP */
 	public static final String SNMP ="snmp";
+	/** WBEM */
+	public static final String WBEM = "wbem";
 	
 	/** 有効/無効フラグ */
 	public static final String VALID = "valid";
@@ -165,6 +178,25 @@ public class NodeProperty {
 	public static final String VMNAME= "VMName";
 	public static final String VIRTSOLUTION= "virtualizationSolution";
 	
+	//20090114 add
+	public static final String VMID = "vmId";
+	public static final String VMUSER= "vmUser";
+	public static final String VMUSERPASSWORD= "vmUserPassword";
+	public static final String VMPROTOCOL= "vmProtocol";
+	
+	/** WBEM接続ユーザ*/
+	public static final String WBEM_USER = "wbemUser";
+	/** WBEM接続ユーザパスワード */
+	public static final String WBEM_USER_PASSWORD = "wbemUserPassword";
+	/** WBEM接続ポート番号 */
+	public static final String WBEM_PORT = "wbemPort";
+	/** WBEM接続プロトコル */
+	public static final String WBEM_PROTOCOL = "wbemProtocol";
+	/** WBEM接続タイムアウト*/
+	public static final String WBEM_TIMEOUT = "wbemTimeout";
+	/** WBEM接続リトライ回数 */
+	public static final String WBEM_RETRIES = "wbemRetries";
+	
 	/**
 	 * ノード用プロパティを返します。
 	 * 
@@ -439,6 +471,67 @@ public class NodeProperty {
 					((Property)propertyList.get(0)).setValue(facility.getVirtSolution());
 				}
 				
+				//20090114 add
+				
+				//仮想マシンID
+				propertyList = PropertyUtil.getProperty(property, VMID);
+				if(facility.getVmId() != null){
+					((Property)propertyList.get(0)).setValue(facility.getVmId());
+				}
+
+				//仮想化ソフト接続ユーザ
+				propertyList = PropertyUtil.getProperty(property, VMUSER);
+				if(facility.getVmUser() != null){
+					((Property)propertyList.get(0)).setValue(facility.getVmUser());
+				}
+
+				//仮想化ソフト接続ユーザパスワード
+				propertyList = PropertyUtil.getProperty(property, VMUSERPASSWORD);
+				if(facility.getVmUserpassword() != null){
+					((Property)propertyList.get(0)).setValue(facility.getVmUserpassword());
+				}
+
+				//仮想化ソフト接続プロトコル
+				propertyList = PropertyUtil.getProperty(property, VMPROTOCOL);
+				if(facility.getVmProtocol() != null){
+					((Property)propertyList.get(0)).setValue(facility.getVmProtocol());
+				}
+
+				//WBEM接続ユーザ
+				propertyList = PropertyUtil.getProperty(property, WBEM_USER);
+				if(facility.getWbemUser() != null){
+					((Property)propertyList.get(0)).setValue(facility.getWbemUser());
+				}
+				
+				//WBEM接続ユーザパスワード
+				propertyList = PropertyUtil.getProperty(property, WBEM_USER_PASSWORD);
+				if(facility.getWbemUserPassword() != null){
+					((Property)propertyList.get(0)).setValue(facility.getWbemUserPassword());
+				}
+				
+				//WBEM接続ポート番号
+				propertyList = PropertyUtil.getProperty(property, WBEM_PORT);
+				if(facility.getWbemPort() != null){
+					((Property)propertyList.get(0)).setValue(facility.getWbemPort());
+				}
+				
+				//WBEM接続プロトコル
+				propertyList = PropertyUtil.getProperty(property, WBEM_PROTOCOL);
+				if(facility.getWbemProtocol() != null){
+					((Property)propertyList.get(0)).setValue(facility.getWbemProtocol());
+				}
+				
+				//WBEM接続タイムアウト
+				propertyList = PropertyUtil.getProperty(property, WBEM_TIMEOUT);
+				if(facility.getWbemTimeout() != null){
+					((Property)propertyList.get(0)).setValue(facility.getWbemTimeout());
+				}
+				
+				//WBEM接続リトライ回数
+				propertyList = PropertyUtil.getProperty(property, WBEM_RETRIES);
+				if(facility.getWbemRetries() != null){
+					((Property)propertyList.get(0)).setValue(facility.getWbemRetries());
+				}
 				
 				//デバイス
 				propertyList = PropertyUtil.getProperty(property, DEVICE);
@@ -447,19 +540,21 @@ public class NodeProperty {
 				
 				//デバイスを取得
 				Collection deviceList = null;
-				try {
-					deviceList = facility.getDeviceInfo();
-				} catch (FinderException e) {
-				}
+				deviceList = facility.getDeviceInfo();
 				if(deviceList != null){
 					Iterator itr = deviceList.iterator();
 					int i = 0;
 					while(itr.hasNext()){
 						DeviceInfoLocal d = (DeviceInfoLocal)itr.next();
 						if(i == 0){
-							//デバイスと書いてあるところにデバイス名を表示
-							deviceProperty.setValue(d.getDeviceName());
+							//デバイス表示名を表示
+							deviceProperty.setValue(d.getDisplayName());
 							
+							//デバイス表示名
+							propertyList = PropertyUtil.getProperty(deviceProperty, DEVICE_DISPLAY_NAME);
+							if(d.getDisplayName() != null && d.getDisplayName().compareTo("") != 0){
+								((Property)propertyList.get(0)).setValue(d.getDisplayName());
+							}
 							//デバイス名
 							propertyList = PropertyUtil.getProperty(deviceProperty, DEVICE_NAME);
 							if(d.getDeviceName() != null && d.getDeviceName().compareTo("") != 0){
@@ -485,13 +580,28 @@ public class NodeProperty {
 							if(d.getDescription() != null && d.getDescription().compareTo("") != 0){
 								((Property)propertyList.get(0)).setValue(d.getDescription());
 							}
+							m_log.debug("i==0");
+							m_log.debug("d.getDisplayName() = " + d.getDisplayName());
+							m_log.debug("d.getDeviceName() = " + d.getDeviceName());
+							m_log.debug("d.getSnmpOID() = " + d.getSnmpOID());
+							m_log.debug("d.getDeviceIndex() = " + d.getDeviceIndex());
+							m_log.debug("d.getDeviceType() = " + d.getDeviceType());
+							m_log.debug("d.getDescription() = " + d.getDescription());
+							m_log.debug("d.getFacilityId() = " + d.getFacilityId());
+							m_log.debug("d.getCn() = " + d.getCn());
+							m_log.debug("d.getDn() = " + d.getDn());
 						}
 						else{
 							Property copy = PropertyUtil.copy(deviceProperty);
 							
-//							デバイスと書いてあるところにデバイス名を表示
-							copy.setValue(d.getDeviceName());
+							//デバイス表示名を表示
+							copy.setValue(d.getDisplayName());
 							
+							//デバイス表示名
+							propertyList = PropertyUtil.getProperty(copy, DEVICE_DISPLAY_NAME);
+							if(d.getDisplayName() != null && d.getDisplayName().compareTo("") != 0){
+								((Property)propertyList.get(0)).setValue(d.getDisplayName());
+							}
 							//デバイス名
 							propertyList = PropertyUtil.getProperty(copy, DEVICE_NAME);
 							if(d.getDeviceName() != null && d.getDeviceName().compareTo("") != 0){
@@ -518,6 +628,16 @@ public class NodeProperty {
 								((Property)propertyList.get(0)).setValue(d.getDescription());
 							}
 							property.addChildren(copy, index + i);
+							m_log.debug("i!=0");
+							m_log.debug("d.getDisplayName() = " + d.getDisplayName());
+							m_log.debug("d.getDeviceName() = " + d.getDeviceName());
+							m_log.debug("d.getSnmpOID() = " + d.getSnmpOID());
+							m_log.debug("d.getDeviceIndex() = " + d.getDeviceIndex());
+							m_log.debug("d.getDeviceType() = " + d.getDeviceType());
+							m_log.debug("d.getDescription() = " + d.getDescription());
+							m_log.debug("d.getFacilityId() = " + d.getFacilityId());
+							m_log.debug("d.getCn() = " + d.getCn());
+							m_log.debug("d.getDn() = " + d.getDn());
 						}
 						i++;
 					}
@@ -532,19 +652,21 @@ public class NodeProperty {
 				
 				//ファイルシステムを取得
 				Collection fileSystemList = null;
-				try {
-					fileSystemList = facility.getFileSystemInfo();
-				} catch (FinderException e) {
-				}
+				fileSystemList = facility.getFileSystemInfo();
 				if(fileSystemList != null){
 					Iterator itr = fileSystemList.iterator();
 					int i = 0;
 					while(itr.hasNext()){
 						FileSystemInfoLocal fs = (FileSystemInfoLocal)itr.next();
 						if(i == 0){
-//							ファイルシステムと書いてあるところにマウントポイントを表示
-							fileSystemProperty.setValue(fs.getFileSystemMountPoint());
+							//ファイルシステム表示名を表示
+							fileSystemProperty.setValue(fs.getDisplayName());
 							
+						    //ファイルシステム表示名
+							propertyList = PropertyUtil.getProperty(fileSystemProperty, FILE_SYSTEM_DISPLAY_NAME);
+							if(fs.getDisplayName() != null && fs.getDisplayName().compareTo("") != 0){
+								((Property)propertyList.get(0)).setValue(fs.getDisplayName());
+							}
 							//ファイルシステムINDEX
 							propertyList = PropertyUtil.getProperty(fileSystemProperty, FILE_SYSTEM_INDEX);
 							if(fs.getCn() != null){
@@ -570,13 +692,27 @@ public class NodeProperty {
 							if(fs.getDescription() != null && fs.getDescription().compareTo("") != 0){
 								((Property)propertyList.get(0)).setValue(fs.getDescription());
 							}
+							m_log.debug("i==0");
+							m_log.debug("fs.getDisplayName() = " + fs.getDisplayName());
+							m_log.debug("fs.getCn() = " + fs.getCn());
+							m_log.debug("fs.getFileSystemMountPoint() = " + fs.getFileSystemMountPoint());
+							m_log.debug("fs.getSnmpOID() = " + fs.getSnmpOID());
+							m_log.debug("fs.getFileSystemType() = " + fs.getFileSystemType());
+							m_log.debug("fs.getDescription() = " + fs.getDescription());
+							m_log.debug("fs.getDn() = " + fs.getDn());
+							m_log.debug("fs.getFacilityId() = " + fs.getFacilityId());
 						}
 						else{
 							Property copy = PropertyUtil.copy(fileSystemProperty);
 							
-//							ファイルシステムと書いてあるところにマウントポイントを表示
-							copy.setValue(fs.getFileSystemMountPoint());
+							//ファイルシステム表示名を表示
+							copy.setValue(fs.getDisplayName());
 							
+						    //ファイルシステム表示名
+							propertyList = PropertyUtil.getProperty(copy, FILE_SYSTEM_DISPLAY_NAME);
+							if(fs.getDisplayName() != null && fs.getDisplayName().compareTo("") != 0){
+								((Property)propertyList.get(0)).setValue(fs.getDisplayName());
+							}
 							//ファイルシステムINDEX
 							propertyList = PropertyUtil.getProperty(copy, FILE_SYSTEM_INDEX);
 							if(fs.getCn() != null){
@@ -603,6 +739,15 @@ public class NodeProperty {
 								((Property)propertyList.get(0)).setValue(fs.getDescription());
 							}
 							property.addChildren(copy, index + i);
+							m_log.debug("i!=0");
+							m_log.debug("fs.getDisplayName() = " + fs.getDisplayName());
+							m_log.debug("fs.getCn() = " + fs.getCn());
+							m_log.debug("fs.getFileSystemMountPoint() = " + fs.getFileSystemMountPoint());
+							m_log.debug("fs.getSnmpOID() = " + fs.getSnmpOID());
+							m_log.debug("fs.getFileSystemType() = " + fs.getFileSystemType());
+							m_log.debug("fs.getDescription() = " + fs.getDescription());
+							m_log.debug("fs.getDn() = " + fs.getDn());
+							m_log.debug("fs.getFacilityId() = " + fs.getFacilityId());
 						}
 						i++;
 					}
@@ -714,7 +859,10 @@ public class NodeProperty {
 		Property modifierName =
 			new Property(MODIFIER_NAME, Messages.getString("modifier.name", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
 
-		//デバイス
+		//デバイス表示名
+		Property deviceDisplayName =
+			new Property(DEVICE_DISPLAY_NAME, Messages.getString("device.display.name", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
+		//デバイス名
 		Property deviceName =
 			new Property(DEVICE_NAME, Messages.getString("device.name", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
 		//デバイスOID
@@ -730,6 +878,9 @@ public class NodeProperty {
 		Property deviceDescription =
 			new Property(DEVICE_DESCRIPTION, Messages.getString("description", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
 		
+		//ファイルシステム表示名
+		Property fileSystemDisplayName =
+			new Property(FILE_SYSTEM_DISPLAY_NAME, Messages.getString("file.system.display.name", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
 		//マウント位置
 		Property fileSystemMountPoint =
 			new Property(FILE_SYSTEM_MOUNT_POINT, Messages.getString("file.system.mount.point", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
@@ -774,7 +925,10 @@ public class NodeProperty {
 		//SNMP
 		Property snmp =
 			new Property(SNMP, Messages.getString("snmp", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
-
+		//WBEM
+		Property wbem =
+			new Property(WBEM, Messages.getString("wbem", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
+		
 		//SNMPタイムアウト
 		Property snmpTimeout =
 			new Property(SNMPTIMEOUT, Messages.getString("snmp.timeout", locale), PropertyConstant.EDITOR_NUM, Integer.MAX_VALUE, 0);
@@ -815,9 +969,46 @@ public class NodeProperty {
 			new Property(VMNAME, Messages.getString("vm.name", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_64);
 		//仮想化ソリューション
 		Property virtSolution =
-			new Property(VIRTSOLUTION, Messages.getString("virtualization.solution", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_64);
+			new Property(VIRTSOLUTION, Messages.getString("virtualization.solution", locale), PropertyConstant.EDITOR_SELECT);
 
 		
+		//20090114
+		
+		//仮想マシンID
+		Property vmId =
+			new Property(VMID, Messages.getString("vm.id", locale),  PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_64);
+		
+		//仮想化ソフト接続ユーザ
+		Property vmUser =
+			new Property(VMUSER, Messages.getString("vm.user", locale),  PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_64);
+		
+		//仮想化ソフト接続ユーザパスワード
+		Property vmUserPassword =
+			new Property(VMUSERPASSWORD, Messages.getString("vm.userpassword", locale),  PropertyConstant.EDITOR_PASSWORD, DataRangeConstant.VARCHAR_64);
+		
+		//仮想化ソフト接続プロトコル
+		Property vmProtocol =
+			new Property(VMPROTOCOL, Messages.getString("vm.protocol", locale),  PropertyConstant.EDITOR_SELECT);
+
+		//WBEM接続ユーザ
+		Property wbemUser =
+			new Property(WBEM_USER, Messages.getString("wbem.user", locale),  PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_64);
+		//WBEM接続ユーザパスワード
+		Property wbemUserPassword =
+			new Property(WBEM_USER_PASSWORD, Messages.getString("wbem.user.password", locale),  PropertyConstant.EDITOR_PASSWORD, DataRangeConstant.VARCHAR_64);
+		//WBEM接続ポート番号
+		Property wbemPort =
+			new Property(WBEM_PORT, Messages.getString("wbem.port.number", locale), PropertyConstant.EDITOR_NUM, DataRangeConstant.PORT_NUMBER_MAX, 0);
+		//WBEM接続プロトコル
+		Property wbemProtocol =
+			new Property(WBEM_PROTOCOL, Messages.getString("wbem.protocol", locale),  PropertyConstant.EDITOR_SELECT);
+		//WBEM接続タイムアウト
+		Property wbemTimeout =
+			new Property(WBEM_TIMEOUT, Messages.getString("wbem.timeout", locale), PropertyConstant.EDITOR_NUM, Integer.MAX_VALUE, 0);
+		//WBEM接続リトライ回数
+		Property wbemRetries = 
+			new Property(WBEM_RETRIES, Messages.getString("wbem.retries", locale), PropertyConstant.EDITOR_NUM, Integer.MAX_VALUE, 0);
+
 		
 		
 		//値を初期化
@@ -855,12 +1046,14 @@ public class NodeProperty {
 		modifyTime.setValue("");
 		modifierName.setValue("");
 		
+		deviceDisplayName.setValue("");
 		deviceName.setValue("");
 		deviceOID.setValue("");
 		deviceIndex.setValue("");
 		deviceType.setValue("");
 		deviceDescription.setValue("");
 
+		fileSystemDisplayName.setValue("");
 		fileSystemMountPoint.setValue("");
 		fileSystemOID.setValue("");
 		fileSystemIndex.setValue("");
@@ -902,12 +1095,34 @@ public class NodeProperty {
 		virtualization.setValue("");
 		virtNodeType.setSelectValues(vmNodeTypeValue);
 		virtNodeType.setValue("");
-		vmManagementNode.setSelectValues(getFacilityIdAndFacilityName());
+		vmManagementNode.setSelectValues(getHostFacilityIdAndFacilityName());
 		vmManagementNode.setValue("");
 		vmIndex.setValue("");
 		vmName.setValue("");
+		virtSolution.setSelectValues(getVmSolutionNames());
 		virtSolution.setValue("");
-	
+		
+		//20090114
+		vmId.setValue("");
+		vmUser.setValue("");
+		vmUserPassword.setValue("");
+		vmProtocol.setSelectValues(getVmProtocol());
+		vmProtocol.setValue("");
+		
+		Object wbemProtocolValue[][] = {
+				{"", "http"},
+				{"", "http"}
+		};
+		
+		wbem.setValue("");
+		wbemUser.setValue("");
+		wbemUserPassword.setValue("");
+		wbemPort.setValue("");
+		wbemProtocol.setSelectValues(wbemProtocolValue);
+		wbemProtocol.setValue("");
+		wbemTimeout.setValue("");
+		wbemRetries.setValue("");
+		
 
 		//モードにより、変更可及びコピー可を設定
 		if(mode == PropertyConstant.MODE_ADD){
@@ -937,12 +1152,14 @@ public class NodeProperty {
 			administrator.setModify(PropertyConstant.MODIFY_OK);
 			contact.setModify(PropertyConstant.MODIFY_OK);
 			
+			deviceDisplayName.setModify(PropertyConstant.MODIFY_OK);
 			deviceName.setModify(PropertyConstant.MODIFY_OK);
 			deviceOID.setModify(PropertyConstant.MODIFY_OK);
 			deviceIndex.setModify(PropertyConstant.MODIFY_OK);
 			deviceType.setModify(PropertyConstant.MODIFY_OK);
 			deviceDescription.setModify(PropertyConstant.MODIFY_OK);
 			
+			fileSystemDisplayName.setModify(PropertyConstant.MODIFY_OK);
 			fileSystemMountPoint.setModify(PropertyConstant.MODIFY_OK);
 			fileSystemOID.setModify(PropertyConstant.MODIFY_OK);
 			fileSystemIndex.setModify(PropertyConstant.MODIFY_OK);
@@ -967,6 +1184,19 @@ public class NodeProperty {
 			vmName.setModify(PropertyConstant.MODIFY_OK);
 			virtSolution.setModify(PropertyConstant.MODIFY_OK);
 			
+			//20090114 add
+			vmId.setModify(PropertyConstant.MODIFY_OK);
+			vmUser.setModify(PropertyConstant.MODIFY_OK);
+			vmUserPassword.setModify(PropertyConstant.MODIFY_OK);
+			vmProtocol.setModify(PropertyConstant.MODIFY_OK);
+			
+			wbemUser.setModify(PropertyConstant.MODIFY_OK);
+			wbemUserPassword.setModify(PropertyConstant.MODIFY_OK);
+			wbemPort.setModify(PropertyConstant.MODIFY_OK);
+			wbemProtocol.setModify(PropertyConstant.MODIFY_OK);
+			wbemTimeout.setModify(PropertyConstant.MODIFY_OK);
+			wbemRetries.setModify(PropertyConstant.MODIFY_OK);
+			
 			hostName.setCopy(PropertyConstant.COPY_OK);
 			note.setCopy(PropertyConstant.COPY_OK);
 			note.setModify(PropertyConstant.MODIFY_OK);
@@ -999,12 +1229,14 @@ public class NodeProperty {
 			administrator.setModify(PropertyConstant.MODIFY_OK);
 			contact.setModify(PropertyConstant.MODIFY_OK);
 			
+			deviceDisplayName.setModify(PropertyConstant.MODIFY_OK);
 			deviceName.setModify(PropertyConstant.MODIFY_OK);
 			deviceOID.setModify(PropertyConstant.MODIFY_OK);
 			deviceIndex.setModify(PropertyConstant.MODIFY_OK);
 			deviceType.setModify(PropertyConstant.MODIFY_OK);
 			deviceDescription.setModify(PropertyConstant.MODIFY_OK);
 			
+			fileSystemDisplayName.setModify(PropertyConstant.MODIFY_OK);
 			fileSystemMountPoint.setModify(PropertyConstant.MODIFY_OK);
 			fileSystemOID.setModify(PropertyConstant.MODIFY_OK);
 			fileSystemIndex.setModify(PropertyConstant.MODIFY_OK);
@@ -1029,6 +1261,19 @@ public class NodeProperty {
 			vmName.setModify(PropertyConstant.MODIFY_OK);
 			virtSolution.setModify(PropertyConstant.MODIFY_OK);
 			
+			//20090114 add
+			vmId.setModify(PropertyConstant.MODIFY_OK);
+			vmUser.setModify(PropertyConstant.MODIFY_OK);
+			vmUserPassword.setModify(PropertyConstant.MODIFY_OK);
+			vmProtocol.setModify(PropertyConstant.MODIFY_OK);
+
+			wbemUser.setModify(PropertyConstant.MODIFY_OK);
+			wbemUserPassword.setModify(PropertyConstant.MODIFY_OK);
+			wbemPort.setModify(PropertyConstant.MODIFY_OK);
+			wbemProtocol.setModify(PropertyConstant.MODIFY_OK);
+			wbemTimeout.setModify(PropertyConstant.MODIFY_OK);
+			wbemRetries.setModify(PropertyConstant.MODIFY_OK);
+			
 			hostName.setCopy(PropertyConstant.COPY_OK);
 			note.setCopy(PropertyConstant.COPY_OK);
 			note.setModify(PropertyConstant.MODIFY_OK);
@@ -1069,6 +1314,7 @@ public class NodeProperty {
 //		network.addChildren(statusMonitoring);
 //		network.addChildren(eventMonitoring);
 		network.addChildren(snmp);
+		network.addChildren(wbem);
 		network.addChildren(dhcpClient);
 		network.addChildren(ipAddressType);
 		network.addChildren(ipAddressVersion);
@@ -1076,6 +1322,7 @@ public class NodeProperty {
 		network.addChildren(ipAddressV6);
 		network.addChildren(hostName);
 		
+		// SNMPツリー
 		snmp.removeChildren();
 		snmp.addChildren(snmpPort);
 		snmp.addChildren(snmpCommunity);
@@ -1084,6 +1331,14 @@ public class NodeProperty {
 		snmp.addChildren(snmpRetries);
 		snmp.addChildren(snmpProxy);
 
+		// WBEMツリー
+		wbem.removeChildren();
+		wbem.addChildren(wbemUser);
+		wbem.addChildren(wbemUserPassword);
+		wbem.addChildren(wbemPort);
+		wbem.addChildren(wbemProtocol);
+		wbem.addChildren(wbemTimeout);
+		wbem.addChildren(wbemRetries);
 		
 		// OSツリー
 		os.removeChildren();
@@ -1102,6 +1357,12 @@ public class NodeProperty {
 		virtualization.addChildren(vmName);
 		virtualization.addChildren(virtSolution);
 		
+		virtualization.addChildren(vmId);
+		virtualization.addChildren(vmUser);
+		virtualization.addChildren(vmUserPassword);
+		virtualization.addChildren(vmProtocol);
+
+		
 		// 保守ツリー
 		maintenance.removeChildren();
 		maintenance.addChildren(administrator);
@@ -1109,6 +1370,7 @@ public class NodeProperty {
 		
 		// デバイスツリー
 		device.removeChildren();
+		device.addChildren(deviceDisplayName);
 		device.addChildren(deviceName);
 		device.addChildren(deviceOID);
 		device.addChildren(deviceIndex);
@@ -1118,6 +1380,7 @@ public class NodeProperty {
 		
 		// ファイルシステムツリー
 		fileSystem.removeChildren();
+		fileSystem.addChildren(fileSystemDisplayName);
 		fileSystem.addChildren(fileSystemIndex);
 		fileSystem.addChildren(fileSystemMountPoint);
 		fileSystem.addChildren(fileSystemOID);
@@ -1218,6 +1481,155 @@ public class NodeProperty {
 			throw e;
 		}
 		
+		return ret;
+	}
+	
+	/**
+	 * 
+	 * コンボボックス表示のためのファシリティID, ファシリティ名を返すメソッド
+	 * 返り値は下記の構成の２次元配列である。
+	 * 
+	 * {{value1, value2, ...}, {DisplayText1, DisplayText2, ...}}
+	 * 
+	 * value		：　ファシリティID
+	 * DisplayText	：　ファシリティ名(ファシリティID)
+	 * 
+	 * 値をセットするメソッドの引数がObject型の２次元配列のため、その形式で返す.
+	 * 対象は管理ノード=Hostノード+UNALLOCATED
+	 * 
+	 * @return オブジェクト配列
+	 * @throws FinderException
+	 * @throws NamingException
+	 */
+	private Object[][] getHostFacilityIdAndFacilityName() throws FinderException, NamingException {
+		
+		Object[][] ret = null;
+		
+		try{
+			HashMap<String, String> condition = new HashMap<String, String>();
+			condition.put(FacilityAttributeConstant.VIRTNODETYPE, "host");
+			Collection nodes = FacilityUtil.getLocalHome().findByCondition(condition);
+			Iterator iterator = nodes.iterator();
+			ArrayList<String> facilityIdList = new ArrayList();
+			ArrayList<String> facilityNameList = new ArrayList();
+			facilityIdList.add("");
+			facilityNameList.add("");
+			while (iterator.hasNext()) {
+				FacilityLocal facility = (FacilityLocal)iterator.next();
+				facilityIdList.add(facility.getFacilityId());
+				facilityNameList.add(facility.getCn() + "(" + facility.getFacilityId() + ")" );
+			}
+			//未割当を選択できるようにUNALLOCATEDを追加
+			facilityIdList.add(FacilityTreeAttributeConstant.UNALLOCATED_SCOPE);
+			facilityNameList.add(Messages.getString("vm.scope.unallocated")+ "(" + FacilityTreeAttributeConstant.UNALLOCATED_SCOPE + ")" );
+			
+			ret = new Object[2][facilityIdList.size()];
+			ret[PropertyConstant.SELECT_VALUE] = facilityIdList.toArray();
+			ret[PropertyConstant.SELECT_DISP_TEXT] = facilityNameList.toArray();
+			
+		} catch (FinderException e) {
+			m_log.error("getHostFacilityIdAndFacilityName() : findAllNode failure ", e);
+			throw e;
+		} catch (NamingException e) {
+			m_log.error("getHostFacilityIdAndFacilityName() : FacilityUtil.getLocalHome() failure ", e);
+			throw e;
+		}
+		
+		return ret;
+	}
+	
+	
+	/**
+	 * 
+	 * コンボボックス表示のための, 仮想化ソリューション名を返すメソッド
+	 * 返り値は下記の構成の２次元配列である。
+	 * 
+	 * {{value1, value2, ...}, {DisplayText1, DisplayText2, ...}}
+	 * 
+	 * value		：　仮想化ソフトソリューションID
+	 * DisplayText	：　仮想化ソリューション名(仮想化ソフトソリューションID)
+	 * 
+	 * 値をセットするメソッドの引数がObject型の２次元配列のため、その形式で返す
+	 * 
+	 * @return オブジェクト配列
+	 */
+	private Object[][] getVmSolutionNames() throws FinderException, NamingException {
+		Object[][] ret = null;
+		
+		try {
+			Collection<VmSolutionMstLocal> vmSolutions = VmSolutionMstUtil.getLocalHome().findAll();
+			Iterator<VmSolutionMstLocal> iterator = vmSolutions.iterator();
+			
+			ArrayList<String> vmSolutionIdList = new ArrayList<String>();
+			ArrayList<String> vmSolutionNameList = new ArrayList<String>();
+			vmSolutionIdList.add("");
+			vmSolutionNameList.add("");
+			
+			while(iterator.hasNext()) {
+				VmSolutionMstLocal vmSolution = iterator.next();
+				vmSolutionIdList.add(vmSolution.getVmSolutionId());
+				vmSolutionNameList.add(vmSolution.getVmSolutionName() + "(" + vmSolution.getVmSolutionId() + ")");
+			}
+			
+			ret = new Object[2][vmSolutionIdList.size()];
+			ret[PropertyConstant.SELECT_VALUE] = vmSolutionIdList.toArray();
+			ret[PropertyConstant.SELECT_DISP_TEXT] = vmSolutionNameList.toArray();
+			
+		} catch (FinderException e) {
+			m_log.error("getVmSolutionNames() : findAllNode failure ", e);
+			throw e;
+		} catch (NamingException e) {
+			m_log.error("getVmSolutionNames() : FacilityUtil.getLocalHome() failure ", e);
+			throw e;
+		}
+		
+		
+		return ret;
+	}
+	
+	/**
+	 * 
+	 * コンボボックス表示のための,プロトコル名を返すメソッド
+	 * 返り値は下記の構成の２次元配列である。
+	 * 
+	 * {{value1, value2, ...}, {DisplayText1, DisplayText2, ...}}
+	 * 
+	 * value		：　プロトコル名
+	 * DisplayText	：　プロトコル名
+	 * 
+	 * 値をセットするメソッドの引数がObject型の２次元配列のため、その形式で返す
+	 * 
+	 * @return オブジェクト配列
+	 */
+	private Object[][] getVmProtocol() throws FinderException, NamingException {
+		Object[][] ret = null;
+		
+		try {
+			Collection<VmProtocolMstLocal> vmProtocols = VmProtocolMstUtil.getLocalHome().findAll();
+			Iterator<VmProtocolMstLocal> iterator = vmProtocols.iterator();
+			
+			ArrayList<String> vmProtocolList = new ArrayList<String>();
+			vmProtocolList.add("");
+			
+			while(iterator.hasNext()) {
+				VmProtocolMstLocal vmProtocol = iterator.next();
+				vmProtocolList.add(vmProtocol.getProtocol());
+			}
+			
+			ret = new Object[2][vmProtocolList.size()];
+			ret[PropertyConstant.SELECT_VALUE] = vmProtocolList.toArray();
+			ret[PropertyConstant.SELECT_DISP_TEXT] = vmProtocolList.toArray();
+
+			
+		} catch (FinderException e) {
+			m_log.error("getVmProtocol() : findAllNode failure ", e);
+			throw e;
+		} catch (NamingException e) {
+			m_log.error("getVmProtocol() : FacilityUtil.getLocalHome() failure ", e);
+			throw e;
+		}
+		
+		
 		return ret;
 	}
 }
