@@ -126,6 +126,7 @@ public class SelectMonitorInfo {
 			monitorInfo.setRegUser(info.getRegUser());
 			monitorInfo.setUpdateUser(info.getUpdateUser());
 			monitorInfo.setCheckMode(info.getCheckMode());
+			monitorInfo.setCalendarId(info.getCalendarId());
 			monitorInfo.setNotifyId(notifyId);
 			
 			// 監視OID情報取得
@@ -456,6 +457,7 @@ public class SelectMonitorInfo {
 	 */
 	@SuppressWarnings("unchecked")
 	public SnmpTrapFacilityInfo getSnmpTrapFacilityInfo(String monitorId) throws CreateException, FinderException, NamingException {
+		m_log.debug("start getSnmpTrapFacilityInfo() MonitorId : " + monitorId);
 		
 		// SNMPTRAP監視を取得
 		SnmpTrapFacilityInfo snmpTrapInfo = null;
@@ -518,6 +520,8 @@ public class SelectMonitorInfo {
 				
 				snmpTrapInfo.setCheckMode(info.getCheckMode());
 				
+				snmpTrapInfo.setCalendarId(info.getCalendarId());
+				
 				if(snmpTrapInfo.getCheckMode() == 1 || snmpTrapInfo.getCheckMode() == 2){
 					//checkMode 1 : すべてのOIDを監視
 					//checkMode 2 : マスター以外のOIDを監視 
@@ -558,6 +562,8 @@ public class SelectMonitorInfo {
 			m_log.debug("getSnmpTrapFacilityInfo():" + e.getMessage());
 			throw e;
 		}
+		
+		m_log.debug("end   getSnmpTrapFacilityInfo() MonitorId : " + monitorId);
 		return snmpTrapInfo;
 	}
 	
@@ -649,6 +655,8 @@ public class SelectMonitorInfo {
 					
 					snmpTrapInfo.setCheckMode(info.getCheckMode());
 					
+					snmpTrapInfo.setCalendarId(info.getCalendarId());
+					
 					//OIDのリストを作成する。
 					ArrayList<SnmpTrapOidInfo> oidList = new ArrayList<SnmpTrapOidInfo>();
 					
