@@ -15,15 +15,11 @@
 
 package com.clustercontrol.snmptrap.factory;
 
-import java.io.File;
-import java.io.FileInputStream;
-import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.Map;
-import java.util.Properties;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 
@@ -35,6 +31,8 @@ import javax.naming.NamingException;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.calendar.ejb.session.CalendarControllerLocal;
+import com.clustercontrol.calendar.ejb.session.CalendarControllerUtil;
 import com.clustercontrol.commons.util.SendQueue;
 import com.clustercontrol.repository.bean.FacilityAttributeConstant;
 import com.clustercontrol.repository.bean.FacilityTreeAttributeConstant;
@@ -117,12 +115,6 @@ public class TrapSnmpManager {
 	 */
 	private int m_port = 162;
 	
-	/**
-	 * SNMPTRAPカウンタ(受信数)
-	 */
-	private long snmptrapCounter = 0;
-	private int statsInterval = 100;
-	
 	/**
 	 * コンストラクタ
 	 * @param port 待ち受けポート番号
@@ -132,35 +124,6 @@ public class TrapSnmpManager {
 		m_port = port;
 	}
 	
-	/**
-	 * hinemos.propertiesからsnmptrap.stats.intervalというプロパティ値を取得して返す。
-	 * デフォルト値は100。
-	 * SNMPTRAP受信数/100の間隔でログファイルにSNMP受信数を出力する。
-	 * @return
-	 */
-	private int getStatsInterval () {
-		Properties properties = new Properties();
-		String etcdir = System.getProperty("hinemos.manager.etc.dir");
-		String propertyFile = etcdir + File.separator + "hinemos.properties";
-		FileInputStream stream = null;
-		try {
-			stream = new FileInputStream(propertyFile);
-			properties.load(stream);
-			statsInterval = Integer.parseInt(properties.getProperty("snmptrap.stats.interval","100"));
-			m_log.debug("getStatsInterval() : " + statsInterval);
-		} catch (Exception e) {
-		} finally {
-			if (stream != null) {
-				try {
-					stream.close();
-				} catch (IOException e) {
-				}
-				stream = null;
-			}
-		}
-		return statsInterval;
-	}
-	
 	/**
 	 * 開始処理
 	 */
@@ -170,9 +133,6 @@ public class TrapSnmpManager {
 			m_sendQueue = new SendQueue(QueueConstant.QUEUE_NAME_NOTIFY);
 			m_repository = RepositoryControllerUtil.getLocalHome().create();
 			
-			// 統計情報の出力間隔を設定ファイルから読み込む。
-			getStatsInterval();
-			
 			// キャッシュ取得
 			
 			updateCache();
@@ -238,11 +198,6 @@ public class TrapSnmpManager {
 		m_log.debug("find() : received generic : " + Integer.toString(genericId) );
 		m_log.debug("find() : received specific: " + Integer.toString(specificId) );
 		
-		snmptrapCounter++;
-		if (statsInterval != 0 && snmptrapCounter % statsInterval == 0) {
-			m_log.info("find() : The number of received snmptrap : " + snmptrapCounter);
-		}
-		
 		if(m_snmpTrapInfoMap == null)
 			return true;
 		
@@ -255,6 +210,31 @@ public class TrapSnmpManager {
 			if(info == null)
 				continue;
 			
+			// カレンダのチェック
+			String calendarId = info.getCalendarId();
+			m_log.debug("check calender.  MonitorID : " + info.getMonitorId() + ", CalendarID ： " + calendarId);
+			if(calendarId != null && !"".equals(calendarId)){
+				try {
+					// 稼働日か否かチェック
+					CalendarControllerLocal calendar = CalendarControllerUtil.getLocalHome().create();
+					
+					if(!calendar.isRun(calendarId, trapDate).booleanValue()){
+						// 非稼働日の場合は、処理終了
+						m_log.debug("MonitorID : " + info.getMonitorId() + " is disable.");
+						continue;
+					}
+				} catch (FinderException e) {
+					// 指定されたカレンダIDがすでに存在しない場合は、処理継続
+					m_log.error("CalendarId not found. CalendarId : " + calendarId);
+				} catch (CreateException e) {
+					// 予期せぬエラーが発生した場合は、処理継続
+					m_log.error("Error: get CalendarId. CalendarId : " + calendarId, e);
+				} catch (NamingException e) {
+					// 予期せぬエラーが発生した場合は、処理継続
+					m_log.error("Error: get CalendarId. CalendarId : " + calendarId, e);
+				}
+			}
+			
 			// コミュニティ名が同一か
 			
 			String communityNameCache = info.getCommunityName();
