@@ -17,7 +17,6 @@ package com.clustercontrol.syslogng.forward;
 
 import java.io.File;
 import java.io.Serializable;
-import java.rmi.RemoteException;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.HashMap;
@@ -26,7 +25,6 @@ import java.util.Properties;
 import java.util.Timer;
 import java.util.TimerTask;
 
-import javax.ejb.CreateException;
 import javax.ejb.FinderException;
 import javax.jms.ExceptionListener;
 import javax.jms.JMSException;
@@ -52,6 +50,7 @@ import com.clustercontrol.notify.bean.QueueConstant;
 import com.clustercontrol.repository.bean.FacilityAttributeConstant;
 import com.clustercontrol.repository.bean.FacilityTreeAttributeConstant;
 import com.clustercontrol.repository.ejb.session.RepositoryController;
+import com.clustercontrol.repository.ejb.session.RepositoryControllerBean;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerHome;
 import com.clustercontrol.syslogng.bean.LogFilterInfo;
 import com.clustercontrol.syslogng.ejb.session.SyslogNGController;
@@ -129,6 +128,11 @@ public class EJBContoroller {
 	/** ログ出力のインスタンス。 */
 	static Log log = LogFactory.getLog(EJBContoroller.class);
 	
+	/** リポジトリ情報のローカルコンポーネント。 */
+	private RepositoryControllerHome m_repositoryHome;
+	
+	/** syslog-ng情報のホーム。 */
+	private SyslogNGControllerHome m_logFilterHome;
 	
 	/** Lockオブジェクト */
 	private Object reconnectLock = new Object();
@@ -276,151 +280,134 @@ public class EJBContoroller {
 	 */
 	public void loadFilterInfo() {
 		
-		log.debug("loadFilterInfo() : start");
+		log.debug("フィルタ条件受信開始!");
 		
-		// 最後に失敗した例外格納用
-		Exception lastException = null;
+		//
+		// syslog-ng監視条件取得
+		//
+		ArrayList<LogFilterRepositoryInfo> filterRepList = null;
 		
-		// EJB認証失敗のケースを想定して指定回数リトライする
-		boolean flg = false;
-		for (int i = 0; i < 10; i++) {
-			log.debug("loadFilterInfo() : number of trials = " + i);
+		NamingContext con;
+		try {
+			con = LoginManager.getContextManager(m_props).getNamingContext();
 			
-			NamingContext con;
-			RepositoryControllerHome m_repositoryHome;
-			SyslogNGControllerHome m_logFilterHome;
+			//リポジトリ情報ホームインターフェース
+			m_repositoryHome = (RepositoryControllerHome) con
+			.lookup(RepositoryControllerHome.JNDI_NAME);
 			
-			ArrayList<LogFilterRepositoryInfo> filterRepList = null;
-			RepositoryController repositoryController = null;
-			SyslogNGController logFilter = null;
-			
-			try{
-				//
-				//ログイン処理
-				//
-				log.debug("Login Hinemos Manager");
-				con = LoginManager.getContextManager(m_props).getNamingContext();
-				
-				//リポジトリ情報ホームインターフェース
-				m_repositoryHome = (RepositoryControllerHome) con
-				.lookup(RepositoryControllerHome.JNDI_NAME);
-				
-				//syslog-ng監視情報ホームインターフェース
-				m_logFilterHome =  (SyslogNGControllerHome) con
-				.lookup(SyslogNGControllerHome.JNDI_NAME);
-				
-				//
-				// syslog-ng監視条件取得
-				//
-				log.debug("Load syslog-ng Filter Info");
-				logFilter = m_logFilterHome.create();
-				repositoryController = m_repositoryHome.create();
-				
-				
-				//フィルタ情報取得（ダイアログで見えるものリストと同じ？）
-				ArrayList filterList = logFilter.getFilterInfoList();
-				
-				//実際に実行するときのフィルタ情報
-				filterRepList = new ArrayList<LogFilterRepositoryInfo>();
-				
-				// syslog-ng監視条件には対象のfacilityIDしか含まないので、
-				//　リポジトリにアクセスを行い、フィルタ条件情報（ホスト名）を作成
-				for (Iterator iter = filterList.iterator(); iter.hasNext();) {
-					
-					//１つ１つのフィルタ条件を有効フラグを確認して、
-					//実行用のフィルタ条件としていく
-					LogFilterInfo filterInfo = (LogFilterInfo) iter.next();
-					if (ValidConstant.typeToBoolean(filterInfo.getValid())) {
-						
-						LogFilterRepositoryInfo filterRepInfo = 
-							new LogFilterRepositoryInfo(filterInfo);
-						
-						String facilityID = filterInfo.getFacilityId();
-						if(log.isDebugEnabled()){
-							log.debug("getList For:" + facilityID);
-						}
-						
-						//未登録ノード対応
-						//登録ノードのホスト名のリストをここでは入れておき、
-						//containsのメソッドで除外する
-						
-						if(facilityID.equals(FacilityTreeAttributeConstant.UNREGISTEREFD_SCOPE)){
-							
-							facilityID=FacilityTreeAttributeConstant.REGISTEREFD_SCOPE;
-							
-						}
-							
-						//配下の一覧
-						ArrayList facilityList = repositoryController.getExecTargetFacilityIdList(facilityID);
-						
-						//ノード名取得
-						ArrayList<String> attributeList = new ArrayList<String>();
-						attributeList.add(FacilityAttributeConstant.NODENAME);
-						attributeList.add(FacilityAttributeConstant.CN);
-						
-						HashMap facilityAttrMap = repositoryController
-						.getNodeDetail(facilityList, attributeList);
-						
-						filterRepInfo.setMap(facilityAttrMap);
-						
-						filterRepList.add(filterRepInfo);
-						
-					}	
-				}
-				
-				//
-				// フィルタ条件を設定
-				//
-				log.debug("Set New syslog-ng Filter Info");
-				m_logManager.add(filterRepList);
-				flg = true;
-			
-			} catch (NamingException e) {
-				log.debug("Login Hinemos Manager : fail",e);
-				lastException = e;
-			} catch (CreateException e) {
-				log.debug("Load syslog-ng Filter Info : fail",e);
-				lastException = e;
-			} catch (FinderException e) {
-				log.debug("Load syslog-ng Filter Info : fail",e);
-				lastException = e;
-			} catch (RemoteException e) {
-				log.debug("Load syslog-ng Filter Info : fail",e);
-				lastException = e;
-			} finally {
-				
-				log.debug("Logout Hinemos Manager");
-
-				//ログアウト
-				try {
-					LoginManager.getContextManager(m_props).logout();
-				} catch (NamingException e) {
-					log.error("Logout Hinemos Manager : fail",e);
-				}
-			}
-			
-			//
-			// 処理成功時に抜ける
-			//
-			if(flg) {
-				log.debug("loadFilterInfo() : success");
-				return;
-			}
-			
-			// 処理失敗時はタイミングをずらす為にsleep
-			try {
-				Thread.sleep(i * 100);
-			} catch (InterruptedException e) {
-				log.debug("Catch InterruptedException for isRun()",e);
-				Thread.currentThread().interrupt();
-			}
-		}	
-
-		if(lastException != null){
-			log.error("loadFilterInfo() : fail",lastException);
+			//syslog-ng監視情報ホームインターフェース
+			m_logFilterHome =  (SyslogNGControllerHome) con
+			.lookup(SyslogNGControllerHome.JNDI_NAME);
+		} catch (NamingException e) {
 		}
-		return;		
 		
+		RepositoryController repositoryController = null;
+		SyslogNGController logFilter = null;
+		
+		
+		try {
+			//
+			// EJB初期処理
+			//
+			log.debug("EJBインターフェース初期化");
+			logFilter = m_logFilterHome.create();
+			repositoryController = m_repositoryHome.create();
+			
+			
+			//フィルタ情報取得（ダイアログで見えるものリストと同じ？）
+			ArrayList filterList = logFilter.getFilterInfoList();
+			
+			//実際に実行するときのフィルタ情報
+			filterRepList = new ArrayList<LogFilterRepositoryInfo>();
+			
+			// syslog-ng監視条件には対象のfacilityIDしか含まないので、
+			//　リポジトリにアクセスを行い、フィルタ条件情報（ホスト名）を作成
+			for (Iterator iter = filterList.iterator(); iter.hasNext();) {
+				
+				//１つ１つのフィルタ条件を有効フラグを確認して、
+				//実行用のフィルタ条件としていく
+				LogFilterInfo filterInfo = (LogFilterInfo) iter.next();
+				if (ValidConstant.typeToBoolean(filterInfo.getValid())) {
+					
+					LogFilterRepositoryInfo filterRepInfo = 
+						new LogFilterRepositoryInfo(filterInfo);
+					
+					String facilityID = filterInfo.getFacilityId();
+					log.debug("getList For:" + facilityID);
+					
+					
+					//未登録ノード対応
+					//登録ノードのホスト名のリストをここでは入れておき、
+					//containsのメソッドで除外する
+					
+					if(facilityID.equals(FacilityTreeAttributeConstant.UNREGISTEREFD_SCOPE)){
+						
+						facilityID=FacilityTreeAttributeConstant.REGISTEREFD_SCOPE;
+						
+					}
+						
+					//配下の一覧
+					ArrayList facilityList = repositoryController.getExecTargetFacilityIdList(facilityID);
+//					ArrayList facilityList = repositoryController
+//					.getNodeFacilityIdList(facilityID,
+//							RepositoryControllerBean.ALL);
+//					
+//					//配下にノードがないということはノードの可能性があるので指定されたIDをセット
+//					if (facilityList.size() == 0) {
+//						facilityList.add(facilityID);
+//					}
+					
+					//ノード名取得
+					ArrayList<String> attributeList = new ArrayList<String>();
+					attributeList.add(FacilityAttributeConstant.NODENAME);
+					attributeList.add(FacilityAttributeConstant.CN);
+					
+					HashMap facilityAttrMap = repositoryController
+					.getNodeDetail(facilityList, attributeList);
+					
+					filterRepInfo.setMap(facilityAttrMap);
+					
+					filterRepList.add(filterRepInfo);
+					
+				}
+				
+			}
+			
+		} catch (Exception e) {
+			
+			log.error("フィルタ条件受信失敗!",e);
+			
+			return;
+			
+			
+		} finally {
+			
+			log.debug("EJBメソッド開放");
+			//
+			// EJB終了処理
+			//
+			try {
+				repositoryController.remove();
+				logFilter.remove();
+			} catch (Exception e) {
+			}
+			
+			//ログアウト
+			try {
+				LoginManager.getContextManager(m_props).logout();
+			} catch (NamingException e) {
+			}
+		}
+		
+		//
+		// フィルタ条件を設定
+		//
+		
+		m_logManager.add(filterRepList);
+		
+		log.debug("フィルタ条件受信終了!");
+		
+		return;
 	}
 	
 	/**
@@ -436,101 +423,56 @@ public class EJBContoroller {
 	 */
 	public boolean isRun(String id, OutputNotifyGroupInfo msg) {
 		
-		if(log.isDebugEnabled()){
-			log.debug("isRun() : start");
-		}
+		CalendarController calendarController = null;
 		
-		// 最後に失敗した例外格納用
-		Exception lastException = null;
-
-		// EJB認証失敗のケースを想定して指定回数リトライする
-		for (int i = 0; i < 10; i++) {
-			CalendarController calendarController = null;
-
-			if(log.isDebugEnabled()){
-				log.debug("isRun() : start id = " + id + ", msg = " + msg.getMessage() + ", number of trials = " + i);
-			}
+		try {
+			NamingContext con = LoginManager.getContextManager(m_props).getNamingContext();
 			
-			try{
-				//
-				//ログイン処理
-				//
-				if(log.isDebugEnabled()){
-					log.debug("Login Hinemos Manager");
-				}
-				NamingContext con = LoginManager.getContextManager(m_props).getNamingContext();
-				//カレンダ情報ホームインターフェース
-				CalendarControllerHome calendarHome = (CalendarControllerHome) con.lookup(CalendarControllerHome.JNDI_NAME);
-				calendarController = calendarHome.create();
-
-				//
-				//カレンダ稼働日チェック処理
-				//
-				try {
-					if(calendarController.isRun(id, msg.getGenerationDate()).booleanValue()){
-						// 稼動日
-						if(log.isDebugEnabled()){
-							log.debug("isRun() : success");
-						}
-						return true;
-					}
-					else{
-						// 非稼働日
-						if(log.isDebugEnabled()){
-							log.debug("isRun() : calendarID = " + id + ", It is non-operating day");
-						}
-						return false;
-					}
-				} catch (FinderException e) {
-					// 指定されたカレンダIDがすでに存在しない場合は、カレンダ指定なしと判断する
-					log.info("isRun() : calendarID = " + id + " is not exist! msg = " + msg.getMessage());
+			//カレンダ情報ホームインターフェース
+			CalendarControllerHome calendarHome = (CalendarControllerHome) con.lookup(CalendarControllerHome.JNDI_NAME);
+			calendarController = calendarHome.create();
+			
+			try {
+				if(calendarController.isRun(id, msg.getGenerationDate()).booleanValue()){
+					// 稼動日
 					return true;
 				}
-			} catch (Exception e) {
-				if(log.isDebugEnabled()){
-					log.debug("iisRun() : fail",e);
-				}
-				lastException = e;
-			} finally {
-				//
-				// ログアウト
-				//
-				if(log.isDebugEnabled()){
-					log.debug("Logout Hinemos Manager");
-				}
-				try {
-					LoginManager.getContextManager(m_props).logout();
-				} catch (NamingException e) {
-					log.error("Logout Hinemos Manager : fail",e);
+				else{
+					// 非稼働日
+					log.debug("isRun() : カレンダID：" + id + "。非稼働日です。");
 				}
+			} catch (FinderException e) {
+				// 指定されたカレンダIDがすでに存在しない
+				log.info("isRun() : フィルタ条件に指定されたカレンダID「" + id + "」は存在しません。");
 			}
 			
-			// 処理失敗時はタイミングをずらす為にsleep
+		} catch (Exception e) {
+			log.error("isRun() : 稼働日チェック失敗!",e);
+			
+			// 失敗はファイル出力
+			log.info("オブジェクトメッセージファイル書き込み!");
+			m_logManager.addMsg((String) msg.getMessageOrg());
+			
+			setErrFlg(true);
+			
+		} finally {
+			
+			log.debug("EJBメソッド開放");
+			//
+			// EJB終了処理
+			//
 			try {
-				Thread.sleep(i * 100);
-			} catch (InterruptedException e) {
-				if(log.isDebugEnabled()){
-					log.debug("Catch InterruptedException for isRun()",e);
-				}
-				Thread.currentThread().interrupt();
+				calendarController.remove();
+			} catch (Exception e) {
+			}
+			
+			//ログアウト
+			try {
+				LoginManager.getContextManager(m_props).logout();
+			} catch (NamingException e) {
 			}
 		}
-		
-		//
-		// 失敗はファイル出力(指定回数失敗したら諦める)
-		//
-		log.info("Write Message To Files");
-		m_logManager.addMsg((String) msg.getMessageOrg());
-		setErrFlg(true);
-
-		//
-		// 指定回数失敗したらカレンダ指定無しと判断する
-		//
-		if(lastException != null){
-			log.error("isRun() : fail id = " + id + ", msg = " + msg.getMessage(),lastException);
-		}
-		return true;	
-
+		return false;		
 	}
 	
 	/**
