@@ -85,6 +85,9 @@ public class UpdateRepositoryInfoReceiveTopic implements MessageListener, Except
 	/** メッセージサービス再接続用タイマー。*/
 	protected Timer m_timer = new Timer(true);
 	
+	/** Lockオブジェクト */
+	private Object reconnectLock = new Object();
+	
 	/**
 	 * コンストラクタ。<BR>
 	 * 初期処理を呼び出します。
@@ -233,13 +236,19 @@ public class UpdateRepositoryInfoReceiveTopic implements MessageListener, Except
 		try {
 			if (m_session != null)
 				m_session.close();
+			
+			m_log.debug("Session close was successful.");
 		} catch (JMSException e) {
+			m_log.error(e.getMessage(),e);
 		}
 		
 		try {
 			if (m_con != null)
 				m_con.close();
-		} catch (JMSException e1) {
+			
+			m_log.debug("Connection close was successful.");
+		} catch (JMSException e) {
+			m_log.error(e.getMessage(),e);
 		}
 	}
 	
@@ -251,6 +260,7 @@ public class UpdateRepositoryInfoReceiveTopic implements MessageListener, Except
 			if (m_subscriber != null)
 				m_subscriber.close();
 		} catch (JMSException e) {
+			m_log.error(e.getMessage(),e);
 		}
 	}
 	
@@ -362,12 +372,15 @@ public class UpdateRepositoryInfoReceiveTopic implements MessageListener, Except
 	/**
 	 * 再接続処理を行う
 	 */
-	synchronized public void reconnect() {
+	public void reconnect() {
 		
-        setErrFlg(true);
-        
-        terminate();
-        
+		synchronized (reconnectLock) {
+		
+			setErrFlg(true);
+			
+			terminate();
+			
+		}
 	}
 	
 	/**
